@@ -42,13 +42,12 @@ class Cache
     private $readOnly;
 
     /**
-     * @param IOInterface $io
      * @param string      $cacheDir   location of the cache
      * @param string      $allowlist  List of characters that are allowed in path names (used in a regex character class)
      * @param Filesystem  $filesystem optional filesystem instance
      * @param bool        $readOnly   whether the cache is in readOnly mode
      */
-    public function __construct(IOInterface $io, string $cacheDir, string $allowlist = 'a-z0-9.', Filesystem $filesystem = null, bool $readOnly = false)
+    public function __construct(IOInterface $io, string $cacheDir, string $allowlist = 'a-z0-9.', ?Filesystem $filesystem = null, bool $readOnly = false)
     {
         $this->io = $io;
         $this->root = rtrim($cacheDir, '/\\') . '/';
@@ -62,8 +61,6 @@ class Cache
     }
 
     /**
-     * @param bool $readOnly
-     *
      * @return void
      */
     public function setReadOnly(bool $readOnly)
@@ -80,8 +77,6 @@ class Cache
     }
 
     /**
-     * @param string $path
-     *
      * @return bool
      */
     public static function isUsable(string $path)
@@ -121,8 +116,6 @@ class Cache
     }
 
     /**
-     * @param string $file
-     *
      * @return string|false
      */
     public function read(string $file)
@@ -140,9 +133,6 @@ class Cache
     }
 
     /**
-     * @param string $file
-     * @param string $contents
-     *
      * @return bool
      */
     public function write(string $file, string $contents)
@@ -162,11 +152,11 @@ class Cache
                     unlink($tempFileName);
 
                     $message = sprintf(
-                        '<warning>Writing %1$s into cache failed after %2$u of %3$u bytes written, only %4$u bytes of free space available</warning>',
+                        '<warning>Writing %1$s into cache failed after %2$u of %3$u bytes written, only %4$s bytes of free space available</warning>',
                         $tempFileName,
                         $m[1],
                         $m[2],
-                        @disk_free_space(dirname($tempFileName))
+                        function_exists('disk_free_space') ? @disk_free_space(dirname($tempFileName)) : 'unknown'
                     );
 
                     $this->io->writeError($message);
@@ -184,8 +174,6 @@ class Cache
     /**
      * Copy a file into the cache
      *
-     * @param string $file
-     * @param string $source
      *
      * @return bool
      */
@@ -210,8 +198,6 @@ class Cache
     /**
      * Copy a file out of the cache
      *
-     * @param string $file
-     * @param string $target
      *
      * @return bool
      */
@@ -251,12 +237,14 @@ class Cache
             return false;
         }
 
+        if (Platform::isInputCompletionProcess()) {
+            return false;
+        }
+
         return !random_int(0, 50);
     }
 
     /**
-     * @param string $file
-     *
      * @return bool
      */
     public function remove(string $file)
@@ -286,7 +274,6 @@ class Cache
     }
 
     /**
-     * @param string $file
      * @return int|false
      * @phpstan-return int<0, max>|false
      */
@@ -303,9 +290,6 @@ class Cache
     }
 
     /**
-     * @param int $ttl
-     * @param int $maxSize
-     *
      * @return bool
      */
     public function gc(int $ttl, int $maxSize)
@@ -338,9 +322,26 @@ class Cache
         return false;
     }
 
+    public function gcVcsCache(int $ttl): bool
+    {
+        if ($this->isEnabled()) {
+            $expire = new \DateTime();
+            $expire->modify('-'.$ttl.' seconds');
+
+            $finder = Finder::create()->in($this->root)->directories()->depth(0)->date('until '.$expire->format('Y-m-d H:i:s'));
+            foreach ($finder as $file) {
+                $this->filesystem->removeDirectory($file->getPathname());
+            }
+
+            self::$cacheCollected = true;
+
+            return true;
+        }
+
+        return false;
+    }
+
     /**
-     * @param string $file
-     *
      * @return string|false
      */
     public function sha1(string $file)
@@ -356,8 +357,6 @@ class Cache
     }
 
     /**
-     * @param string $file
-     *
      * @return string|false
      */
     public function sha256(string $file)
