@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -26,6 +26,7 @@ use Composer\DependencyResolver\Operation\InstallOperation;
 use Composer\Package\Version\VersionSelector;
 use Composer\Package\AliasPackage;
 use Composer\Pcre\Preg;
+use Composer\Plugin\PluginBlockedException;
 use Composer\Repository\RepositoryFactory;
 use Composer\Repository\CompositeRepository;
 use Composer\Repository\PlatformRepository;
@@ -33,9 +34,10 @@ use Composer\Repository\InstalledArrayRepository;
 use Composer\Repository\RepositorySet;
 use Composer\Script\ScriptEvents;
 use Composer\Util\Silencer;
-use Symfony\Component\Console\Input\InputArgument;
+use Composer\Console\Input\InputArgument;
+use Seld\Signal\SignalHandler;
 use Symfony\Component\Console\Input\InputInterface;
-use Symfony\Component\Console\Input\InputOption;
+use Composer\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 use Symfony\Component\Finder\Finder;
 use Composer\Json\JsonFile;
@@ -44,6 +46,7 @@ use Composer\Util\Filesystem;
 use Composer\Util\Platform;
 use Composer\Util\ProcessExecutor;
 use Composer\Package\Version\VersionParser;
+use Composer\Advisory\Auditor;
 
 /**
  * Install a package as new project into new directory.
@@ -55,27 +58,26 @@ use Composer\Package\Version\VersionParser;
  */
 class CreateProjectCommand extends BaseCommand
 {
+    use CompletionTrait;
+
     /**
      * @var SuggestedPackagesReporter
      */
     protected $suggestedPackagesReporter;
 
-    /**
-     * @return void
-     */
-    protected function configure()
+    protected function configure(): void
     {
         $this
             ->setName('create-project')
-            ->setDescription('Creates new project from a package into given directory.')
-            ->setDefinition(array(
-                new InputArgument('package', InputArgument::OPTIONAL, 'Package name to be installed'),
+            ->setDescription('Creates new project from a package into given directory')
+            ->setDefinition([
+                new InputArgument('package', InputArgument::OPTIONAL, 'Package name to be installed', null, $this->suggestAvailablePackage()),
                 new InputArgument('directory', InputArgument::OPTIONAL, 'Directory where the files should be created'),
                 new InputArgument('version', InputArgument::OPTIONAL, 'Version, will default to latest'),
                 new InputOption('stability', 's', InputOption::VALUE_REQUIRED, 'Minimum-stability allowed (unless a version is specified).'),
                 new InputOption('prefer-source', null, InputOption::VALUE_NONE, 'Forces installation from package sources when possible, including VCS information.'),
                 new InputOption('prefer-dist', null, InputOption::VALUE_NONE, 'Forces installation from package dist (default behavior).'),
-                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).'),
+                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).', null, $this->suggestPreferInstall()),
                 new InputOption('repository', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Add custom repositories to look the package up, either by URL or using JSON arrays'),
                 new InputOption('repository-url', null, InputOption::VALUE_REQUIRED, 'DEPRECATED: Use --repository instead.'),
                 new InputOption('add-repository', null, InputOption::VALUE_NONE, 'Add the custom repository in the composer.json. If a lock file is present it will be deleted and an update will be run instead of install.'),
@@ -88,10 +90,12 @@ class CreateProjectCommand extends BaseCommand
                 new InputOption('keep-vcs', null, InputOption::VALUE_NONE, 'Whether to prevent deleting the vcs folder.'),
                 new InputOption('remove-vcs', null, InputOption::VALUE_NONE, 'Whether to force deletion of the vcs folder without prompting.'),
                 new InputOption('no-install', null, InputOption::VALUE_NONE, 'Whether to skip installation of the package dependencies.'),
+                new InputOption('no-audit', null, InputOption::VALUE_NONE, 'Whether to skip auditing of the installed package dependencies (can also be set via the COMPOSER_NO_AUDIT=1 env var).'),
+                new InputOption('audit-format', null, InputOption::VALUE_REQUIRED, 'Audit output format. Must be "table", "plain", "json" or "summary".', Auditor::FORMAT_SUMMARY, Auditor::FORMATS),
                 new InputOption('ignore-platform-req', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Ignore a specific platform requirement (php & ext- packages).'),
                 new InputOption('ignore-platform-reqs', null, InputOption::VALUE_NONE, 'Ignore all platform requirements (php & ext- packages).'),
                 new InputOption('ask', null, InputOption::VALUE_NONE, 'Whether to ask for project directory.'),
-            ))
+            ])
             ->setHelp(
                 <<<EOT
 The <info>create-project</info> command creates a new project from a given
@@ -122,15 +126,12 @@ EOT
         ;
     }
 
-    /**
-     * @return int
-     */
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $config = Factory::createConfig();
         $io = $this->getIO();
 
-        list($preferSource, $preferDist) = $this->getPreferredInstallOptions($config, $input, true);
+        [$preferSource, $preferDist] = $this->getPreferredInstallOptions($config, $input, true);
 
         if ($input->getOption('dev')) {
             $io->writeError('<warning>You are using the deprecated option "dev". Dev packages are installed by default now.</warning>');
@@ -141,12 +142,14 @@ EOT
         }
 
         if ($input->isInteractive() && $input->getOption('ask')) {
-            $parts = explode("/", strtolower($input->getArgument('package')), 2);
+            $package = $input->getArgument('package');
+            if (null === $package) {
+                throw new \RuntimeException('Not enough arguments (missing: "package").');
+            }
+            $parts = explode("/", strtolower($package), 2);
             $input->setArgument('directory', $io->ask('New project directory [<comment>'.array_pop($parts).'</comment>]: '));
         }
 
-        $ignorePlatformReqs = $input->getOption('ignore-platform-reqs') ?: ($input->getOption('ignore-platform-req') ?: false);
-
         return $this->installProject(
             $io,
             $config,
@@ -158,45 +161,31 @@ EOT
             $preferSource,
             $preferDist,
             !$input->getOption('no-dev'),
-            $input->getOption('repository') ?: $input->getOption('repository-url'),
+            \count($input->getOption('repository')) > 0 ? $input->getOption('repository') : $input->getOption('repository-url'),
             $input->getOption('no-plugins'),
             $input->getOption('no-scripts'),
             $input->getOption('no-progress'),
             $input->getOption('no-install'),
-            PlatformRequirementFilterFactory::fromBoolOrList($ignorePlatformReqs),
+            $this->getPlatformRequirementFilter($input),
             !$input->getOption('no-secure-http'),
             $input->getOption('add-repository')
         );
     }
 
     /**
-     * @param string|null               $packageName
-     * @param string|null               $directory
-     * @param string|null               $packageVersion
-     * @param string                    $stability
-     * @param bool                      $preferSource
-     * @param bool                      $preferDist
-     * @param bool                      $installDevPackages
      * @param string|array<string>|null $repositories
-     * @param bool                      $disablePlugins
-     * @param bool                      $disableScripts
-     * @param bool                      $noProgress
-     * @param bool                      $noInstall
-     * @param bool                      $secureHttp
-     * @param bool                      $addRepository
      *
-     * @return int
      * @throws \Exception
      */
-    public function installProject(IOInterface $io, Config $config, InputInterface $input, $packageName = null, $directory = null, $packageVersion = null, $stability = 'stable', $preferSource = false, $preferDist = false, $installDevPackages = false, $repositories = null, $disablePlugins = false, $disableScripts = false, $noProgress = false, $noInstall = false, PlatformRequirementFilterInterface $platformRequirementFilter = null, $secureHttp = true, $addRepository = false)
+    public function installProject(IOInterface $io, Config $config, InputInterface $input, ?string $packageName = null, ?string $directory = null, ?string $packageVersion = null, ?string $stability = 'stable', bool $preferSource = false, bool $preferDist = false, bool $installDevPackages = false, $repositories = null, bool $disablePlugins = false, bool $disableScripts = false, bool $noProgress = false, bool $noInstall = false, ?PlatformRequirementFilterInterface $platformRequirementFilter = null, bool $secureHttp = true, bool $addRepository = false): int
     {
-        $oldCwd = getcwd();
+        $oldCwd = Platform::getCwd();
 
         if ($repositories !== null && !is_array($repositories)) {
             $repositories = (array) $repositories;
         }
 
-        $platformRequirementFilter = $platformRequirementFilter ?: PlatformRequirementFilterFactory::ignoreNothing();
+        $platformRequirementFilter = $platformRequirementFilter ?? PlatformRequirementFilterFactory::ignoreNothing();
 
         // we need to manually load the configuration to pass the auth credentials to the io interface!
         $io->loadConfiguration($config);
@@ -224,8 +213,8 @@ EOT
                 $configSource = new JsonConfigSource(new JsonFile('composer.json'));
 
                 if (
-                    (isset($repoConfig['packagist']) && $repoConfig === array('packagist' => false))
-                    || (isset($repoConfig['packagist.org']) && $repoConfig === array('packagist.org' => false))
+                    (isset($repoConfig['packagist']) && $repoConfig === ['packagist' => false])
+                    || (isset($repoConfig['packagist.org']) && $repoConfig === ['packagist.org' => false])
                 ) {
                     $configSource->addRepository('packagist.org', false);
                 } else {
@@ -236,7 +225,7 @@ EOT
             }
         }
 
-        $process = new ProcessExecutor($io);
+        $process = $composer->getLoop()->getProcessExecutor();
         $fs = new Filesystem($process);
 
         // dispatch event
@@ -244,7 +233,7 @@ EOT
 
         // use the new config including the newly installed project
         $config = $composer->getConfig();
-        list($preferSource, $preferDist) = $this->getPreferredInstallOptions($config, $input);
+        [$preferSource, $preferDist] = $this->getPreferredInstallOptions($config, $input);
 
         // install dependencies of the created project
         if ($noInstall === false) {
@@ -258,7 +247,9 @@ EOT
                 ->setSuggestedPackagesReporter($this->suggestedPackagesReporter)
                 ->setOptimizeAutoloader($config->get('optimize-autoloader'))
                 ->setClassMapAuthoritative($config->get('classmap-authoritative'))
-                ->setApcuAutoloader($config->get('apcu-autoloader'));
+                ->setApcuAutoloader($config->get('apcu-autoloader'))
+                ->setAudit(!$input->getOption('no-audit'))
+                ->setAuditFormat($this->getAuditFormat($input));
 
             if (!$composer->getLocker()->isLocked()) {
                 $installer->setUpdate(true);
@@ -268,9 +259,15 @@ EOT
                 $installer->disablePlugins();
             }
 
-            $status = $installer->run();
-            if (0 !== $status) {
-                return $status;
+            try {
+                $status = $installer->run();
+                if (0 !== $status) {
+                    return $status;
+                }
+            } catch (PluginBlockedException $e) {
+                $io->writeError('<error>Hint: To allow running the config command recommended below before dependencies are installed, run create-project with --no-install.</error>');
+                $io->writeError('<error>You can then cd into '.getcwd().', configure allow-plugins, and finally run a composer install to complete the process.</error>');
+                throw $e;
             }
         }
 
@@ -285,8 +282,8 @@ EOT
             )
         ) {
             $finder = new Finder();
-            $finder->depth(0)->directories()->in(getcwd())->ignoreVCS(false)->ignoreDotFiles(false);
-            foreach (array('.svn', '_svn', 'CVS', '_darcs', '.arch-params', '.monotone', '.bzr', '.git', '.hg', '.fslckout', '_FOSSIL_') as $vcsName) {
+            $finder->depth(0)->directories()->in(Platform::getCwd())->ignoreVCS(false)->ignoreDotFiles(false);
+            foreach (['.svn', '_svn', 'CVS', '_darcs', '.arch-params', '.monotone', '.bzr', '.git', '.hg', '.fslckout', '_FOSSIL_'] as $vcsName) {
                 $finder->name($vcsName);
             }
 
@@ -294,7 +291,7 @@ EOT
                 $dirs = iterator_to_array($finder);
                 unset($finder);
                 foreach ($dirs as $dir) {
-                    if (!$fs->removeDirectory($dir)) {
+                    if (!$fs->removeDirectory((string) $dir)) {
                         throw new \RuntimeException('Could not remove '.$dir);
                     }
                 }
@@ -335,30 +332,18 @@ EOT
     }
 
     /**
-     * @param string             $packageName
-     * @param string|null        $directory
-     * @param string|null        $packageVersion
-     * @param string|null        $stability
-     * @param bool               $preferSource
-     * @param bool               $preferDist
-     * @param bool               $installDevPackages
      * @param array<string>|null $repositories
-     * @param bool               $disablePlugins
-     * @param bool               $disableScripts
-     * @param bool               $noProgress
-     * @param bool               $secureHttp
      *
-     * @return bool
      * @throws \Exception
      */
-    protected function installRootPackage(IOInterface $io, Config $config, $packageName, PlatformRequirementFilterInterface $platformRequirementFilter, $directory = null, $packageVersion = null, $stability = 'stable', $preferSource = false, $preferDist = false, $installDevPackages = false, array $repositories = null, $disablePlugins = false, $disableScripts = false, $noProgress = false, $secureHttp = true)
+    protected function installRootPackage(IOInterface $io, Config $config, string $packageName, PlatformRequirementFilterInterface $platformRequirementFilter, ?string $directory = null, ?string $packageVersion = null, ?string $stability = 'stable', bool $preferSource = false, bool $preferDist = false, bool $installDevPackages = false, ?array $repositories = null, bool $disablePlugins = false, bool $disableScripts = false, bool $noProgress = false, bool $secureHttp = true): bool
     {
         if (!$secureHttp) {
-            $config->merge(array('config' => array('secure-http' => false)), Config::SOURCE_COMMAND);
+            $config->merge(['config' => ['secure-http' => false]], Config::SOURCE_COMMAND);
         }
 
         $parser = new VersionParser();
-        $requirements = $parser->parseNameVersionPairs(array($packageName));
+        $requirements = $parser->parseNameVersionPairs([$packageName]);
         $name = strtolower($requirements[0]['name']);
         if (!$packageVersion && isset($requirements[0]['version'])) {
             $packageVersion = $requirements[0]['version'];
@@ -367,16 +352,16 @@ EOT
         // if no directory was specified, use the 2nd part of the package name
         if (null === $directory) {
             $parts = explode("/", $name, 2);
-            $directory = getcwd() . DIRECTORY_SEPARATOR . array_pop($parts);
+            $directory = Platform::getCwd() . DIRECTORY_SEPARATOR . array_pop($parts);
         }
 
         $process = new ProcessExecutor($io);
         $fs = new Filesystem($process);
         if (!$fs->isAbsolutePath($directory)) {
-            $directory = getcwd() . DIRECTORY_SEPARATOR . $directory;
+            $directory = Platform::getCwd() . DIRECTORY_SEPARATOR . $directory;
         }
 
-        $io->writeError('<info>Creating a "' . $packageName . '" project at "' . $fs->findShortestPath(getcwd(), $directory, true) . '"</info>');
+        $io->writeError('<info>Creating a "' . $packageName . '" project at "' . $fs->findShortestPath(Platform::getCwd(), $directory, true) . '"</info>');
 
         if (file_exists($directory)) {
             if (!is_dir($directory)) {
@@ -403,7 +388,7 @@ EOT
             throw new \InvalidArgumentException('Invalid stability provided ('.$stability.'), must be one of: '.implode(', ', array_keys(BasePackage::$stabilities)));
         }
 
-        $composer = Factory::create($io, $config->all(), $disablePlugins);
+        $composer = Factory::create($io, $config->all(), $disablePlugins, $disableScripts);
         $config = $composer->getConfig();
         $rm = $composer->getRepositoryManager();
 
@@ -414,8 +399,8 @@ EOT
             foreach ($repositories as $repo) {
                 $repoConfig = RepositoryFactory::configFromString($io, $config, $repo, true);
                 if (
-                    (isset($repoConfig['packagist']) && $repoConfig === array('packagist' => false))
-                    || (isset($repoConfig['packagist.org']) && $repoConfig === array('packagist.org' => false))
+                    (isset($repoConfig['packagist']) && $repoConfig === ['packagist' => false])
+                    || (isset($repoConfig['packagist.org']) && $repoConfig === ['packagist.org' => false])
                 ) {
                     continue;
                 }
@@ -423,12 +408,12 @@ EOT
             }
         }
 
-        $platformOverrides = $config->get('platform') ?: array();
-        $platformRepo = new PlatformRepository(array(), $platformOverrides);
+        $platformOverrides = $config->get('platform');
+        $platformRepo = new PlatformRepository([], $platformOverrides);
 
         // find the latest version if there are multiple
         $versionSelector = new VersionSelector($repositorySet, $platformRepo);
-        $package = $versionSelector->findBestCandidate($name, $packageVersion, $stability, $platformRequirementFilter);
+        $package = $versionSelector->findBestCandidate($name, $packageVersion, $stability, $platformRequirementFilter, 0, $io);
 
         if (!$package) {
             $errorMessage = "Could not find package $name with " . ($packageVersion ? "version $packageVersion" : "stability $stability");
@@ -439,28 +424,15 @@ EOT
             throw new \InvalidArgumentException($errorMessage .'.');
         }
 
-        // handler Ctrl+C for unix-like systems
-        if (function_exists('pcntl_async_signals') && function_exists('pcntl_signal')) {
-            @mkdir($directory, 0777, true);
-            if ($realDir = realpath($directory)) {
-                pcntl_async_signals(true);
-                pcntl_signal(SIGINT, function () use ($realDir) {
-                    $fs = new Filesystem();
-                    $fs->removeDirectory($realDir);
-                    exit(130);
-                });
-            }
-        }
-        // handler Ctrl+C for Windows on PHP 7.4+
-        if (function_exists('sapi_windows_set_ctrl_handler') && PHP_SAPI === 'cli') {
-            @mkdir($directory, 0777, true);
-            if ($realDir = realpath($directory)) {
-                sapi_windows_set_ctrl_handler(function () use ($realDir) {
-                    $fs = new Filesystem();
-                    $fs->removeDirectory($realDir);
-                    exit(130);
-                });
-            }
+        // handler Ctrl+C aborts gracefully
+        @mkdir($directory, 0777, true);
+        if (false !== ($realDir = realpath($directory))) {
+            $signalHandler = SignalHandler::create([SignalHandler::SIGINT, SignalHandler::SIGTERM, SignalHandler::SIGHUP], function (string $signal, SignalHandler $handler) use ($realDir) {
+                $this->getIO()->writeError('Received '.$signal.', aborting', true, IOInterface::DEBUG);
+                $fs = new Filesystem();
+                $fs->removeDirectory($realDir);
+                $handler->exitWithLastSignal();
+            });
         }
 
         // avoid displaying 9999999-dev as version if default-branch was selected
@@ -486,7 +458,7 @@ EOT
         $im = $composer->getInstallationManager();
         $im->setOutputProgress(!$noProgress);
         $im->addInstaller($projectInstaller);
-        $im->execute(new InstalledArrayRepository(), array(new InstallOperation($package)));
+        $im->execute(new InstalledArrayRepository(), [new InstallOperation($package)]);
         $im->notifyInstalls($io);
 
         // collect suggestions
@@ -499,6 +471,11 @@ EOT
 
         Platform::putEnv('COMPOSER_ROOT_VERSION', $package->getPrettyVersion());
 
+        // once the root project is fully initialized, we do not need to wipe everything on user abort anymore even if it happens during deps install
+        if (isset($signalHandler)) {
+            $signalHandler->unregister();
+        }
+
         return $installedFromVcs;
     }
 }
