@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,11 +13,13 @@
 namespace Composer\Command;
 
 use Composer\DependencyResolver\Request;
-use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterFactory;
+use Composer\Package\CompletePackageInterface;
 use Composer\Util\Filesystem;
+use Composer\Util\PackageSorter;
+use Seld\Signal\SignalHandler;
 use Symfony\Component\Console\Input\InputInterface;
-use Symfony\Component\Console\Input\InputArgument;
-use Symfony\Component\Console\Input\InputOption;
+use Composer\Console\Input\InputArgument;
+use Composer\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 use Composer\Factory;
 use Composer\Installer;
@@ -32,14 +34,18 @@ use Composer\Plugin\PluginEvents;
 use Composer\Repository\CompositeRepository;
 use Composer\Repository\PlatformRepository;
 use Composer\IO\IOInterface;
+use Composer\Advisory\Auditor;
 use Composer\Util\Silencer;
 
 /**
  * @author Jérémy Romey <jeremy@free-agent.fr>
  * @author Jordi Boggiano <j.boggiano@seld.be>
  */
-class RequireCommand extends InitCommand
+class RequireCommand extends BaseCommand
 {
+    use CompletionTrait;
+    use PackageDiscoveryTrait;
+
     /** @var bool */
     private $newlyCreated;
     /** @var bool */
@@ -64,19 +70,22 @@ class RequireCommand extends InitCommand
     {
         $this
             ->setName('require')
-            ->setDescription('Adds required packages to your composer.json and installs them.')
-            ->setDefinition(array(
-                new InputArgument('packages', InputArgument::IS_ARRAY | InputArgument::OPTIONAL, 'Optional package name can also include a version constraint, e.g. foo/bar or foo/bar:1.0.0 or foo/bar=1.0.0 or "foo/bar 1.0.0"'),
+            ->setAliases(['r'])
+            ->setDescription('Adds required packages to your composer.json and installs them')
+            ->setDefinition([
+                new InputArgument('packages', InputArgument::IS_ARRAY | InputArgument::OPTIONAL, 'Optional package name can also include a version constraint, e.g. foo/bar or foo/bar:1.0.0 or foo/bar=1.0.0 or "foo/bar 1.0.0"', null, $this->suggestAvailablePackageInclPlatform()),
                 new InputOption('dev', null, InputOption::VALUE_NONE, 'Add requirement to require-dev.'),
                 new InputOption('dry-run', null, InputOption::VALUE_NONE, 'Outputs the operations but will not execute anything (implicitly enables --verbose).'),
                 new InputOption('prefer-source', null, InputOption::VALUE_NONE, 'Forces installation from package sources when possible, including VCS information.'),
                 new InputOption('prefer-dist', null, InputOption::VALUE_NONE, 'Forces installation from package dist (default behavior).'),
-                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).'),
+                new InputOption('prefer-install', null, InputOption::VALUE_REQUIRED, 'Forces installation from package dist|source|auto (auto chooses source for dev versions, dist for the rest).', null, $this->suggestPreferInstall()),
                 new InputOption('fixed', null, InputOption::VALUE_NONE, 'Write fixed version to the composer.json.'),
                 new InputOption('no-suggest', null, InputOption::VALUE_NONE, 'DEPRECATED: This flag does not exist anymore.'),
                 new InputOption('no-progress', null, InputOption::VALUE_NONE, 'Do not output download progress.'),
                 new InputOption('no-update', null, InputOption::VALUE_NONE, 'Disables the automatic update of the dependencies (implies --no-install).'),
                 new InputOption('no-install', null, InputOption::VALUE_NONE, 'Skip the install step after updating the composer.lock file.'),
+                new InputOption('no-audit', null, InputOption::VALUE_NONE, 'Skip the audit step after updating the composer.lock file (can also be set via the COMPOSER_NO_AUDIT=1 env var).'),
+                new InputOption('audit-format', null, InputOption::VALUE_REQUIRED, 'Audit output format. Must be "table", "plain", "json", or "summary".', Auditor::FORMAT_SUMMARY, Auditor::FORMATS),
                 new InputOption('update-no-dev', null, InputOption::VALUE_NONE, 'Run the dependency update with the --no-dev option.'),
                 new InputOption('update-with-dependencies', 'w', InputOption::VALUE_NONE, 'Allows inherited dependencies to be updated, except those that are root requirements.'),
                 new InputOption('update-with-all-dependencies', 'W', InputOption::VALUE_NONE, 'Allows all inherited dependencies to be updated, including those that are root requirements.'),
@@ -84,14 +93,14 @@ class RequireCommand extends InitCommand
                 new InputOption('with-all-dependencies', null, InputOption::VALUE_NONE, 'Alias for --update-with-all-dependencies'),
                 new InputOption('ignore-platform-req', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Ignore a specific platform requirement (php & ext- packages).'),
                 new InputOption('ignore-platform-reqs', null, InputOption::VALUE_NONE, 'Ignore all platform requirements (php & ext- packages).'),
-                new InputOption('prefer-stable', null, InputOption::VALUE_NONE, 'Prefer stable versions of dependencies.'),
-                new InputOption('prefer-lowest', null, InputOption::VALUE_NONE, 'Prefer lowest versions of dependencies.'),
+                new InputOption('prefer-stable', null, InputOption::VALUE_NONE, 'Prefer stable versions of dependencies (can also be set via the COMPOSER_PREFER_STABLE=1 env var).'),
+                new InputOption('prefer-lowest', null, InputOption::VALUE_NONE, 'Prefer lowest versions of dependencies (can also be set via the COMPOSER_PREFER_LOWEST=1 env var).'),
                 new InputOption('sort-packages', null, InputOption::VALUE_NONE, 'Sorts packages when adding/updating a new dependency'),
                 new InputOption('optimize-autoloader', 'o', InputOption::VALUE_NONE, 'Optimize autoloader during autoloader dump'),
                 new InputOption('classmap-authoritative', 'a', InputOption::VALUE_NONE, 'Autoload classes from the classmap only. Implicitly enables `--optimize-autoloader`.'),
                 new InputOption('apcu-autoloader', null, InputOption::VALUE_NONE, 'Use APCu to cache found/not-found classes.'),
                 new InputOption('apcu-autoloader-prefix', null, InputOption::VALUE_REQUIRED, 'Use a custom prefix for the APCu autoloader cache. Implicitly enables --apcu-autoloader'),
-            ))
+            ])
             ->setHelp(
                 <<<EOT
 The require command adds required packages to your composer.json and installs them.
@@ -110,18 +119,10 @@ EOT
     }
 
     /**
-     * @return int
      * @throws \Seld\JsonLint\ParsingException
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
-        if (function_exists('pcntl_async_signals') && function_exists('pcntl_signal')) {
-            pcntl_async_signals(true);
-            pcntl_signal(SIGINT, array($this, 'revertComposerFile'));
-            pcntl_signal(SIGTERM, array($this, 'revertComposerFile'));
-            pcntl_signal(SIGHUP, array($this, 'revertComposerFile'));
-        }
-
         $this->file = Factory::getComposerFile();
         $io = $this->getIO();
 
@@ -150,9 +151,15 @@ EOT
         $this->composerBackup = file_get_contents($this->json->getPath());
         $this->lockBackup = file_exists($this->lock) ? file_get_contents($this->lock) : null;
 
+        $signalHandler = SignalHandler::create([SignalHandler::SIGINT, SignalHandler::SIGTERM, SignalHandler::SIGHUP], function (string $signal, SignalHandler $handler) {
+            $this->getIO()->writeError('Received '.$signal.', aborting', true, IOInterface::DEBUG);
+            $this->revertComposerFile();
+            $handler->exitWithLastSignal();
+        });
+
         // check for writability by writing to the file as is_writable can not be trusted on network-mounts
         // see https://github.com/composer/composer/issues/8231 and https://bugs.php.net/bug.php?id=68926
-        if (!is_writable($this->file) && !Silencer::call('file_put_contents', $this->file, $this->composerBackup)) {
+        if (!is_writable($this->file) && false === Silencer::call('file_put_contents', $this->file, $this->composerBackup)) {
             $io->writeError('<error>'.$this->file.' is not writable.</error>');
 
             return 1;
@@ -167,23 +174,23 @@ EOT
              * @see https://github.com/composer/composer/pull/8313#issuecomment-532637955
              */
             if ($packageType !== 'project') {
-                $io->writeError('<error>"--fixed" option is allowed for "project" package types only to prevent possible misuses.</error>');
+                $io->writeError('<error>The "--fixed" option is only allowed for packages with a "project" type to prevent possible misuses.</error>');
 
-                if (empty($config['type'])) {
-                    $io->writeError('<error>If your package is not library, you should explicitly specify "type" parameter in composer.json.</error>');
+                if (!isset($config['type'])) {
+                    $io->writeError('<error>If your package is not a library, you can explicitly specify the "type" by using "composer config type project".</error>');
                 }
 
                 return 1;
             }
         }
 
-        $composer = $this->getComposer(true, $input->getOption('no-plugins'));
+        $composer = $this->requireComposer();
         $repos = $composer->getRepositoryManager()->getRepositories();
 
-        $platformOverrides = $composer->getConfig()->get('platform') ?: array();
-        // initialize $this->repos as it is used by the parent InitCommand
+        $platformOverrides = $composer->getConfig()->get('platform');
+        // initialize $this->repos as it is used by the PackageDiscoveryTrait
         $this->repos = new CompositeRepository(array_merge(
-            array($platformRepo = new PlatformRepository(array(), $platformOverrides)),
+            [$platformRepo = new PlatformRepository([], $platformOverrides)],
             $repos
         ));
 
@@ -205,7 +212,7 @@ EOT
             );
         } catch (\Exception $e) {
             if ($this->newlyCreated) {
-                $this->revertComposerFile(false);
+                $this->revertComposerFile();
 
                 throw new \RuntimeException('No composer.json present in the current directory ('.$this->file.'), this may be the cause of the following exception.', 0, $e);
             }
@@ -213,9 +220,36 @@ EOT
             throw $e;
         }
 
+        $requirements = $this->formatRequirements($requirements);
+
+        if (!$input->getOption('dev') && $io->isInteractive()) {
+            $devPackages = [];
+            $devTags = ['dev', 'testing', 'static analysis'];
+            $currentRequiresByKey = $this->getPackagesByRequireKey();
+            foreach ($requirements as $name => $version) {
+                // skip packages which are already in the composer.json as those have already been decided
+                if (isset($currentRequiresByKey[$name])) {
+                    continue;
+                }
+
+                $pkg = PackageSorter::getMostCurrentVersion($this->getRepos()->findPackages($name));
+                if ($pkg instanceof CompletePackageInterface && count(array_intersect($devTags, array_map('strtolower', $pkg->getKeywords()))) > 0) {
+                    $devPackages[] = $name;
+                }
+            }
+
+            if (count($devPackages) === count($requirements)) {
+                $plural = count($requirements) > 1 ? 's' : '';
+                $plural2 = count($requirements) > 1 ? 'are' : 'is';
+                $io->warning('The package'.$plural.' you required '.$plural2.' recommended to be placed in require-dev but you did not use --dev.');
+                if ($io->askConfirmation('<info>Do you want to re-run the command with --dev?</> [<comment>yes</>]? ')) {
+                    $input->setOption('dev', true);
+                }
+            }
+        }
+
         $requireKey = $input->getOption('dev') ? 'require-dev' : 'require';
         $removeKey = $input->getOption('dev') ? 'require' : 'require-dev';
-        $requirements = $this->formatRequirements($requirements);
 
         // validate requirements format
         $versionParser = new VersionParser();
@@ -225,6 +259,9 @@ EOT
 
                 return 1;
             }
+            if ($constraint === 'self.version') {
+                continue;
+            }
             $versionParser->parseConstraints($constraint);
         }
 
@@ -232,7 +269,7 @@ EOT
         if (count($inconsistentRequireKeys) > 0) {
             foreach ($inconsistentRequireKeys as $package) {
                 $io->warning(sprintf(
-                    '%s is currently present in the %s key and you ran the command %s the --dev flag, which would move it to the %s key.',
+                    '%s is currently present in the %s key and you ran the command %s the --dev flag, which will move it to the %s key.',
                     $package,
                     $removeKey,
                     $input->getOption('dev') ? 'with' : 'without',
@@ -246,7 +283,8 @@ EOT
                         return 0;
                     }
 
-                    list($requireKey, $removeKey) = array($removeKey, $requireKey);
+                    $input->setOption('dev', true);
+                    [$requireKey, $removeKey] = [$removeKey, $requireKey];
                 }
             }
         }
@@ -256,7 +294,7 @@ EOT
         $this->firstRequire = $this->newlyCreated;
         if (!$this->firstRequire) {
             $composerDefinition = $this->json->read();
-            if (empty($composerDefinition['require']) && empty($composerDefinition['require-dev'])) {
+            if (count($composerDefinition['require'] ?? []) === 0 && count($composerDefinition['require-dev'] ?? []) === 0) {
                 $this->firstRequire = true;
             }
         }
@@ -285,21 +323,22 @@ EOT
             return $this->doUpdate($input, $output, $io, $requirements, $requireKey, $removeKey);
         } catch (\Exception $e) {
             if (!$this->dependencyResolutionCompleted) {
-                $this->revertComposerFile(false);
+                $this->revertComposerFile();
             }
             throw $e;
+        } finally {
+            $signalHandler->unregister();
         }
     }
 
     /**
      * @param array<string, string> $newRequirements
-     * @param string $requireKey
      * @return string[]
      */
-    private function getInconsistentRequireKeys(array $newRequirements, $requireKey)
+    private function getInconsistentRequireKeys(array $newRequirements, string $requireKey): array
     {
         $requireKeys = $this->getPackagesByRequireKey();
-        $inconsistentRequirements = array();
+        $inconsistentRequirements = [];
         foreach ($requireKeys as $package => $packageRequireKey) {
             if (!isset($newRequirements[$package])) {
                 continue;
@@ -315,11 +354,11 @@ EOT
     /**
      * @return array<string, string>
      */
-    private function getPackagesByRequireKey()
+    private function getPackagesByRequireKey(): array
     {
         $composerDefinition = $this->json->read();
-        $require = array();
-        $requireDev = array();
+        $require = [];
+        $requireDev = [];
 
         if (isset($composerDefinition['require'])) {
             $require = $composerDefinition['require'];
@@ -335,37 +374,27 @@ EOT
         );
     }
 
-    /**
-     * @private
-     * @return void
-     */
-    public function markSolverComplete()
-    {
-        $this->dependencyResolutionCompleted = true;
-    }
-
     /**
      * @param array<string, string> $requirements
-     * @param string $requireKey
-     * @param string $removeKey
-     * @return int
      * @throws \Exception
      */
-    private function doUpdate(InputInterface $input, OutputInterface $output, IOInterface $io, array $requirements, $requireKey, $removeKey)
+    private function doUpdate(InputInterface $input, OutputInterface $output, IOInterface $io, array $requirements, string $requireKey, string $removeKey): int
     {
         // Update packages
         $this->resetComposer();
-        $composer = $this->getComposer(true, $input->getOption('no-plugins'), $input->getOption('no-scripts'));
+        $composer = $this->requireComposer();
 
         $this->dependencyResolutionCompleted = false;
-        $composer->getEventDispatcher()->addListener(InstallerEvents::PRE_OPERATIONS_EXEC, array($this, 'markSolverComplete'), 10000);
+        $composer->getEventDispatcher()->addListener(InstallerEvents::PRE_OPERATIONS_EXEC, function (): void {
+            $this->dependencyResolutionCompleted = true;
+        }, 10000);
 
         if ($input->getOption('dry-run')) {
             $rootPackage = $composer->getPackage();
-            $links = array(
+            $links = [
                 'require' => $rootPackage->getRequires(),
                 'require-dev' => $rootPackage->getDevRequires(),
-            );
+            ];
             $loader = new ArrayLoader();
             $newLinks = $loader->parseLinks($rootPackage->getName(), $rootPackage->getPrettyVersion(), BasePackage::$supportedLinkTypes[$requireKey]['method'], $requirements);
             $links[$requireKey] = array_merge($links[$requireKey], $newLinks);
@@ -401,8 +430,7 @@ EOT
 
         $install = Installer::create($io, $composer);
 
-        $ignorePlatformReqs = $input->getOption('ignore-platform-reqs') ?: ($input->getOption('ignore-platform-req') ?: false);
-        list($preferSource, $preferDist) = $this->getPreferredInstallOptions($composer->getConfig(), $input);
+        [$preferSource, $preferDist] = $this->getPreferredInstallOptions($composer->getConfig(), $input);
 
         $install
             ->setDryRun($input->getOption('dry-run'))
@@ -416,9 +444,11 @@ EOT
             ->setUpdate(true)
             ->setInstall(!$input->getOption('no-install'))
             ->setUpdateAllowTransitiveDependencies($updateAllowTransitiveDependencies)
-            ->setPlatformRequirementFilter(PlatformRequirementFilterFactory::fromBoolOrList($ignorePlatformReqs))
+            ->setPlatformRequirementFilter($this->getPlatformRequirementFilter($input))
             ->setPreferStable($input->getOption('prefer-stable'))
             ->setPreferLowest($input->getOption('prefer-lowest'))
+            ->setAudit(!$input->getOption('no-audit'))
+            ->setAuditFormat($this->getAuditFormat($input))
         ;
 
         // if no lock is present, or the file is brand new, we do not do a
@@ -437,7 +467,7 @@ EOT
                     }
                 }
             }
-            $this->revertComposerFile(false);
+            $this->revertComposerFile();
         }
 
         return $status;
@@ -445,12 +475,8 @@ EOT
 
     /**
      * @param array<string, string> $new
-     * @param string $requireKey
-     * @param string $removeKey
-     * @param bool $sortPackages
-     * @return bool
      */
-    private function updateFileCleanly(JsonFile $json, array $new, $requireKey, $removeKey, $sortPackages)
+    private function updateFileCleanly(JsonFile $json, array $new, string $requireKey, string $removeKey, bool $sortPackages): bool
     {
         $contents = file_get_contents($json->getPath());
 
@@ -472,16 +498,11 @@ EOT
         return true;
     }
 
-    protected function interact(InputInterface $input, OutputInterface $output)
+    protected function interact(InputInterface $input, OutputInterface $output): void
     {
-        return;
     }
 
-    /**
-     * @param bool $hardExit
-     * @return void
-     */
-    public function revertComposerFile($hardExit = true)
+    private function revertComposerFile(): void
     {
         $io = $this->getIO();
 
@@ -502,9 +523,5 @@ EOT
                 file_put_contents($this->lock, $this->lockBackup);
             }
         }
-
-        if ($hardExit) {
-            exit(1);
-        }
     }
 }
