@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -16,32 +16,38 @@ namespace Composer\DependencyResolver;
  * Stores decisions on installing, removing or keeping packages
  *
  * @author Nils Adermann <naderman@naderman.de>
+ * @implements \Iterator<array{0: int, 1: Rule}>
  */
 class Decisions implements \Iterator, \Countable
 {
-    const DECISION_LITERAL = 0;
-    const DECISION_REASON = 1;
+    public const DECISION_LITERAL = 0;
+    public const DECISION_REASON = 1;
 
+    /** @var Pool */
     protected $pool;
+    /** @var array<int, int> */
     protected $decisionMap;
-    protected $decisionQueue = array();
+    /**
+     * @var array<array{0: int, 1: Rule}>
+     */
+    protected $decisionQueue = [];
 
-    public function __construct($pool)
+    public function __construct(Pool $pool)
     {
         $this->pool = $pool;
-        $this->decisionMap = array();
+        $this->decisionMap = [];
     }
 
-    public function decide($literal, $level, $why)
+    public function decide(int $literal, int $level, Rule $why): void
     {
         $this->addDecision($literal, $level);
-        $this->decisionQueue[] = array(
+        $this->decisionQueue[] = [
             self::DECISION_LITERAL => $literal,
             self::DECISION_REASON => $why,
-        );
+        ];
     }
 
-    public function satisfy($literal)
+    public function satisfy(int $literal): bool
     {
         $packageId = abs($literal);
 
@@ -51,7 +57,7 @@ class Decisions implements \Iterator, \Countable
         );
     }
 
-    public function conflict($literal)
+    public function conflict(int $literal): bool
     {
         $packageId = abs($literal);
 
@@ -61,24 +67,24 @@ class Decisions implements \Iterator, \Countable
         );
     }
 
-    public function decided($literalOrPackageId)
+    public function decided(int $literalOrPackageId): bool
     {
         return !empty($this->decisionMap[abs($literalOrPackageId)]);
     }
 
-    public function undecided($literalOrPackageId)
+    public function undecided(int $literalOrPackageId): bool
     {
         return empty($this->decisionMap[abs($literalOrPackageId)]);
     }
 
-    public function decidedInstall($literalOrPackageId)
+    public function decidedInstall(int $literalOrPackageId): bool
     {
         $packageId = abs($literalOrPackageId);
 
         return isset($this->decisionMap[$packageId]) && $this->decisionMap[$packageId] > 0;
     }
 
-    public function decisionLevel($literalOrPackageId)
+    public function decisionLevel(int $literalOrPackageId): int
     {
         $packageId = abs($literalOrPackageId);
         if (isset($this->decisionMap[$packageId])) {
@@ -88,11 +94,11 @@ class Decisions implements \Iterator, \Countable
         return 0;
     }
 
-    public function decisionRule($literalOrPackageId)
+    public function decisionRule(int $literalOrPackageId): ?Rule
     {
         $packageId = abs($literalOrPackageId);
 
-        foreach ($this->decisionQueue as $i => $decision) {
+        foreach ($this->decisionQueue as $decision) {
             if ($packageId === abs($decision[self::DECISION_LITERAL])) {
                 return $decision[self::DECISION_REASON];
             }
@@ -101,34 +107,37 @@ class Decisions implements \Iterator, \Countable
         return null;
     }
 
-    public function atOffset($queueOffset)
+    /**
+     * @return array{0: int, 1: Rule} a literal and decision reason
+     */
+    public function atOffset(int $queueOffset): array
     {
         return $this->decisionQueue[$queueOffset];
     }
 
-    public function validOffset($queueOffset)
+    public function validOffset(int $queueOffset): bool
     {
         return $queueOffset >= 0 && $queueOffset < \count($this->decisionQueue);
     }
 
-    public function lastReason()
+    public function lastReason(): Rule
     {
         return $this->decisionQueue[\count($this->decisionQueue) - 1][self::DECISION_REASON];
     }
 
-    public function lastLiteral()
+    public function lastLiteral(): int
     {
         return $this->decisionQueue[\count($this->decisionQueue) - 1][self::DECISION_LITERAL];
     }
 
-    public function reset()
+    public function reset(): void
     {
         while ($decision = array_pop($this->decisionQueue)) {
             $this->decisionMap[abs($decision[self::DECISION_LITERAL])] = 0;
         }
     }
 
-    public function resetToOffset($offset)
+    public function resetToOffset(int $offset): void
     {
         while (\count($this->decisionQueue) > $offset + 1) {
             $decision = array_pop($this->decisionQueue);
@@ -136,57 +145,61 @@ class Decisions implements \Iterator, \Countable
         }
     }
 
-    public function revertLast()
+    public function revertLast(): void
     {
         $this->decisionMap[abs($this->lastLiteral())] = 0;
         array_pop($this->decisionQueue);
     }
 
-    public function count()
+    public function count(): int
     {
         return \count($this->decisionQueue);
     }
 
-    public function rewind()
+    public function rewind(): void
     {
         end($this->decisionQueue);
     }
 
+    /**
+     * @return array{0: int, 1: Rule}|false
+     */
+    #[\ReturnTypeWillChange]
     public function current()
     {
         return current($this->decisionQueue);
     }
 
-    public function key()
+    public function key(): ?int
     {
         return key($this->decisionQueue);
     }
 
-    public function next()
+    public function next(): void
     {
-        return prev($this->decisionQueue);
+        prev($this->decisionQueue);
     }
 
-    public function valid()
+    public function valid(): bool
     {
         return false !== current($this->decisionQueue);
     }
 
-    public function isEmpty()
+    public function isEmpty(): bool
     {
         return \count($this->decisionQueue) === 0;
     }
 
-    protected function addDecision($literal, $level)
+    protected function addDecision(int $literal, int $level): void
     {
         $packageId = abs($literal);
 
-        $previousDecision = isset($this->decisionMap[$packageId]) ? $this->decisionMap[$packageId] : null;
-        if ($previousDecision != 0) {
-            $literalString = $this->pool->literalToPrettyString($literal, array());
+        $previousDecision = $this->decisionMap[$packageId] ?? 0;
+        if ($previousDecision !== 0) {
+            $literalString = $this->pool->literalToPrettyString($literal, []);
             $package = $this->pool->literalToPackage($literal);
             throw new SolverBugException(
-                "Trying to decide $literalString on level $level, even though $package was previously decided as ".(int) $previousDecision."."
+                "Trying to decide $literalString on level $level, even though $package was previously decided as ".$previousDecision."."
             );
         }
 
@@ -197,7 +210,7 @@ class Decisions implements \Iterator, \Countable
         }
     }
 
-    public function toString(Pool $pool = null)
+    public function toString(?Pool $pool = null): string
     {
         $decisionMap = $this->decisionMap;
         ksort($decisionMap);
@@ -210,7 +223,7 @@ class Decisions implements \Iterator, \Countable
         return $str;
     }
 
-    public function __toString()
+    public function __toString(): string
     {
         return $this->toString();
     }
