@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -23,8 +23,8 @@ use Composer\Package\BasePackage;
  */
 class Solver
 {
-    const BRANCH_LITERALS = 0;
-    const BRANCH_LEVEL = 1;
+    private const BRANCH_LITERALS = 0;
+    private const BRANCH_LEVEL = 1;
 
     /** @var PolicyInterface */
     protected $policy;
@@ -44,13 +44,13 @@ class Solver
     /** @var int */
     protected $propagateIndex;
     /** @var mixed[] */
-    protected $branches = array();
+    protected $branches = [];
     /** @var Problem[] */
-    protected $problems = array();
+    protected $problems = [];
     /** @var array<Rule[]> */
-    protected $learnedPool = array();
+    protected $learnedPool = [];
     /** @var array<string, int> */
-    protected $learnedWhy = array();
+    protected $learnedWhy = [];
 
     /** @var bool */
     public $testFlagLearnedPositiveLiteral = false;
@@ -65,28 +65,19 @@ class Solver
         $this->pool = $pool;
     }
 
-    /**
-     * @return int
-     */
-    public function getRuleSetSize()
+    public function getRuleSetSize(): int
     {
         return \count($this->rules);
     }
 
-    /**
-     * @return Pool
-     */
-    public function getPool()
+    public function getPool(): Pool
     {
         return $this->pool;
     }
 
     // aka solver_makeruledecisions
 
-    /**
-     * @return void
-     */
-    private function makeAssertionRuleDecisions()
+    private function makeAssertionRuleDecisions(): void
     {
         $decisionStart = \count($this->decisions) - 1;
 
@@ -156,21 +147,15 @@ class Solver
         }
     }
 
-    /**
-     * @return void
-     */
-    protected function setupFixedMap(Request $request)
+    protected function setupFixedMap(Request $request): void
     {
-        $this->fixedMap = array();
+        $this->fixedMap = [];
         foreach ($request->getFixedPackages() as $package) {
             $this->fixedMap[$package->id] = $package;
         }
     }
 
-    /**
-     * @return void
-     */
-    protected function checkForRootRequireProblems(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter)
+    protected function checkForRootRequireProblems(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter): void
     {
         foreach ($request->getRequires() as $packageName => $constraint) {
             if ($platformRequirementFilter->isIgnored($packageName)) {
@@ -181,16 +166,13 @@ class Solver
 
             if (!$this->pool->whatProvides($packageName, $constraint)) {
                 $problem = new Problem();
-                $problem->addRule(new GenericRule(array(), Rule::RULE_ROOT_REQUIRE, array('packageName' => $packageName, 'constraint' => $constraint)));
+                $problem->addRule(new GenericRule([], Rule::RULE_ROOT_REQUIRE, ['packageName' => $packageName, 'constraint' => $constraint]));
                 $this->problems[] = $problem;
             }
         }
     }
 
-    /**
-     * @return LockTransaction
-     */
-    public function solve(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter = null)
+    public function solve(Request $request, ?PlatformRequirementFilterInterface $platformRequirementFilter = null): LockTransaction
     {
         $platformRequirementFilter = $platformRequirementFilter ?: PlatformRequirementFilterFactory::ignoreNothing();
 
@@ -230,10 +212,9 @@ class Solver
      * Evaluates each term affected by the decision (linked through watches)
      * If we find unit rules we make new decisions based on them
      *
-     * @param  int       $level
      * @return Rule|null A rule on conflict, otherwise null.
      */
-    protected function propagate($level)
+    protected function propagate(int $level): ?Rule
     {
         while ($this->decisions->validOffset($this->propagateIndex)) {
             $decision = $this->decisions->atOffset($this->propagateIndex);
@@ -256,12 +237,8 @@ class Solver
 
     /**
      * Reverts a decision at the given level.
-     *
-     * @param int $level
-     *
-     * @return void
      */
-    private function revert($level)
+    private function revert(int $level): void
     {
         while (!$this->decisions->isEmpty()) {
             $literal = $this->decisions->lastLiteral();
@@ -298,11 +275,9 @@ class Solver
      *
      * returns the new solver level or 0 if unsolvable
      *
-     * @param  int        $level
      * @param  string|int $literal
-     * @return int
      */
-    private function setPropagateLearn($level, $literal, Rule $rule)
+    private function setPropagateLearn(int $level, $literal, Rule $rule): int
     {
         $level++;
 
@@ -311,16 +286,16 @@ class Solver
         while (true) {
             $rule = $this->propagate($level);
 
-            if (!$rule) {
+            if (null === $rule) {
                 break;
             }
 
-            if ($level == 1) {
+            if ($level === 1) {
                 return $this->analyzeUnsolvable($rule);
             }
 
             // conflict
-            list($learnLiteral, $newLevel, $newRule, $why) = $this->analyze($level, $rule);
+            [$learnLiteral, $newLevel, $newRule, $why] = $this->analyze($level, $rule);
 
             if ($newLevel <= 0 || $newLevel >= $level) {
                 throw new SolverBugException(
@@ -347,11 +322,9 @@ class Solver
     }
 
     /**
-     * @param  int   $level
      * @param  int[] $decisionQueue
-     * @return int
      */
-    private function selectAndInstall($level, array $decisionQueue, Rule $rule)
+    private function selectAndInstall(int $level, array $decisionQueue, Rule $rule): int
     {
         // choose best package to install from decisionQueue
         $literals = $this->policy->selectPreferredPackages($this->pool, $decisionQueue, $rule->getRequiredPackage());
@@ -360,28 +333,27 @@ class Solver
 
         // if there are multiple candidates, then branch
         if (\count($literals)) {
-            $this->branches[] = array($literals, $level);
+            $this->branches[] = [$literals, $level];
         }
 
         return $this->setPropagateLearn($level, $selectedLiteral, $rule);
     }
 
     /**
-     * @param  int   $level
      * @return array{int, int, GenericRule, int}
      */
-    protected function analyze($level, Rule $rule)
+    protected function analyze(int $level, Rule $rule): array
     {
         $analyzedRule = $rule;
         $ruleLevel = 1;
         $num = 0;
         $l1num = 0;
-        $seen = array();
-        $learnedLiterals = array(null);
+        $seen = [];
+        $learnedLiterals = [null];
 
         $decisionId = \count($this->decisions);
 
-        $this->learnedPool[] = array();
+        $this->learnedPool[] = [];
 
         while (true) {
             $this->learnedPool[\count($this->learnedPool) - 1][] = $rule;
@@ -511,19 +483,18 @@ class Solver
 
         $newRule = new GenericRule($learnedLiterals, Rule::RULE_LEARNED, $why);
 
-        return array($learnedLiterals[0], $ruleLevel, $newRule, $why);
+        return [$learnedLiterals[0], $ruleLevel, $newRule, $why];
     }
 
     /**
      * @param array<string, true> $ruleSeen
-     * @return void
      */
-    private function analyzeUnsolvableRule(Problem $problem, Rule $conflictRule, array &$ruleSeen)
+    private function analyzeUnsolvableRule(Problem $problem, Rule $conflictRule, array &$ruleSeen): void
     {
         $why = spl_object_hash($conflictRule);
         $ruleSeen[$why] = true;
 
-        if ($conflictRule->getType() == RuleSet::TYPE_LEARNED) {
+        if ($conflictRule->getType() === RuleSet::TYPE_LEARNED) {
             $learnedWhy = $this->learnedWhy[$why];
             $problemRules = $this->learnedPool[$learnedWhy];
 
@@ -536,7 +507,7 @@ class Solver
             return;
         }
 
-        if ($conflictRule->getType() == RuleSet::TYPE_PACKAGE) {
+        if ($conflictRule->getType() === RuleSet::TYPE_PACKAGE) {
             // package rules cannot be part of a problem
             return;
         }
@@ -545,21 +516,18 @@ class Solver
         $problem->addRule($conflictRule);
     }
 
-    /**
-     * @return int
-     */
-    private function analyzeUnsolvable(Rule $conflictRule)
+    private function analyzeUnsolvable(Rule $conflictRule): int
     {
         $problem = new Problem();
         $problem->addRule($conflictRule);
 
-        $ruleSeen = array();
+        $ruleSeen = [];
 
         $this->analyzeUnsolvableRule($problem, $conflictRule, $ruleSeen);
 
         $this->problems[] = $problem;
 
-        $seen = array();
+        $seen = [];
         $literals = $conflictRule->getLiterals();
 
         foreach ($literals as $literal) {
@@ -603,10 +571,8 @@ class Solver
      * we have enabled or disabled some of our rules. We now re-enable all
      * of our learnt rules except the ones that were learnt from rules that
      * are now disabled.
-     *
-     * @return void
      */
-    private function enableDisableLearnedRules()
+    private function enableDisableLearnedRules(): void
     {
         foreach ($this->rules->getIteratorFor(RuleSet::TYPE_LEARNED) as $rule) {
             $why = $this->learnedWhy[spl_object_hash($rule)];
@@ -628,10 +594,7 @@ class Solver
         }
     }
 
-    /**
-     * @return void
-     */
-    private function runSat()
+    private function runSat(): void
     {
         $this->propagateIndex = 0;
 
@@ -665,7 +628,7 @@ class Solver
                 $iterator = $this->rules->getIteratorFor(RuleSet::TYPE_REQUEST);
                 foreach ($iterator as $rule) {
                     if ($rule->isEnabled()) {
-                        $decisionQueue = array();
+                        $decisionQueue = [];
                         $noneSatisfied = true;
 
                         foreach ($rule->getLiterals() as $literal) {
@@ -680,7 +643,7 @@ class Solver
 
                         if ($noneSatisfied && \count($decisionQueue)) {
                             // if any of the options in the decision queue are fixed, only use those
-                            $prunedQueue = array();
+                            $prunedQueue = [];
                             foreach ($decisionQueue as $literal) {
                                 if (isset($this->fixedMap[abs($literal)])) {
                                     $prunedQueue[] = $literal;
@@ -723,7 +686,7 @@ class Solver
 
             $this->io->writeError('Looking at all rules.', true, IOInterface::DEBUG);
             for ($i = 0, $n = 0; $n < $rulesCount; $i++, $n++) {
-                if ($i == $rulesCount) {
+                if ($i === $rulesCount) {
                     if (1 === $pass) {
                         $this->io->writeError("Something's changed, looking at all rules again (pass #$pass)", false, IOInterface::DEBUG);
                     } else {
@@ -741,7 +704,7 @@ class Solver
                     continue;
                 }
 
-                $decisionQueue = array();
+                $decisionQueue = [];
 
                 // make sure that
                 // * all negative literals are installed
@@ -792,7 +755,7 @@ class Solver
                 $lastBranchOffset = 0;
 
                 for ($i = \count($this->branches) - 1; $i >= 0; $i--) {
-                    list($literals, $l) = $this->branches[$i];
+                    [$literals, $l] = $this->branches[$i];
 
                     foreach ($literals as $offset => $literal) {
                         if ($literal && $literal > 0 && $this->decisions->decisionLevel($literal) > $l + 1) {
@@ -814,7 +777,7 @@ class Solver
 
                     $level = $this->setPropagateLearn($level, $lastLiteral, $why);
 
-                    if ($level == 0) {
+                    if ($level === 0) {
                         return;
                     }
 
