@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -33,12 +33,12 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
      * @var bool[]
      * @phpstan-var array<string, bool>
      */
-    private $hasStashedChanges = array();
+    private $hasStashedChanges = [];
     /**
      * @var bool[]
      * @phpstan-var array<string, bool>
      */
-    private $hasDiscardedChanges = array();
+    private $hasDiscardedChanges = [];
     /**
      * @var GitUtil
      */
@@ -47,9 +47,9 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
      * @var array
      * @phpstan-var array<int, array<string, bool>>
      */
-    private $cachedPackages = array();
+    private $cachedPackages = [];
 
-    public function __construct(IOInterface $io, Config $config, ProcessExecutor $process = null, Filesystem $fs = null)
+    public function __construct(IOInterface $io, Config $config, ?ProcessExecutor $process = null, ?Filesystem $fs = null)
     {
         parent::__construct($io, $config, $process, $fs);
         $this->gitUtil = new GitUtil($this->io, $this->config, $this->process, $this->filesystem);
@@ -58,8 +58,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     /**
      * @inheritDoc
      */
-    protected function doDownload(PackageInterface $package, $path, $url, PackageInterface $prevPackage = null)
+    protected function doDownload(PackageInterface $package, string $path, string $url, ?PackageInterface $prevPackage = null): PromiseInterface
     {
+        // Do not create an extra local cache when repository is already local
+        if (Filesystem::isLocalPath($url)) {
+            return \React\Promise\resolve(null);
+        }
+
         GitUtil::cleanEnv();
 
         $cachePath = $this->config->get('cache-vcs-dir').'/'.Preg::replace('{[^a-z0-9.]}i', '-', $url).'/';
@@ -70,20 +75,20 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             $this->io->writeError("  - Syncing <info>" . $package->getName() . "</info> (<comment>" . $package->getFullPrettyVersion() . "</comment>) into cache");
             $this->io->writeError(sprintf('    Cloning to cache at %s', ProcessExecutor::escape($cachePath)), true, IOInterface::DEBUG);
             $ref = $package->getSourceReference();
-            if ($this->gitUtil->fetchRefOrSyncMirror($url, $cachePath, $ref) && is_dir($cachePath)) {
+            if ($this->gitUtil->fetchRefOrSyncMirror($url, $cachePath, $ref, $package->getPrettyVersion()) && is_dir($cachePath)) {
                 $this->cachedPackages[$package->getId()][$ref] = true;
             }
         } elseif (null === $gitVersion) {
             throw new \RuntimeException('git was not found in your PATH, skipping source download');
         }
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
      * @inheritDoc
      */
-    protected function doInstall(PackageInterface $package, $path, $url)
+    protected function doInstall(PackageInterface $package, string $path, string $url): PromiseInterface
     {
         GitUtil::cleanEnv();
         $path = $this->normalizePath($path);
@@ -114,15 +119,15 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
 
         $this->io->writeError($msg);
 
-        $commandCallable = function ($url) use ($path, $command, $cachePath) {
+        $commandCallable = static function (string $url) use ($path, $command, $cachePath): string {
             return str_replace(
-                array('%url%', '%path%', '%cachePath%', '%sanitizedUrl%'),
-                array(
+                ['%url%', '%path%', '%cachePath%', '%sanitizedUrl%'],
+                [
                     ProcessExecutor::escape($url),
                     ProcessExecutor::escape($path),
                     ProcessExecutor::escape($cachePath),
                     ProcessExecutor::escape(Preg::replace('{://([^@]+?):(.+?)@}', '://', $url)),
-                ),
+                ],
                 $command
             );
         };
@@ -142,13 +147,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             $package->setSourceReference($newRef);
         }
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
      * @inheritDoc
      */
-    protected function doUpdate(PackageInterface $initial, PackageInterface $target, $path, $url)
+    protected function doUpdate(PackageInterface $initial, PackageInterface $target, string $path, string $url): PromiseInterface
     {
         GitUtil::cleanEnv();
         $path = $this->normalizePath($path);
@@ -172,15 +177,15 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
 
         $this->io->writeError($msg);
 
-        $commandCallable = function ($url) use ($ref, $command, $cachePath) {
+        $commandCallable = static function ($url) use ($ref, $command, $cachePath): string {
             return str_replace(
-                array('%url%', '%ref%', '%cachePath%', '%sanitizedUrl%'),
-                array(
+                ['%url%', '%ref%', '%cachePath%', '%sanitizedUrl%'],
+                [
                     ProcessExecutor::escape($url),
                     ProcessExecutor::escape($ref.'^{commit}'),
                     ProcessExecutor::escape($cachePath),
                     ProcessExecutor::escape(Preg::replace('{://([^@]+?):(.+?)@}', '://', $url)),
-                ),
+                ],
                 $command
             );
         };
@@ -207,13 +212,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             $this->updateOriginUrl($path, $target->getSourceUrl());
         }
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
      * @inheritDoc
      */
-    public function getLocalChanges(PackageInterface $package, $path)
+    public function getLocalChanges(PackageInterface $package, string $path): ?string
     {
         GitUtil::cleanEnv();
         if (!$this->hasMetadataRepository($path)) {
@@ -225,13 +230,12 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             throw new \RuntimeException('Failed to execute ' . $command . "\n\n" . $this->process->getErrorOutput());
         }
 
-        return trim($output) ?: null;
+        $output = trim($output);
+
+        return strlen($output) > 0 ? $output : null;
     }
 
-    /**
-     * @return null|string
-     */
-    public function getUnpushedChanges(PackageInterface $package, $path)
+    public function getUnpushedChanges(PackageInterface $package, string $path): ?string
     {
         GitUtil::cleanEnv();
         $path = $this->normalizePath($path);
@@ -264,7 +268,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
 
         // do two passes, as if we find anything we want to fetch and then re-try
         for ($i = 0; $i <= 1; $i++) {
-            $remoteBranches = array();
+            $remoteBranches = [];
 
             // try to find matching branch names in remote repos
             foreach ($candidateBranches as $candidate) {
@@ -328,7 +332,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     /**
      * @inheritDoc
      */
-    protected function cleanChanges(PackageInterface $package, $path, $update)
+    protected function cleanChanges(PackageInterface $package, string $path, bool $update): PromiseInterface
     {
         GitUtil::cleanEnv();
         $path = $this->normalizePath($path);
@@ -338,8 +342,8 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             throw new \RuntimeException('Source directory ' . $path . ' has unpushed changes on the current branch: '."\n".$unpushed);
         }
 
-        if (!$changes = $this->getLocalChanges($package, $path)) {
-            return \React\Promise\resolve();
+        if (null === ($changes = $this->getLocalChanges($package, $path))) {
+            return \React\Promise\resolve(null);
         }
 
         if (!$this->io->isInteractive()) {
@@ -358,7 +362,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             return parent::cleanChanges($package, $path, $update);
         }
 
-        $changes = array_map(function ($elem) {
+        $changes = array_map(static function ($elem): string {
             return '    '.$elem;
         }, Preg::split('{\s*\r?\n\s*}', $changes));
         $this->io->writeError('    <error>'.$package->getPrettyName().' has modified files:</error>');
@@ -395,12 +399,12 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
                 case '?':
                 default:
                     help :
-                    $this->io->writeError(array(
+                    $this->io->writeError([
                         '    y - discard changes and apply the '.($update ? 'update' : 'uninstall'),
                         '    n - abort the '.($update ? 'update' : 'uninstall').' and let you manually clean things up',
                         '    v - view modified files',
                         '    d - view local modifications (diff)',
-                    ));
+                    ]);
                     if ($update) {
                         $this->io->writeError('    s - stash changes and try to reapply them after the update');
                     }
@@ -409,13 +413,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
             }
         }
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
      * @inheritDoc
      */
-    protected function reapplyChanges($path)
+    protected function reapplyChanges(string $path): void
     {
         $path = $this->normalizePath($path);
         if (!empty($this->hasStashedChanges[$path])) {
@@ -432,13 +436,10 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     /**
      * Updates the given path to the given commit ref
      *
-     * @param  string            $path
-     * @param  string            $reference
-     * @param  string            $prettyVersion
      * @throws \RuntimeException
      * @return null|string       if a string is returned, it is the commit reference that was checked out if the original could not be found
      */
-    protected function updateToCommit(PackageInterface $package, $path, $reference, $prettyVersion)
+    protected function updateToCommit(PackageInterface $package, string $path, string $reference, string $prettyVersion): ?string
     {
         $force = !empty($this->hasDiscardedChanges[$path]) || !empty($this->hasStashedChanges[$path]) ? '-f ' : '';
 
@@ -458,7 +459,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
         // check whether non-commitish are branches or tags, and fetch branches with the remote name
         $gitRef = $reference;
         if (!Preg::isMatch('{^[a-f0-9]{40}$}', $reference)
-            && $branches
+            && null !== $branches
             && Preg::isMatch('{^\s+composer/'.preg_quote($reference).'$}m', $branches)
         ) {
             $command = sprintf('git checkout '.$force.'-B %s %s -- && git reset --hard %2$s --', ProcessExecutor::escape($branch), ProcessExecutor::escape('composer/'.$reference));
@@ -470,7 +471,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
         // try to checkout branch by name and then reset it so it's on the proper branch name
         if (Preg::isMatch('{^[a-f0-9]{40}$}', $reference)) {
             // add 'v' in front of the branch if it was stripped when generating the pretty name
-            if (!Preg::isMatch('{^\s+composer/'.preg_quote($branch).'$}m', $branches) && Preg::isMatch('{^\s+composer/v'.preg_quote($branch).'$}m', $branches)) {
+            if (null !== $branches && !Preg::isMatch('{^\s+composer/'.preg_quote($branch).'$}m', $branches) && Preg::isMatch('{^\s+composer/v'.preg_quote($branch).'$}m', $branches)) {
                 $branch = 'v' . $branch;
             }
 
@@ -499,25 +500,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
         throw new \RuntimeException(Url::sanitize('Failed to execute ' . $command . "\n\n" . $this->process->getErrorOutput() . $exceptionExtra));
     }
 
-    /**
-     * @param string $path
-     * @param string $url
-     *
-     * @return void
-     */
-    protected function updateOriginUrl($path, $url)
+    protected function updateOriginUrl(string $path, string $url): void
     {
         $this->process->execute(sprintf('git remote set-url origin -- %s', ProcessExecutor::escape($url)), $output, $path);
         $this->setPushUrl($path, $url);
     }
 
-    /**
-     * @param string $path
-     * @param string $url
-     *
-     * @return void
-     */
-    protected function setPushUrl($path, $url)
+    protected function setPushUrl(string $path, string $url): void
     {
         // set push url for github projects
         if (Preg::isMatch('{^(?:https?|git)://'.GitUtil::getGitHubDomainsRegex($this->config).'/([^/]+)/([^/]+?)(?:\.git)?$}', $url, $match)) {
@@ -534,7 +523,7 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     /**
      * @inheritDoc
      */
-    protected function getCommitLogs($fromReference, $toReference, $path)
+    protected function getCommitLogs(string $fromReference, string $toReference, string $path): string
     {
         $path = $this->normalizePath($path);
         $command = sprintf('git log %s..%s --pretty=format:"%%h - %%an: %%s"'.GitUtil::getNoShowSignatureFlag($this->process), ProcessExecutor::escape($fromReference), ProcessExecutor::escape($toReference));
@@ -547,13 +536,9 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     }
 
     /**
-     * @param string $path
-     *
-     * @return PromiseInterface
-     *
      * @throws \RuntimeException
      */
-    protected function discardChanges($path)
+    protected function discardChanges(string $path): PromiseInterface
     {
         $path = $this->normalizePath($path);
         if (0 !== $this->process->execute('git clean -df && git reset --hard', $output, $path)) {
@@ -562,17 +547,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
 
         $this->hasDiscardedChanges[$path] = true;
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
-     * @param string $path
-     *
-     * @return PromiseInterface
-     *
      * @throws \RuntimeException
      */
-    protected function stashChanges($path)
+    protected function stashChanges(string $path): PromiseInterface
     {
         $path = $this->normalizePath($path);
         if (0 !== $this->process->execute('git stash --include-untracked', $output, $path)) {
@@ -581,17 +562,13 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
 
         $this->hasStashedChanges[$path] = true;
 
-        return \React\Promise\resolve();
+        return \React\Promise\resolve(null);
     }
 
     /**
-     * @param string $path
-     *
-     * @return void
-     *
      * @throws \RuntimeException
      */
-    protected function viewDiff($path)
+    protected function viewDiff(string $path): void
     {
         $path = $this->normalizePath($path);
         if (0 !== $this->process->execute('git diff HEAD', $output, $path)) {
@@ -601,16 +578,11 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
         $this->io->writeError($output);
     }
 
-    /**
-     * @param string $path
-     *
-     * @return string
-     */
-    protected function normalizePath($path)
+    protected function normalizePath(string $path): string
     {
         if (Platform::isWindows() && strlen($path) > 0) {
             $basePath = $path;
-            $removed = array();
+            $removed = [];
 
             while (!is_dir($basePath) && $basePath !== '\\') {
                 array_unshift($removed, basename($basePath));
@@ -630,18 +602,14 @@ class GitDownloader extends VcsDownloader implements DvcsDownloaderInterface
     /**
      * @inheritDoc
      */
-    protected function hasMetadataRepository($path)
+    protected function hasMetadataRepository(string $path): bool
     {
         $path = $this->normalizePath($path);
 
         return is_dir($path.'/.git');
     }
 
-    /**
-     * @param  string $reference
-     * @return string
-     */
-    protected function getShortHash($reference)
+    protected function getShortHash(string $reference): string
     {
         if (!$this->io->isVerbose() && Preg::isMatch('{^[0-9a-f]{40}$}', $reference)) {
             return substr($reference, 0, 10);
