@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,10 +13,12 @@
 namespace Composer\Downloader;
 
 use Composer\Package\PackageInterface;
+use Composer\Pcre\Preg;
 use Composer\Util\IniHelper;
 use Composer\Util\Platform;
 use Composer\Util\ProcessExecutor;
 use Symfony\Component\Process\ExecutableFinder;
+use Symfony\Component\Process\Process;
 use React\Promise\PromiseInterface;
 use ZipArchive;
 
@@ -38,28 +40,28 @@ class ZipDownloader extends ArchiveDownloader
     /**
      * @inheritDoc
      */
-    public function download(PackageInterface $package, $path, PackageInterface $prevPackage = null, $output = true)
+    public function download(PackageInterface $package, string $path, ?PackageInterface $prevPackage = null, bool $output = true): PromiseInterface
     {
         if (null === self::$unzipCommands) {
-            self::$unzipCommands = array();
+            self::$unzipCommands = [];
             $finder = new ExecutableFinder;
-            if (Platform::isWindows() && ($cmd = $finder->find('7z', null, array('C:\Program Files\7-Zip')))) {
-                self::$unzipCommands[] = array('7z', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s');
+            if (Platform::isWindows() && ($cmd = $finder->find('7z', null, ['C:\Program Files\7-Zip']))) {
+                self::$unzipCommands[] = ['7z', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s'];
             }
             if ($cmd = $finder->find('unzip')) {
-                self::$unzipCommands[] = array('unzip', ProcessExecutor::escape($cmd).' -qq %s -d %s');
+                self::$unzipCommands[] = ['unzip', ProcessExecutor::escape($cmd).' -qq %s -d %s'];
             }
             if (!Platform::isWindows() && ($cmd = $finder->find('7z'))) { // 7z linux/macOS support is only used if unzip is not present
-                self::$unzipCommands[] = array('7z', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s');
+                self::$unzipCommands[] = ['7z', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s'];
             }
             if (!Platform::isWindows() && ($cmd = $finder->find('7zz'))) { // 7zz linux/macOS support is only used if unzip is not present
-                self::$unzipCommands[] = array('7zz', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s');
+                self::$unzipCommands[] = ['7zz', ProcessExecutor::escape($cmd).' x -bb0 -y %s -o%s'];
             }
         }
 
         $procOpenMissing = false;
         if (!function_exists('proc_open')) {
-            self::$unzipCommands = array();
+            self::$unzipCommands = [];
             $procOpenMissing = true;
         }
 
@@ -86,11 +88,11 @@ class ZipDownloader extends ArchiveDownloader
                 if ($procOpenMissing) {
                     $this->io->writeError("<warning>proc_open is disabled so 'unzip' and '7z' commands cannot be used, zip files are being unpacked using the PHP zip extension.</warning>");
                     $this->io->writeError("<warning>This may cause invalid reports of corrupted archives. Besides, any UNIX permissions (e.g. executable) defined in the archives will be lost.</warning>");
-                    $this->io->writeError("<warning>Enabling proc_open and installing 'unzip' or '7z' may remediate them.</warning>");
+                    $this->io->writeError("<warning>Enabling proc_open and installing 'unzip' or '7z' (21.01+) may remediate them.</warning>");
                 } else {
                     $this->io->writeError("<warning>As there is no 'unzip' nor '7z' command installed zip files are being unpacked using the PHP zip extension.</warning>");
                     $this->io->writeError("<warning>This may cause invalid reports of corrupted archives. Besides, any UNIX permissions (e.g. executable) defined in the archives will be lost.</warning>");
-                    $this->io->writeError("<warning>Installing 'unzip' or '7z' may remediate them.</warning>");
+                    $this->io->writeError("<warning>Installing 'unzip' or '7z' (21.01+) may remediate them.</warning>");
                 }
             }
         }
@@ -103,10 +105,11 @@ class ZipDownloader extends ArchiveDownloader
      *
      * @param  string           $file File to extract
      * @param  string           $path Path where to extract file
-     * @return PromiseInterface
      */
-    private function extractWithSystemUnzip(PackageInterface $package, $file, $path)
+    private function extractWithSystemUnzip(PackageInterface $package, string $file, string $path): PromiseInterface
     {
+        static $warned7ZipLinux = false;
+
         // Force Exception throwing if the other alternative extraction method is not available
         $isLastChance = !self::$hasZipArchive;
 
@@ -125,10 +128,17 @@ class ZipDownloader extends ArchiveDownloader
         }
 
         $executable = $commandSpec[0];
+        if (!$warned7ZipLinux && !Platform::isWindows() && in_array($executable, ['7z', '7zz'], true)) {
+            $warned7ZipLinux = true;
+            if (0 === $this->process->execute($executable, $output)) {
+                if (Preg::isMatch('{^\s*7-Zip(?: \[64\])? ([0-9.]+)}', $output, $match) && version_compare($match[1], '21.01', '<')) {
+                    $this->io->writeError('    <warning>Unzipping using '.$executable.' '.$match[1].' may result in incorrect file permissions. Install '.$executable.' 21.01+ or unzip to ensure you get correct permissions.</warning>');
+                }
+            }
+        }
 
-        $self = $this;
         $io = $this->io;
-        $tryFallback = function ($processError) use ($isLastChance, $io, $self, $file, $path, $package, $executable) {
+        $tryFallback = function (\Throwable $processError) use ($isLastChance, $io, $file, $path, $package, $executable): \React\Promise\PromiseInterface {
             if ($isLastChance) {
                 throw $processError;
             }
@@ -143,15 +153,15 @@ class ZipDownloader extends ArchiveDownloader
                 $io->writeError('    Unzip with '.$executable.' command failed, falling back to ZipArchive class');
             }
 
-            return $self->extractWithZipArchive($package, $file, $path);
+            return $this->extractWithZipArchive($package, $file, $path);
         };
 
         try {
             $promise = $this->process->executeAsync($command);
 
-            return $promise->then(function ($process) use ($tryFallback, $command, $package, $file, $self) {
+            return $promise->then(function (Process $process) use ($tryFallback, $command, $package, $file) {
                 if (!$process->isSuccessful()) {
-                    if (isset($self->cleanupExecuted[$package->getName()])) {
+                    if (isset($this->cleanupExecuted[$package->getName()])) {
                         throw new \RuntimeException('Failed to extract '.$package->getName().' as the installation was aborted by another package operation.');
                     }
 
@@ -161,8 +171,6 @@ class ZipDownloader extends ArchiveDownloader
                     return $tryFallback(new \RuntimeException('Failed to extract '.$package->getName().': ('.$process->getExitCode().') '.$command."\n\n".$output));
                 }
             });
-        } catch (\Exception $e) {
-            return $tryFallback($e);
         } catch (\Throwable $e) {
             return $tryFallback($e);
         }
@@ -173,24 +181,25 @@ class ZipDownloader extends ArchiveDownloader
      *
      * @param  string           $file File to extract
      * @param  string           $path Path where to extract file
-     * @return PromiseInterface
-     *
-     * TODO v3 should make this private once we can drop PHP 5.3 support
-     * @protected
      */
-    public function extractWithZipArchive(PackageInterface $package, $file, $path)
+    private function extractWithZipArchive(PackageInterface $package, string $file, string $path): PromiseInterface
     {
         $processError = null;
         $zipArchive = $this->zipArchiveObject ?: new ZipArchive();
 
         try {
-            if (true === ($retval = $zipArchive->open($file))) {
+            if (!file_exists($file) || ($filesize = filesize($file)) === false || $filesize === 0) {
+                $retval = -1;
+            } else {
+                $retval = $zipArchive->open($file);
+            }
+            if (true === $retval) {
                 $extractResult = $zipArchive->extractTo($path);
 
                 if (true === $extractResult) {
                     $zipArchive->close();
 
-                    return \React\Promise\resolve();
+                    return \React\Promise\resolve(null);
                 }
 
                 $processError = new \RuntimeException(rtrim("There was an error extracting the ZIP file, it is either corrupted or using an invalid format.\n"));
@@ -199,8 +208,6 @@ class ZipDownloader extends ArchiveDownloader
             }
         } catch (\ErrorException $e) {
             $processError = new \RuntimeException('The archive may contain identical file names with different capitalization (which fails on case insensitive filesystems): '.$e->getMessage(), 0, $e);
-        } catch (\Exception $e) {
-            $processError = $e;
         } catch (\Throwable $e) {
             $processError = $e;
         }
@@ -213,24 +220,16 @@ class ZipDownloader extends ArchiveDownloader
      *
      * @param  string                $file File to extract
      * @param  string                $path Path where to extract file
-     * @return PromiseInterface|null
-     *
-     * TODO v3 should make this private once we can drop PHP 5.3 support
-     * @protected
      */
-    public function extract(PackageInterface $package, $file, $path)
+    protected function extract(PackageInterface $package, string $file, string $path): PromiseInterface
     {
         return $this->extractWithSystemUnzip($package, $file, $path);
     }
 
     /**
      * Give a meaningful error message to the user.
-     *
-     * @param  int    $retval
-     * @param  string $file
-     * @return string
      */
-    protected function getErrorMessage($retval, $file)
+    protected function getErrorMessage(int $retval, string $file): string
     {
         switch ($retval) {
             case ZipArchive::ER_EXISTS:
@@ -251,6 +250,8 @@ class ZipDownloader extends ArchiveDownloader
                 return sprintf("Zip read error (%s)", $file);
             case ZipArchive::ER_SEEK:
                 return sprintf("Zip seek error (%s)", $file);
+            case -1:
+                return sprintf("'%s' is a corrupted zip archive (0 bytes), try again.", $file);
             default:
                 return sprintf("'%s' is not a valid zip archive, got error code: %s", $file, $retval);
         }
