@@ -39,7 +39,7 @@ final class IgnoreListPlatformRequirementFilter implements PlatformRequirementFi
      */
     public function __construct(array $reqList)
     {
-        $ignoreAll = $ignoreUpperBound = array();
+        $ignoreAll = $ignoreUpperBound = [];
         foreach ($reqList as $req) {
             if (substr($req, -1) === '+') {
                 $ignoreUpperBound[] = substr($req, 0, -1);
@@ -51,10 +51,6 @@ final class IgnoreListPlatformRequirementFilter implements PlatformRequirementFi
         $this->ignoreUpperBoundRegex = BasePackage::packageNamesToRegexp($ignoreUpperBound);
     }
 
-    /**
-     * @param string $req
-     * @return bool
-     */
     public function isIgnored(string $req): bool
     {
         if (!PlatformRepository::isPlatformPackage($req)) {
@@ -64,10 +60,6 @@ final class IgnoreListPlatformRequirementFilter implements PlatformRequirementFi
         return Preg::isMatch($this->ignoreRegex, $req);
     }
 
-    /**
-     * @param string $req
-     * @return ConstraintInterface
-     */
     public function filterConstraint(string $req, ConstraintInterface $constraint): ConstraintInterface
     {
         if (!PlatformRepository::isPlatformPackage($req)) {
@@ -85,7 +77,7 @@ final class IgnoreListPlatformRequirementFilter implements PlatformRequirementFi
         $intervals = Intervals::get($constraint);
         $last = end($intervals['numeric']);
         if ($last !== false && (string) $last->getEnd() !== (string) Interval::untilPositiveInfinity()) {
-            $constraint = new MultiConstraint(array($constraint, new Constraint('>=', $last->getEnd()->getVersion())), false);
+            $constraint = new MultiConstraint([$constraint, new Constraint('>=', $last->getEnd()->getVersion())], false);
         }
 
         return $constraint;
