@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -28,14 +28,18 @@ use Composer\Downloader\TransportException;
  */
 class JsonFile
 {
-    const LAX_SCHEMA = 1;
-    const STRICT_SCHEMA = 2;
+    public const LAX_SCHEMA = 1;
+    public const STRICT_SCHEMA = 2;
+    public const AUTH_SCHEMA = 3;
 
-    const JSON_UNESCAPED_SLASHES = 64;
-    const JSON_PRETTY_PRINT = 128;
-    const JSON_UNESCAPED_UNICODE = 256;
+    /** @deprecated Use \JSON_UNESCAPED_SLASHES */
+    public const JSON_UNESCAPED_SLASHES = 64;
+    /** @deprecated Use \JSON_PRETTY_PRINT */
+    public const JSON_PRETTY_PRINT = 128;
+    /** @deprecated Use \JSON_UNESCAPED_UNICODE */
+    public const JSON_UNESCAPED_UNICODE = 256;
 
-    const COMPOSER_SCHEMA_PATH = '/../../../res/composer-schema.json';
+    public const COMPOSER_SCHEMA_PATH = __DIR__ . '/../../../res/composer-schema.json';
 
     /** @var string */
     private $path;
@@ -52,7 +56,7 @@ class JsonFile
      * @param  ?IOInterface              $io
      * @throws \InvalidArgumentException
      */
-    public function __construct($path, HttpDownloader $httpDownloader = null, IOInterface $io = null)
+    public function __construct(string $path, ?HttpDownloader $httpDownloader = null, ?IOInterface $io = null)
     {
         $this->path = $path;
 
@@ -63,20 +67,15 @@ class JsonFile
         $this->io = $io;
     }
 
-    /**
-     * @return string
-     */
-    public function getPath()
+    public function getPath(): string
     {
         return $this->path;
     }
 
     /**
      * Checks whether json file exists.
-     *
-     * @return bool
      */
-    public function exists()
+    public function exists(): bool
     {
         return is_file($this->path);
     }
@@ -110,18 +109,22 @@ class JsonFile
             throw new \RuntimeException('Could not read '.$this->path."\n\n".$e->getMessage());
         }
 
+        if ($json === false) {
+            throw new \RuntimeException('Could not read '.$this->path);
+        }
+
         return static::parseJson($json, $this->path);
     }
 
     /**
      * Writes json file.
      *
-     * @param  mixed[]                          $hash    writes hash into json file
-     * @param  int                                  $options json_encode options (defaults to JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE)
+     * @param  mixed[]                              $hash    writes hash into json file
+     * @param  int                                  $options json_encode options
      * @throws \UnexpectedValueException|\Exception
      * @return void
      */
-    public function write(array $hash, $options = 448)
+    public function write(array $hash, int $options = JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE)
     {
         if ($this->path === 'php://memory') {
             file_put_contents($this->path, static::encode($hash, $options));
@@ -146,7 +149,7 @@ class JsonFile
         $retries = 3;
         while ($retries--) {
             try {
-                $this->filePutContentsIfModified($this->path, static::encode($hash, $options). ($options & self::JSON_PRETTY_PRINT ? "\n" : ''));
+                $this->filePutContentsIfModified($this->path, static::encode($hash, $options). ($options & JSON_PRETTY_PRINT ? "\n" : ''));
                 break;
             } catch (\Exception $e) {
                 if ($retries > 0) {
@@ -162,14 +165,12 @@ class JsonFile
     /**
      * Modify file properties only if content modified
      *
-     * @param string $path
-     * @param string $content
      * @return int|false
      */
-    private function filePutContentsIfModified($path, $content)
+    private function filePutContentsIfModified(string $path, string $content)
     {
         $currentContent = @file_get_contents($path);
-        if (!$currentContent || ($currentContent != $content)) {
+        if (false === $currentContent || $currentContent !== $content) {
             return file_put_contents($path, $content);
         }
 
@@ -183,9 +184,11 @@ class JsonFile
      * @param  string|null             $schemaFile a path to the schema file
      * @throws JsonValidationException
      * @throws ParsingException
-     * @return bool                    true on success
+     * @return true                    true on success
+     *
+     * @phpstan-param self::*_SCHEMA $schema
      */
-    public function validateSchema($schema = self::STRICT_SCHEMA, $schemaFile = null)
+    public function validateSchema(int $schema = self::STRICT_SCHEMA, ?string $schemaFile = null): bool
     {
         $content = file_get_contents($this->path);
         $data = json_decode($content);
@@ -194,10 +197,26 @@ class JsonFile
             self::validateSyntax($content, $this->path);
         }
 
+        return self::validateJsonSchema($this->path, $data, $schema, $schemaFile);
+    }
+
+    /**
+     * Validates the schema of the current json file according to composer-schema.json rules
+     *
+     * @param  mixed                   $data       Decoded JSON data to validate
+     * @param  int                     $schema     a JsonFile::*_SCHEMA constant
+     * @param  string|null             $schemaFile a path to the schema file
+     * @throws JsonValidationException
+     * @return true                    true on success
+     *
+     * @phpstan-param self::*_SCHEMA $schema
+     */
+    public static function validateJsonSchema(string $source, $data, int $schema, ?string $schemaFile = null): bool
+    {
         $isComposerSchemaFile = false;
         if (null === $schemaFile) {
             $isComposerSchemaFile = true;
-            $schemaFile = __DIR__ . self::COMPOSER_SCHEMA_PATH;
+            $schemaFile = self::COMPOSER_SCHEMA_PATH;
         }
 
         // Prepend with file:// only when not using a special schema already (e.g. in the phar)
@@ -205,25 +224,27 @@ class JsonFile
             $schemaFile = 'file://' . $schemaFile;
         }
 
-        $schemaData = (object) array('$ref' => $schemaFile);
+        $schemaData = (object) ['$ref' => $schemaFile];
 
         if ($schema === self::LAX_SCHEMA) {
             $schemaData->additionalProperties = true;
-            $schemaData->required = array();
+            $schemaData->required = [];
         } elseif ($schema === self::STRICT_SCHEMA && $isComposerSchemaFile) {
             $schemaData->additionalProperties = false;
-            $schemaData->required = array('name', 'description');
+            $schemaData->required = ['name', 'description'];
+        } elseif ($schema === self::AUTH_SCHEMA && $isComposerSchemaFile) {
+            $schemaData = (object) ['$ref' => $schemaFile.'#/properties/config', '$schema' => "https://json-schema.org/draft-04/schema#"];
         }
 
         $validator = new Validator();
         $validator->check($data, $schemaData);
 
         if (!$validator->isValid()) {
-            $errors = array();
+            $errors = [];
             foreach ((array) $validator->getErrors() as $error) {
                 $errors[] = ($error['property'] ? $error['property'].' : ' : '').$error['message'];
             }
-            throw new JsonValidationException('"'.$this->path.'" does not match the expected JSON schema', $errors);
+            throw new JsonValidationException('"'.$source.'" does not match the expected JSON schema', $errors);
         }
 
         return true;
@@ -236,37 +257,14 @@ class JsonFile
      * @param  int    $options json_encode options (defaults to JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE)
      * @return string Encoded json
      */
-    public static function encode($data, $options = 448)
+    public static function encode($data, int $options = 448)
     {
-        if (PHP_VERSION_ID >= 50400) {
-            $json = json_encode($data, $options);
-            if (false === $json) {
-                self::throwEncodeError(json_last_error());
-            }
-
-            //  compact brackets to follow recent php versions
-            if (PHP_VERSION_ID < 50428 || (PHP_VERSION_ID >= 50500 && PHP_VERSION_ID < 50512) || (defined('JSON_C_VERSION') && version_compare(phpversion('json'), '1.3.6', '<'))) {
-                $json = Preg::replace('/\[\s+\]/', '[]', $json);
-                $json = Preg::replace('/\{\s+\}/', '{}', $json);
-            }
-
-            return $json;
-        }
-
-        $json = json_encode($data);
+        $json = json_encode($data, $options);
         if (false === $json) {
             self::throwEncodeError(json_last_error());
         }
 
-        $prettyPrint = (bool) ($options & self::JSON_PRETTY_PRINT);
-        $unescapeUnicode = (bool) ($options & self::JSON_UNESCAPED_UNICODE);
-        $unescapeSlashes = (bool) ($options & self::JSON_UNESCAPED_SLASHES);
-
-        if (!$prettyPrint && !$unescapeUnicode && !$unescapeSlashes) {
-            return $json;
-        }
-
-        return JsonFormatter::format($json, $unescapeUnicode, $unescapeSlashes);
+        return $json;
     }
 
     /**
@@ -274,9 +272,8 @@ class JsonFile
      *
      * @param  int               $code return code of json_last_error function
      * @throws \RuntimeException
-     * @return void
      */
-    private static function throwEncodeError($code)
+    private static function throwEncodeError(int $code): void
     {
         switch ($code) {
             case JSON_ERROR_DEPTH:
@@ -301,13 +298,13 @@ class JsonFile
     /**
      * Parses json string and returns hash.
      *
-     * @param ?string $json json string
+     * @param null|string $json json string
      * @param string $file the json file
      *
      * @throws ParsingException
      * @return mixed
      */
-    public static function parseJson($json, $file = null)
+    public static function parseJson(?string $json, ?string $file = null)
     {
         if (null === $json) {
             return null;
@@ -323,13 +320,12 @@ class JsonFile
     /**
      * Validates the syntax of a JSON string
      *
-     * @param  string                    $json
      * @param  string                    $file
      * @throws \UnexpectedValueException
      * @throws ParsingException
      * @return bool                      true on success
      */
-    protected static function validateSyntax($json, $file = null)
+    protected static function validateSyntax(string $json, ?string $file = null): bool
     {
         $parser = new JsonParser();
         $result = $parser->lint($json);
