@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -20,6 +20,9 @@ use Composer\Util\ComposerMirror;
  * Core package definitions that are needed to resolve dependencies and install packages
  *
  * @author Nils Adermann <naderman@naderman.de>
+ *
+ * @phpstan-import-type AutoloadRules from PackageInterface
+ * @phpstan-import-type DevAutoloadRules from PackageInterface
  */
 class Package extends BasePackage
 {
@@ -51,12 +54,12 @@ class Package extends BasePackage
     protected $version;
     /** @var string */
     protected $prettyVersion;
-    /** @var ?\DateTime */
+    /** @var ?\DateTimeInterface */
     protected $releaseDate;
     /** @var mixed[] */
-    protected $extra = array();
+    protected $extra = [];
     /** @var string[] */
-    protected $binaries = array();
+    protected $binaries = [];
     /** @var bool */
     protected $dev;
     /**
@@ -68,27 +71,33 @@ class Package extends BasePackage
     protected $notificationUrl;
 
     /** @var array<string, Link> */
-    protected $requires = array();
+    protected $requires = [];
     /** @var array<string, Link> */
-    protected $conflicts = array();
+    protected $conflicts = [];
     /** @var array<string, Link> */
-    protected $provides = array();
+    protected $provides = [];
     /** @var array<string, Link> */
-    protected $replaces = array();
+    protected $replaces = [];
     /** @var array<string, Link> */
-    protected $devRequires = array();
+    protected $devRequires = [];
     /** @var array<string, string> */
-    protected $suggests = array();
-    /** @var array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} */
-    protected $autoload = array();
-    /** @var array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} */
-    protected $devAutoload = array();
+    protected $suggests = [];
+    /**
+     * @var array
+     * @phpstan-var AutoloadRules
+     */
+    protected $autoload = [];
+    /**
+     * @var array
+     * @phpstan-var DevAutoloadRules
+     */
+    protected $devAutoload = [];
     /** @var string[] */
-    protected $includePaths = array();
+    protected $includePaths = [];
     /** @var bool */
     protected $isDefaultBranch = false;
     /** @var mixed[] */
-    protected $transportOptions = array();
+    protected $transportOptions = [];
 
     /**
      * Creates a new in memory package.
@@ -97,7 +106,7 @@ class Package extends BasePackage
      * @param string $version       The package's version
      * @param string $prettyVersion The package's non-normalized version
      */
-    public function __construct($name, $version, $prettyVersion)
+    public function __construct(string $name, string $version, string $prettyVersion)
     {
         parent::__construct($name);
 
@@ -111,17 +120,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function isDev()
+    public function isDev(): bool
     {
         return $this->dev;
     }
 
-    /**
-     * @param string $type
-     *
-     * @return void
-     */
-    public function setType($type)
+    public function setType(string $type): void
     {
         $this->type = $type;
     }
@@ -129,7 +133,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getType()
+    public function getType(): string
     {
         return $this->type ?: 'library';
     }
@@ -137,17 +141,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getStability()
+    public function getStability(): string
     {
         return $this->stability;
     }
 
-    /**
-     * @param string $targetDir
-     *
-     * @return void
-     */
-    public function setTargetDir($targetDir)
+    public function setTargetDir(?string $targetDir): void
     {
         $this->targetDir = $targetDir;
     }
@@ -155,7 +154,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getTargetDir()
+    public function getTargetDir(): ?string
     {
         if (null === $this->targetDir) {
             return null;
@@ -166,10 +165,8 @@ class Package extends BasePackage
 
     /**
      * @param mixed[] $extra
-     *
-     * @return void
      */
-    public function setExtra(array $extra)
+    public function setExtra(array $extra): void
     {
         $this->extra = $extra;
     }
@@ -177,17 +174,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getExtra()
+    public function getExtra(): array
     {
         return $this->extra;
     }
 
     /**
      * @param string[] $binaries
-     *
-     * @return void
      */
-    public function setBinaries(array $binaries)
+    public function setBinaries(array $binaries): void
     {
         $this->binaries = $binaries;
     }
@@ -195,17 +190,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getBinaries()
+    public function getBinaries(): array
     {
         return $this->binaries;
     }
 
     /**
      * @inheritDoc
-     *
-     * @return void
      */
-    public function setInstallationSource($type)
+    public function setInstallationSource(?string $type): void
     {
         $this->installationSource = $type;
     }
@@ -213,17 +206,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getInstallationSource()
+    public function getInstallationSource(): ?string
     {
         return $this->installationSource;
     }
 
-    /**
-     * @param string $type
-     *
-     * @return void
-     */
-    public function setSourceType($type)
+    public function setSourceType(?string $type): void
     {
         $this->sourceType = $type;
     }
@@ -231,17 +219,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSourceType()
+    public function getSourceType(): ?string
     {
         return $this->sourceType;
     }
 
-    /**
-     * @param string $url
-     *
-     * @return void
-     */
-    public function setSourceUrl($url)
+    public function setSourceUrl(?string $url): void
     {
         $this->sourceUrl = $url;
     }
@@ -249,17 +232,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSourceUrl()
+    public function getSourceUrl(): ?string
     {
         return $this->sourceUrl;
     }
 
-    /**
-     * @param string $reference
-     *
-     * @return void
-     */
-    public function setSourceReference($reference)
+    public function setSourceReference(?string $reference): void
     {
         $this->sourceReference = $reference;
     }
@@ -267,17 +245,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSourceReference()
+    public function getSourceReference(): ?string
     {
         return $this->sourceReference;
     }
 
-    /**
-     * @inheritDoc
-     *
-     * @return void
-     */
-    public function setSourceMirrors($mirrors)
+    public function setSourceMirrors(?array $mirrors): void
     {
         $this->sourceMirrors = $mirrors;
     }
@@ -285,7 +258,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSourceMirrors()
+    public function getSourceMirrors(): ?array
     {
         return $this->sourceMirrors;
     }
@@ -293,17 +266,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSourceUrls()
+    public function getSourceUrls(): array
     {
         return $this->getUrls($this->sourceUrl, $this->sourceMirrors, $this->sourceReference, $this->sourceType, 'source');
     }
 
     /**
      * @param string $type
-     *
-     * @return void
      */
-    public function setDistType($type)
+    public function setDistType(?string $type): void
     {
         $this->distType = $type;
     }
@@ -311,17 +282,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistType()
+    public function getDistType(): ?string
     {
         return $this->distType;
     }
 
     /**
      * @param string $url
-     *
-     * @return void
      */
-    public function setDistUrl($url)
+    public function setDistUrl(?string $url): void
     {
         $this->distUrl = $url;
     }
@@ -329,17 +298,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistUrl()
+    public function getDistUrl(): ?string
     {
         return $this->distUrl;
     }
 
     /**
      * @param string $reference
-     *
-     * @return void
      */
-    public function setDistReference($reference)
+    public function setDistReference(?string $reference): void
     {
         $this->distReference = $reference;
     }
@@ -347,17 +314,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistReference()
+    public function getDistReference(): ?string
     {
         return $this->distReference;
     }
 
     /**
      * @param string $sha1checksum
-     *
-     * @return void
      */
-    public function setDistSha1Checksum($sha1checksum)
+    public function setDistSha1Checksum(?string $sha1checksum): void
     {
         $this->distSha1Checksum = $sha1checksum;
     }
@@ -365,17 +330,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistSha1Checksum()
+    public function getDistSha1Checksum(): ?string
     {
         return $this->distSha1Checksum;
     }
 
-    /**
-     * @inheritDoc
-     *
-     * @return void
-     */
-    public function setDistMirrors($mirrors)
+    public function setDistMirrors(?array $mirrors): void
     {
         $this->distMirrors = $mirrors;
     }
@@ -383,7 +343,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistMirrors()
+    public function getDistMirrors(): ?array
     {
         return $this->distMirrors;
     }
@@ -391,7 +351,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDistUrls()
+    public function getDistUrls(): array
     {
         return $this->getUrls($this->distUrl, $this->distMirrors, $this->distReference, $this->distType, 'dist');
     }
@@ -399,7 +359,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getTransportOptions()
+    public function getTransportOptions(): array
     {
         return $this->transportOptions;
     }
@@ -407,7 +367,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function setTransportOptions(array $options)
+    public function setTransportOptions(array $options): void
     {
         $this->transportOptions = $options;
     }
@@ -415,7 +375,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getVersion()
+    public function getVersion(): string
     {
         return $this->version;
     }
@@ -423,19 +383,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getPrettyVersion()
+    public function getPrettyVersion(): string
     {
         return $this->prettyVersion;
     }
 
-    /**
-     * Set the releaseDate
-     *
-     * @param \DateTime $releaseDate
-     *
-     * @return void
-     */
-    public function setReleaseDate(\DateTime $releaseDate)
+    public function setReleaseDate(?\DateTimeInterface $releaseDate): void
     {
         $this->releaseDate = $releaseDate;
     }
@@ -443,7 +396,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getReleaseDate()
+    public function getReleaseDate(): ?\DateTimeInterface
     {
         return $this->releaseDate;
     }
@@ -452,10 +405,8 @@ class Package extends BasePackage
      * Set the required packages
      *
      * @param array<string, Link> $requires A set of package links
-     *
-     * @return void
      */
-    public function setRequires(array $requires)
+    public function setRequires(array $requires): void
     {
         if (isset($requires[0])) { // @phpstan-ignore-line
             $requires = $this->convertLinksToMap($requires, 'setRequires');
@@ -467,7 +418,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getRequires()
+    public function getRequires(): array
     {
         return $this->requires;
     }
@@ -476,10 +427,8 @@ class Package extends BasePackage
      * Set the conflicting packages
      *
      * @param array<string, Link> $conflicts A set of package links
-     *
-     * @return void
      */
-    public function setConflicts(array $conflicts)
+    public function setConflicts(array $conflicts): void
     {
         if (isset($conflicts[0])) { // @phpstan-ignore-line
             $conflicts = $this->convertLinksToMap($conflicts, 'setConflicts');
@@ -492,7 +441,7 @@ class Package extends BasePackage
      * @inheritDoc
      * @return array<string, Link>
      */
-    public function getConflicts()
+    public function getConflicts(): array
     {
         return $this->conflicts;
     }
@@ -501,10 +450,8 @@ class Package extends BasePackage
      * Set the provided virtual packages
      *
      * @param array<string, Link> $provides A set of package links
-     *
-     * @return void
      */
-    public function setProvides(array $provides)
+    public function setProvides(array $provides): void
     {
         if (isset($provides[0])) { // @phpstan-ignore-line
             $provides = $this->convertLinksToMap($provides, 'setProvides');
@@ -517,7 +464,7 @@ class Package extends BasePackage
      * @inheritDoc
      * @return array<string, Link>
      */
-    public function getProvides()
+    public function getProvides(): array
     {
         return $this->provides;
     }
@@ -526,10 +473,8 @@ class Package extends BasePackage
      * Set the packages this one replaces
      *
      * @param array<string, Link> $replaces A set of package links
-     *
-     * @return void
      */
-    public function setReplaces(array $replaces)
+    public function setReplaces(array $replaces): void
     {
         if (isset($replaces[0])) { // @phpstan-ignore-line
             $replaces = $this->convertLinksToMap($replaces, 'setReplaces');
@@ -542,7 +487,7 @@ class Package extends BasePackage
      * @inheritDoc
      * @return array<string, Link>
      */
-    public function getReplaces()
+    public function getReplaces(): array
     {
         return $this->replaces;
     }
@@ -551,10 +496,8 @@ class Package extends BasePackage
      * Set the recommended packages
      *
      * @param array<string, Link> $devRequires A set of package links
-     *
-     * @return void
      */
-    public function setDevRequires(array $devRequires)
+    public function setDevRequires(array $devRequires): void
     {
         if (isset($devRequires[0])) { // @phpstan-ignore-line
             $devRequires = $this->convertLinksToMap($devRequires, 'setDevRequires');
@@ -566,7 +509,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDevRequires()
+    public function getDevRequires(): array
     {
         return $this->devRequires;
     }
@@ -575,10 +518,8 @@ class Package extends BasePackage
      * Set the suggested packages
      *
      * @param array<string, string> $suggests A set of package names/comments
-     *
-     * @return void
      */
-    public function setSuggests(array $suggests)
+    public function setSuggests(array $suggests): void
     {
         $this->suggests = $suggests;
     }
@@ -586,7 +527,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getSuggests()
+    public function getSuggests(): array
     {
         return $this->suggests;
     }
@@ -596,11 +537,10 @@ class Package extends BasePackage
      *
      * @param array $autoload Mapping of autoloading rules
      *
-     * @return void
      *
-     * @phpstan-param array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} $autoload
+     * @phpstan-param AutoloadRules $autoload
      */
-    public function setAutoload(array $autoload)
+    public function setAutoload(array $autoload): void
     {
         $this->autoload = $autoload;
     }
@@ -608,7 +548,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getAutoload()
+    public function getAutoload(): array
     {
         return $this->autoload;
     }
@@ -618,11 +558,10 @@ class Package extends BasePackage
      *
      * @param array $devAutoload Mapping of dev autoloading rules
      *
-     * @return void
      *
-     * @phpstan-param array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} $devAutoload
+     * @phpstan-param DevAutoloadRules $devAutoload
      */
-    public function setDevAutoload(array $devAutoload)
+    public function setDevAutoload(array $devAutoload): void
     {
         $this->devAutoload = $devAutoload;
     }
@@ -630,7 +569,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getDevAutoload()
+    public function getDevAutoload(): array
     {
         return $this->devAutoload;
     }
@@ -639,10 +578,8 @@ class Package extends BasePackage
      * Sets the list of paths added to PHP's include path.
      *
      * @param string[] $includePaths List of directories.
-     *
-     * @return void
      */
-    public function setIncludePaths(array $includePaths)
+    public function setIncludePaths(array $includePaths): void
     {
         $this->includePaths = $includePaths;
     }
@@ -650,19 +587,15 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getIncludePaths()
+    public function getIncludePaths(): array
     {
         return $this->includePaths;
     }
 
     /**
      * Sets the notification URL
-     *
-     * @param string $notificationUrl
-     *
-     * @return void
      */
-    public function setNotificationUrl($notificationUrl)
+    public function setNotificationUrl(string $notificationUrl): void
     {
         $this->notificationUrl = $notificationUrl;
     }
@@ -670,17 +603,12 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function getNotificationUrl()
+    public function getNotificationUrl(): ?string
     {
         return $this->notificationUrl;
     }
 
-    /**
-     * @param bool $defaultBranch
-     *
-     * @return void
-     */
-    public function setIsDefaultBranch($defaultBranch)
+    public function setIsDefaultBranch(bool $defaultBranch): void
     {
         $this->isDefaultBranch = $defaultBranch;
     }
@@ -688,7 +616,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function isDefaultBranch()
+    public function isDefaultBranch(): bool
     {
         return $this->isDefaultBranch;
     }
@@ -696,7 +624,7 @@ class Package extends BasePackage
     /**
      * @inheritDoc
      */
-    public function setSourceDistReferences($reference)
+    public function setSourceDistReferences(string $reference): void
     {
         $this->setSourceReference($reference);
 
@@ -719,10 +647,8 @@ class Package extends BasePackage
      *
      * @param string $version       The package's normalized version
      * @param string $prettyVersion The package's non-normalized version
-     *
-     * @return void
      */
-    public function replaceVersion($version, $prettyVersion)
+    public function replaceVersion(string $version, string $prettyVersion): void
     {
         $this->version = $version;
         $this->prettyVersion = $prettyVersion;
@@ -732,27 +658,23 @@ class Package extends BasePackage
     }
 
     /**
-     * @param string|null  $url
      * @param mixed[]|null $mirrors
-     * @param string|null  $ref
-     * @param string|null  $type
-     * @param string       $urlType
      *
      * @return string[]
      *
      * @phpstan-param list<array{url: string, preferred: bool}>|null $mirrors
      */
-    protected function getUrls($url, $mirrors, $ref, $type, $urlType)
+    protected function getUrls(?string $url, ?array $mirrors, ?string $ref, ?string $type, string $urlType): array
     {
         if (!$url) {
-            return array();
+            return [];
         }
 
         if ($urlType === 'dist' && false !== strpos($url, '%')) {
             $url = ComposerMirror::processUrl($url, $this->name, $this->version, $ref, $type, $this->prettyVersion);
         }
 
-        $urls = array($url);
+        $urls = [$url];
         if ($mirrors) {
             foreach ($mirrors as $mirror) {
                 if ($urlType === 'dist') {
@@ -776,13 +698,12 @@ class Package extends BasePackage
 
     /**
      * @param  array<int, Link> $links
-     * @param  string $source
      * @return array<string, Link>
      */
-    private function convertLinksToMap(array $links, $source)
+    private function convertLinksToMap(array $links, string $source): array
     {
         trigger_error('Package::'.$source.' must be called with a map of lowercased package name => Link object, got a indexed array, this is deprecated and you should fix your usage.');
-        $newLinks = array();
+        $newLinks = [];
         foreach ($links as $link) {
             $newLinks[$link->getTarget()] = $link;
         }
