@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -34,9 +34,9 @@ class GitBitbucketDriver extends VcsDriver
     private $hasIssues = false;
     /** @var ?string */
     private $rootIdentifier;
-    /** @var array<string, string> Map of tag name to identifier */
+    /** @var array<int|string, string> Map of tag name to identifier */
     private $tags;
-    /** @var array<string, string> Map of branch name to identifier */
+    /** @var array<int|string, string> Map of branch name to identifier */
     private $branches;
     /** @var string */
     private $branchesUrl = '';
@@ -48,6 +48,8 @@ class GitBitbucketDriver extends VcsDriver
     private $website = '';
     /** @var string */
     private $cloneHttpsUrl = '';
+    /** @var array<string, mixed> */
+    private $repoData;
 
     /**
      * @var ?VcsDriver
@@ -59,20 +61,23 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function initialize()
+    public function initialize(): void
     {
-        Preg::match('#^https?://bitbucket\.org/([^/]+)/([^/]+?)(\.git|/?)?$#i', $this->url, $match);
+        if (!Preg::isMatch('#^https?://bitbucket\.org/([^/]+)/([^/]+?)(\.git|/?)?$#i', $this->url, $match)) {
+            throw new \InvalidArgumentException(sprintf('The Bitbucket repository URL %s is invalid. It must be the HTTPS URL of a Bitbucket repository.', $this->url));
+        }
+
         $this->owner = $match[1];
         $this->repository = $match[2];
         $this->originUrl = 'bitbucket.org';
         $this->cache = new Cache(
             $this->io,
-            implode('/', array(
+            implode('/', [
                 $this->config->get('cache-repo-dir'),
                 $this->originUrl,
                 $this->owner,
                 $this->repository,
-            ))
+            ])
         );
         $this->cache->setReadOnly($this->config->get('cache-read-only'));
     }
@@ -80,7 +85,7 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getUrl()
+    public function getUrl(): string
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getUrl();
@@ -93,17 +98,16 @@ class GitBitbucketDriver extends VcsDriver
      * Attempts to fetch the repository data via the BitBucket API and
      * sets some parameters which are used in other methods
      *
-     * @return bool
      * @phpstan-impure
      */
-    protected function getRepoData()
+    protected function getRepoData(): bool
     {
         $resource = sprintf(
             'https://api.bitbucket.org/2.0/repositories/%s/%s?%s',
             $this->owner,
             $this->repository,
             http_build_query(
-                array('fields' => '-project,-owner'),
+                ['fields' => '-project,-owner'],
                 '',
                 '&'
             )
@@ -122,13 +126,15 @@ class GitBitbucketDriver extends VcsDriver
         $this->website = $repoData['website'];
         $this->vcsType = $repoData['scm'];
 
+        $this->repoData = $repoData;
+
         return true;
     }
 
     /**
      * @inheritDoc
      */
-    public function getComposerInformation($identifier)
+    public function getComposerInformation(string $identifier): ?array
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getComposerInformation($identifier);
@@ -145,7 +151,7 @@ class GitBitbucketDriver extends VcsDriver
                 }
             }
 
-            if ($composer) {
+            if ($composer !== null) {
                 // specials for bitbucket
                 if (!isset($composer['support']['source'])) {
                     $label = array_search(
@@ -202,7 +208,7 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getFileContent($file, $identifier)
+    public function getFileContent(string $file, string $identifier): ?string
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getFileContent($file, $identifier);
@@ -229,7 +235,7 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getChangeDate($identifier)
+    public function getChangeDate(string $identifier): ?\DateTimeImmutable
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getChangeDate($identifier);
@@ -250,25 +256,25 @@ class GitBitbucketDriver extends VcsDriver
         );
         $commit = $this->fetchWithOAuthCredentials($resource)->decodeJson();
 
-        return new \DateTime($commit['date']);
+        return new \DateTimeImmutable($commit['date']);
     }
 
     /**
      * @inheritDoc
      */
-    public function getSource($identifier)
+    public function getSource(string $identifier): array
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getSource($identifier);
         }
 
-        return array('type' => $this->vcsType, 'url' => $this->getUrl(), 'reference' => $identifier);
+        return ['type' => $this->vcsType, 'url' => $this->getUrl(), 'reference' => $identifier];
     }
 
     /**
      * @inheritDoc
      */
-    public function getDist($identifier)
+    public function getDist(string $identifier): ?array
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getDist($identifier);
@@ -281,29 +287,29 @@ class GitBitbucketDriver extends VcsDriver
             $identifier
         );
 
-        return array('type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => '');
+        return ['type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => ''];
     }
 
     /**
      * @inheritDoc
      */
-    public function getTags()
+    public function getTags(): array
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getTags();
         }
 
         if (null === $this->tags) {
-            $tags = array();
+            $tags = [];
             $resource = sprintf(
                 '%s?%s',
                 $this->tagsUrl,
                 http_build_query(
-                    array(
+                    [
                         'pagelen' => 100,
                         'fields' => 'values.name,values.target.hash,next',
                         'sort' => '-target.date',
-                    ),
+                    ],
                     '',
                     '&'
                 )
@@ -330,23 +336,23 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getBranches()
+    public function getBranches(): array
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getBranches();
         }
 
         if (null === $this->branches) {
-            $branches = array();
+            $branches = [];
             $resource = sprintf(
                 '%s?%s',
                 $this->branchesUrl,
                 http_build_query(
-                    array(
+                    [
                         'pagelen' => 100,
                         'fields' => 'values.name,values.target.hash,values.heads,next',
                         'sort' => '-target.date',
-                    ),
+                    ],
                     '',
                     '&'
                 )
@@ -374,20 +380,19 @@ class GitBitbucketDriver extends VcsDriver
      * Get the remote content.
      *
      * @param string $url              The URL of content
-     * @param bool   $fetchingRepoData
      *
      * @return Response The result
      *
      * @phpstan-impure
      */
-    protected function fetchWithOAuthCredentials($url, $fetchingRepoData = false)
+    protected function fetchWithOAuthCredentials(string $url, bool $fetchingRepoData = false): Response
     {
         try {
             return parent::getContents($url);
         } catch (TransportException $e) {
             $bitbucketUtil = new Bitbucket($this->io, $this->config, $this->process, $this->httpDownloader);
 
-            if (403 === $e->getCode() || (401 === $e->getCode() && strpos($e->getMessage(), 'Could not authenticate against') === 0)) {
+            if (in_array($e->getCode(), [403, 404], true) || (401 === $e->getCode() && strpos($e->getMessage(), 'Could not authenticate against') === 0)) {
                 if (!$this->io->hasAuthentication($this->originUrl)
                     && $bitbucketUtil->authorizeOAuth($this->originUrl)
                 ) {
@@ -397,7 +402,7 @@ class GitBitbucketDriver extends VcsDriver
                 if (!$this->io->isInteractive() && $fetchingRepoData) {
                     $this->attemptCloneFallback();
 
-                    return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                    return new Response(['url' => 'dummy'], 200, [], 'null');
                 }
             }
 
@@ -407,10 +412,8 @@ class GitBitbucketDriver extends VcsDriver
 
     /**
      * Generate an SSH URL
-     *
-     * @return string
      */
-    protected function generateSshUrl()
+    protected function generateSshUrl(): string
     {
         return 'git@' . $this->originUrl . ':' . $this->owner.'/'.$this->repository.'.git';
     }
@@ -421,7 +424,7 @@ class GitBitbucketDriver extends VcsDriver
      * @return true
      * @throws \RuntimeException
      */
-    protected function attemptCloneFallback()
+    protected function attemptCloneFallback(): bool
     {
         try {
             $this->setupFallbackDriver($this->generateSshUrl());
@@ -438,14 +441,10 @@ class GitBitbucketDriver extends VcsDriver
         }
     }
 
-    /**
-     * @param  string $url
-     * @return void
-     */
-    protected function setupFallbackDriver($url)
+    protected function setupFallbackDriver(string $url): void
     {
         $this->fallbackDriver = new GitDriver(
-            array('url' => $url),
+            ['url' => $url],
             $this->io,
             $this->config,
             $this->httpDownloader,
@@ -456,9 +455,8 @@ class GitBitbucketDriver extends VcsDriver
 
     /**
      * @param  array<array{name: string, href: string}> $cloneLinks
-     * @return void
      */
-    protected function parseCloneUrls(array $cloneLinks)
+    protected function parseCloneUrls(array $cloneLinks): void
     {
         foreach ($cloneLinks as $cloneLink) {
             if ($cloneLink['name'] === 'https') {
@@ -469,29 +467,10 @@ class GitBitbucketDriver extends VcsDriver
         }
     }
 
-    /**
-     * @return (array{name: string}&mixed[])|null
-     */
-    protected function getMainBranchData()
-    {
-        $resource = sprintf(
-            'https://api.bitbucket.org/2.0/repositories/%s/%s?fields=mainbranch',
-            $this->owner,
-            $this->repository
-        );
-
-        $data = $this->fetchWithOAuthCredentials($resource)->decodeJson();
-        if (isset($data['mainbranch'])) {
-            return $data['mainbranch'];
-        }
-
-        return null;
-    }
-
     /**
      * @inheritDoc
      */
-    public function getRootIdentifier()
+    public function getRootIdentifier(): string
     {
         if ($this->fallbackDriver) {
             return $this->fallbackDriver->getRootIdentifier();
@@ -514,8 +493,7 @@ class GitBitbucketDriver extends VcsDriver
                 );
             }
 
-            $mainBranchData = $this->getMainBranchData();
-            $this->rootIdentifier = !empty($mainBranchData['name']) ? $mainBranchData['name'] : 'master';
+            $this->rootIdentifier = $this->repoData['mainbranch']['name'] ?? 'master';
         }
 
         return $this->rootIdentifier;
@@ -524,7 +502,7 @@ class GitBitbucketDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public static function supports(IOInterface $io, Config $config, $url, $deep = false)
+    public static function supports(IOInterface $io, Config $config, string $url, bool $deep = false): bool
     {
         if (!Preg::isMatch('#^https?://bitbucket\.org/([^/]+)/([^/]+?)(\.git|/?)?$#i', $url)) {
             return false;
