@@ -13,7 +13,6 @@
 namespace Composer\Repository\Vcs;
 
 use Composer\Pcre\Preg;
-use Composer\Util\Platform;
 use Composer\Util\ProcessExecutor;
 use Composer\Util\Filesystem;
 use Composer\Util\Url;
@@ -95,12 +94,14 @@ class GitDriver extends VcsDriver
             $this->rootIdentifier = 'master';
 
             $gitUtil = new GitUtil($this->io, $this->config, $this->process, new Filesystem());
-            $defaultBranch = $gitUtil->getMirrorDefaultBranch($this->url, $this->repoDir, Filesystem::isLocalPath($this->url));
-            if ($defaultBranch !== null) {
-                return $this->rootIdentifier = $defaultBranch;
+            if (!Filesystem::isLocalPath($this->url)) {
+                $defaultBranch = $gitUtil->getMirrorDefaultBranch($this->url, $this->repoDir, false);
+                if ($defaultBranch !== null) {
+                    return $this->rootIdentifier = $defaultBranch;
+                }
             }
 
-            // select currently checked out branch if master is not available
+            // select currently checked out branch as default branch
             $this->process->execute('git branch --no-color', $output, $this->repoDir);
             $branches = $this->process->splitLines($output);
             if (!in_array('* master', $branches)) {
@@ -129,7 +130,7 @@ class GitDriver extends VcsDriver
      */
     public function getSource(string $identifier): array
     {
-        return array('type' => 'git', 'url' => $this->getUrl(), 'reference' => $identifier);
+        return ['type' => 'git', 'url' => $this->getUrl(), 'reference' => $identifier];
     }
 
     /**
@@ -178,7 +179,7 @@ class GitDriver extends VcsDriver
     public function getTags(): array
     {
         if (null === $this->tags) {
-            $this->tags = array();
+            $this->tags = [];
 
             $this->process->execute('git show-ref --tags --dereference', $output, $this->repoDir);
             foreach ($output = $this->process->splitLines($output) as $tag) {
@@ -197,7 +198,7 @@ class GitDriver extends VcsDriver
     public function getBranches(): array
     {
         if (null === $this->branches) {
-            $branches = array();
+            $branches = [];
 
             $this->process->execute('git branch --no-color --no-abbrev -v', $output, $this->repoDir);
             foreach ($this->process->splitLines($output) as $branch) {
@@ -245,7 +246,7 @@ class GitDriver extends VcsDriver
         GitUtil::cleanEnv();
 
         try {
-            $gitUtil->runCommand(function ($url): string {
+            $gitUtil->runCommand(static function ($url): string {
                 return 'git ls-remote --heads -- ' . ProcessExecutor::escape($url);
             }, $url, sys_get_temp_dir());
         } catch (\RuntimeException $e) {
