@@ -59,7 +59,7 @@ class GitHubDriver extends VcsDriver
      */
     public function initialize(): void
     {
-        if (!Preg::isMatch('#^(?:(?:https?|git)://([^/]+)/|git@([^:]+):/?)([^/]+)/(.+?)(?:\.git|/)?$#', $this->url, $match)) {
+        if (!Preg::isMatch('#^(?:(?:https?|git)://([^/]+)/|git@([^:]+):/?)([^/]+)/([^/]+?)(?:\.git|/)?$#', $this->url, $match)) {
             throw new \InvalidArgumentException(sprintf('The GitHub repository URL %s is invalid.', $this->url));
         }
 
@@ -81,9 +81,6 @@ class GitHubDriver extends VcsDriver
         $this->fetchRootIdentifier();
     }
 
-    /**
-     * @return string
-     */
     public function getRepositoryUrl(): string
     {
         return 'https://'.$this->originUrl.'/'.$this->owner.'/'.$this->repository;
@@ -113,9 +110,6 @@ class GitHubDriver extends VcsDriver
         return 'https://' . $this->originUrl . '/'.$this->owner.'/'.$this->repository.'.git';
     }
 
-    /**
-     * @return string
-     */
     protected function getApiUrl(): string
     {
         if ('github.com' === $this->originUrl) {
@@ -143,7 +137,7 @@ class GitHubDriver extends VcsDriver
             $url = $this->getUrl();
         }
 
-        return array('type' => 'git', 'url' => $url, 'reference' => $identifier);
+        return ['type' => 'git', 'url' => $url, 'reference' => $identifier];
     }
 
     /**
@@ -153,7 +147,7 @@ class GitHubDriver extends VcsDriver
     {
         $url = $this->getApiUrl() . '/repos/'.$this->owner.'/'.$this->repository.'/zipball/'.$identifier;
 
-        return array('type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => '');
+        return ['type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => ''];
     }
 
     /**
@@ -212,11 +206,11 @@ class GitHubDriver extends VcsDriver
             return $this->fundingInfo = false;
         }
 
-        foreach (array($this->getApiUrl() . '/repos/'.$this->owner.'/'.$this->repository.'/contents/.github/FUNDING.yml', $this->getApiUrl() . '/repos/'.$this->owner.'/.github/contents/FUNDING.yml') as $file) {
+        foreach ([$this->getApiUrl() . '/repos/'.$this->owner.'/'.$this->repository.'/contents/.github/FUNDING.yml', $this->getApiUrl() . '/repos/'.$this->owner.'/.github/contents/FUNDING.yml'] as $file) {
             try {
-                $response = $this->httpDownloader->get($file, array(
+                $response = $this->httpDownloader->get($file, [
                     'retry-auth-failure' => false,
-                ))->decodeJson();
+                ])->decodeJson();
             } catch (TransportException $e) {
                 continue;
             }
@@ -229,7 +223,7 @@ class GitHubDriver extends VcsDriver
             return $this->fundingInfo = false;
         }
 
-        $result = array();
+        $result = [];
         $key = null;
         foreach (Preg::split('{\r?\n}', $funding) as $line) {
             $line = trim($line);
@@ -240,10 +234,10 @@ class GitHubDriver extends VcsDriver
                 }
                 if (Preg::isMatch('{^\[(.*)\](?:\s*#.*)?$}', $match[2], $match2)) {
                     foreach (array_map('trim', Preg::split('{[\'"]?\s*,\s*[\'"]?}', $match2[1])) as $item) {
-                        $result[] = array('type' => $match[1], 'url' => trim($item, '"\' '));
+                        $result[] = ['type' => $match[1], 'url' => trim($item, '"\' ')];
                     }
                 } elseif (Preg::isMatch('{^([^#].*?)(\s+#.*)?$}', $match[2], $match2)) {
-                    $result[] = array('type' => $match[1], 'url' => trim($match2[1], '"\' '));
+                    $result[] = ['type' => $match[1], 'url' => trim($match2[1], '"\' ')];
                 }
                 $key = null;
             } elseif (Preg::isMatch('{^(\w+)\s*:\s*#\s*$}', $line, $match)) {
@@ -252,7 +246,7 @@ class GitHubDriver extends VcsDriver
                 Preg::isMatch('{^-\s*(.+)(\s+#.*)?$}', $line, $match)
                 || Preg::isMatch('{^(.+),(\s*#.*)?$}', $line, $match)
             )) {
-                $result[] = array('type' => $key, 'url' => trim($match[1], '"\' '));
+                $result[] = ['type' => $key, 'url' => trim($match[1], '"\' ')];
             } elseif ($key && $line === ']') {
                 $key = null;
             }
@@ -342,7 +336,7 @@ class GitHubDriver extends VcsDriver
             return $this->gitDriver->getTags();
         }
         if (null === $this->tags) {
-            $tags = array();
+            $tags = [];
             $resource = $this->getApiUrl() . '/repos/'.$this->owner.'/'.$this->repository.'/tags?per_page=100';
 
             do {
@@ -370,7 +364,7 @@ class GitHubDriver extends VcsDriver
             return $this->gitDriver->getBranches();
         }
         if (null === $this->branches) {
-            $branches = array();
+            $branches = [];
             $resource = $this->getApiUrl() . '/repos/'.$this->owner.'/'.$this->repository.'/git/refs/heads?per_page=100';
 
             do {
@@ -397,7 +391,7 @@ class GitHubDriver extends VcsDriver
      */
     public static function supports(IOInterface $io, Config $config, string $url, bool $deep = false): bool
     {
-        if (!Preg::isMatch('#^((?:https?|git)://([^/]+)/|git@([^:]+):/?)([^/]+)/(.+?)(?:\.git|/)?$#', $url, $matches)) {
+        if (!Preg::isMatch('#^((?:https?|git)://([^/]+)/|git@([^:]+):/?)([^/]+)/([^/]+?)(?:\.git|/)?$#', $url, $matches)) {
             return false;
         }
 
@@ -429,8 +423,6 @@ class GitHubDriver extends VcsDriver
 
     /**
      * Generate an SSH URL
-     *
-     * @return string
      */
     protected function generateSshUrl(): string
     {
@@ -443,8 +435,6 @@ class GitHubDriver extends VcsDriver
 
     /**
      * @inheritDoc
-     *
-     * @param bool $fetchingRepoData
      */
     protected function getContents(string $url, bool $fetchingRepoData = false): Response
     {
@@ -468,11 +458,11 @@ class GitHubDriver extends VcsDriver
                     if (!$this->io->isInteractive()) {
                         $this->attemptCloneFallback();
 
-                        return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                        return new Response(['url' => 'dummy'], 200, [], 'null');
                     }
 
-                    $scopesIssued = array();
-                    $scopesNeeded = array();
+                    $scopesIssued = [];
+                    $scopesNeeded = [];
                     if ($headers = $e->getHeaders()) {
                         if ($scopes = Response::findHeaderValue($headers, 'X-OAuth-Scopes')) {
                             $scopesIssued = explode(' ', $scopes);
@@ -498,7 +488,7 @@ class GitHubDriver extends VcsDriver
                     if (!$this->io->isInteractive() && $fetchingRepoData) {
                         $this->attemptCloneFallback();
 
-                        return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                        return new Response(['url' => 'dummy'], 200, [], 'null');
                     }
 
                     $rateLimited = $gitHubUtil->isRateLimited((array) $e->getHeaders());
@@ -534,7 +524,6 @@ class GitHubDriver extends VcsDriver
     /**
      * Fetch root identifier from GitHub
      *
-     * @return void
      * @throws TransportException
      */
     protected function fetchRootIdentifier(): void
@@ -599,15 +588,10 @@ class GitHubDriver extends VcsDriver
         }
     }
 
-    /**
-     * @param string $url
-     *
-     * @return void
-     */
     protected function setupGitDriver(string $url): void
     {
         $this->gitDriver = new GitDriver(
-            array('url' => $url),
+            ['url' => $url],
             $this->io,
             $this->config,
             $this->httpDownloader,
@@ -616,9 +600,6 @@ class GitHubDriver extends VcsDriver
         $this->gitDriver->initialize();
     }
 
-    /**
-     * @return string|null
-     */
     protected function getNextPage(Response $response): ?string
     {
         $header = $response->getHeader('link');
