@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -48,12 +48,12 @@ class GitLabDriver extends VcsDriver
     /**
      * @var array<string|int, mixed[]> Keeps commits returned by GitLab API as commit id => info
      */
-    private $commits = array();
+    private $commits = [];
 
-    /** @var array<string, string> Map of tag name to identifier */
+    /** @var array<int|string, string> Map of tag name to identifier */
     private $tags;
 
-    /** @var array<string, string> Map of branch name to identifier */
+    /** @var array<int|string, string> Map of branch name to identifier */
     private $branches;
 
     /**
@@ -82,7 +82,7 @@ class GitLabDriver extends VcsDriver
      */
     private $hasNonstandardOrigin = false;
 
-    const URL_REGEX = '#^(?:(?P<scheme>https?)://(?P<domain>.+?)(?::(?P<port>[0-9]+))?/|git@(?P<domain2>[^:]+):)(?P<parts>.+)/(?P<repo>[^/]+?)(?:\.git|/)?$#';
+    public const URL_REGEX = '#^(?:(?P<scheme>https?)://(?P<domain>.+?)(?::(?P<port>[0-9]+))?/|git@(?P<domain2>[^:]+):)(?P<parts>.+)/(?P<repo>[^/]+?)(?:\.git|/)?$#';
 
     /**
      * Extracts information from the repository url.
@@ -91,10 +91,10 @@ class GitLabDriver extends VcsDriver
      *
      * @inheritDoc
      */
-    public function initialize()
+    public function initialize(): void
     {
         if (!Preg::isMatch(self::URL_REGEX, $this->url, $match)) {
-            throw new \InvalidArgumentException('The URL provided is invalid. It must be the HTTP URL of a GitLab project.');
+            throw new \InvalidArgumentException(sprintf('The GitLab repository URL %s is invalid. It must be the HTTP URL of a GitLab project.', $this->url));
         }
 
         $guessedDomain = !empty($match['domain']) ? $match['domain'] : $match['domain2'];
@@ -105,11 +105,15 @@ class GitLabDriver extends VcsDriver
             ? $match['scheme']
             : (isset($this->repoConfig['secure-http']) && $this->repoConfig['secure-http'] === false ? 'http' : 'https')
         ;
-        $this->originUrl = self::determineOrigin($configuredDomains, $guessedDomain, $urlParts, $match['port']);
+        $origin = self::determineOrigin($configuredDomains, $guessedDomain, $urlParts, $match['port']);
+        if (false === $origin) {
+            throw new \LogicException('It should not be possible to create a gitlab driver with an unparseable origin URL ('.$this->url.')');
+        }
+        $this->originUrl = $origin;
 
-        if ($protocol = $this->config->get('gitlab-protocol')) {
+        if (is_string($protocol = $this->config->get('gitlab-protocol'))) {
             // https treated as a synonym for http.
-            if (!in_array($protocol, array('git', 'http', 'https'))) {
+            if (!in_array($protocol, ['git', 'http', 'https'])) {
                 throw new \RuntimeException('gitlab-protocol must be one of git, http.');
             }
             $this->protocol = $protocol === 'git' ? 'ssh' : 'http';
@@ -133,10 +137,8 @@ class GitLabDriver extends VcsDriver
      * Mainly useful for tests.
      *
      * @internal
-     *
-     * @return void
      */
-    public function setHttpDownloader(HttpDownloader $httpDownloader)
+    public function setHttpDownloader(HttpDownloader $httpDownloader): void
     {
         $this->httpDownloader = $httpDownloader;
     }
@@ -144,7 +146,7 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getComposerInformation($identifier)
+    public function getComposerInformation(string $identifier): ?array
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getComposerInformation($identifier);
@@ -161,7 +163,7 @@ class GitLabDriver extends VcsDriver
                 }
             }
 
-            if ($composer) {
+            if (null !== $composer) {
                 // specials for gitlab (this data is only available if authentication is provided)
                 if (!isset($composer['support']['source']) && isset($this->project['web_url'])) {
                     $label = array_search($identifier, $this->getTags(), true) ?: array_search($identifier, $this->getBranches(), true) ?: $identifier;
@@ -184,7 +186,7 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getFileContent($file, $identifier)
+    public function getFileContent(string $file, string $identifier): ?string
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getFileContent($file, $identifier);
@@ -216,23 +218,20 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getChangeDate($identifier)
+    public function getChangeDate(string $identifier): ?\DateTimeImmutable
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getChangeDate($identifier);
         }
 
         if (isset($this->commits[$identifier])) {
-            return new \DateTime($this->commits[$identifier]['committed_date']);
+            return new \DateTimeImmutable($this->commits[$identifier]['committed_date']);
         }
 
-        return new \DateTime();
+        return null;
     }
 
-    /**
-     * @return string
-     */
-    public function getRepositoryUrl()
+    public function getRepositoryUrl(): string
     {
         if ($this->protocol) {
             return $this->project["{$this->protocol}_url_to_repo"];
@@ -244,7 +243,7 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getUrl()
+    public function getUrl(): string
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getUrl();
@@ -256,29 +255,29 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getDist($identifier)
+    public function getDist(string $identifier): ?array
     {
         $url = $this->getApiUrl().'/repository/archive.zip?sha='.$identifier;
 
-        return array('type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => '');
+        return ['type' => 'zip', 'url' => $url, 'reference' => $identifier, 'shasum' => ''];
     }
 
     /**
      * @inheritDoc
      */
-    public function getSource($identifier)
+    public function getSource(string $identifier): array
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getSource($identifier);
         }
 
-        return array('type' => 'git', 'url' => $this->getRepositoryUrl(), 'reference' => $identifier);
+        return ['type' => 'git', 'url' => $this->getRepositoryUrl(), 'reference' => $identifier];
     }
 
     /**
      * @inheritDoc
      */
-    public function getRootIdentifier()
+    public function getRootIdentifier(): string
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getRootIdentifier();
@@ -290,13 +289,13 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getBranches()
+    public function getBranches(): array
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getBranches();
         }
 
-        if (!$this->branches) {
+        if (null === $this->branches) {
             $this->branches = $this->getReferences('branches');
         }
 
@@ -306,13 +305,13 @@ class GitLabDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getTags()
+    public function getTags(): array
     {
         if ($this->gitDriver) {
             return $this->gitDriver->getTags();
         }
 
-        if (!$this->tags) {
+        if (null === $this->tags) {
             $this->tags = $this->getReferences('tags');
         }
 
@@ -322,23 +321,20 @@ class GitLabDriver extends VcsDriver
     /**
      * @return string Base URL for GitLab API v3
      */
-    public function getApiUrl()
+    public function getApiUrl(): string
     {
         return $this->scheme.'://'.$this->originUrl.'/api/v4/projects/'.$this->urlEncodeAll($this->namespace).'%2F'.$this->urlEncodeAll($this->repository);
     }
 
     /**
      * Urlencode all non alphanumeric characters. rawurlencode() can not be used as it does not encode `.`
-     *
-     * @param  string $string
-     * @return string
      */
-    private function urlEncodeAll($string)
+    private function urlEncodeAll(string $string): string
     {
         $encoded = '';
         for ($i = 0; isset($string[$i]); $i++) {
             $character = $string[$i];
-            if (!ctype_alnum($character) && !in_array($character, array('-', '_'), true)) {
+            if (!ctype_alnum($character) && !in_array($character, ['-', '_'], true)) {
                 $character = '%' . sprintf('%02X', ord($character));
             }
             $encoded .= $character;
@@ -348,16 +344,14 @@ class GitLabDriver extends VcsDriver
     }
 
     /**
-     * @param string $type
-     *
      * @return string[] where keys are named references like tags or branches and the value a sha
      */
-    protected function getReferences($type)
+    protected function getReferences(string $type): array
     {
         $perPage = 100;
         $resource = $this->getApiUrl().'/repository/'.$type.'?per_page='.$perPage;
 
-        $references = array();
+        $references = [];
         do {
             $response = $this->getContents($resource);
             $data = $response->decodeJson();
@@ -380,10 +374,7 @@ class GitLabDriver extends VcsDriver
         return $references;
     }
 
-    /**
-     * @return void
-     */
-    protected function fetchProject()
+    protected function fetchProject(): void
     {
         // we need to fetch the default branch from the api
         $resource = $this->getApiUrl();
@@ -402,7 +393,7 @@ class GitLabDriver extends VcsDriver
      * @return true
      * @throws \RuntimeException
      */
-    protected function attemptCloneFallback()
+    protected function attemptCloneFallback(): bool
     {
         if ($this->isPrivate === false) {
             $url = $this->generatePublicUrl();
@@ -427,10 +418,8 @@ class GitLabDriver extends VcsDriver
 
     /**
      * Generate an SSH URL
-     *
-     * @return string
      */
-    protected function generateSshUrl()
+    protected function generateSshUrl(): string
     {
         if ($this->hasNonstandardOrigin) {
             return 'ssh://git@'.$this->originUrl.'/'.$this->namespace.'/'.$this->repository.'.git';
@@ -439,23 +428,15 @@ class GitLabDriver extends VcsDriver
         return 'git@' . $this->originUrl . ':'.$this->namespace.'/'.$this->repository.'.git';
     }
 
-    /**
-     * @return string
-     */
-    protected function generatePublicUrl()
+    protected function generatePublicUrl(): string
     {
         return $this->scheme . '://' . $this->originUrl . '/'.$this->namespace.'/'.$this->repository.'.git';
     }
 
-    /**
-     * @param string $url
-     *
-     * @return void
-     */
-    protected function setupGitDriver($url)
+    protected function setupGitDriver(string $url): void
     {
         $this->gitDriver = new GitDriver(
-            array('url' => $url),
+            ['url' => $url],
             $this->io,
             $this->config,
             $this->httpDownloader,
@@ -466,10 +447,8 @@ class GitLabDriver extends VcsDriver
 
     /**
      * @inheritDoc
-     *
-     * @param bool $fetchingRepoData
      */
-    protected function getContents($url, $fetchingRepoData = false)
+    protected function getContents(string $url, bool $fetchingRepoData = false): Response
     {
         try {
             $response = parent::getContents($url);
@@ -498,7 +477,7 @@ class GitLabDriver extends VcsDriver
 
                         $this->attemptCloneFallback();
 
-                        return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                        return new Response(['url' => 'dummy'], 200, [], 'null');
                     }
                 }
 
@@ -533,10 +512,14 @@ class GitLabDriver extends VcsDriver
                         return parent::getContents($url);
                     }
 
+                    if ($gitLabUtil->isOAuthExpired($this->originUrl) && $gitLabUtil->authorizeOAuthRefresh($this->scheme, $this->originUrl)) {
+                        return parent::getContents($url);
+                    }
+
                     if (!$this->io->isInteractive()) {
                         $this->attemptCloneFallback();
 
-                        return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                        return new Response(['url' => 'dummy'], 200, [], 'null');
                     }
                     $this->io->writeError('<warning>Failed to download ' . $this->namespace . '/' . $this->repository . ':' . $e->getMessage() . '</warning>');
                     $gitLabUtil->authorizeOAuthInteractively($this->scheme, $this->originUrl, 'Your credentials are required to fetch private repository metadata (<info>'.$this->url.'</info>)');
@@ -551,7 +534,7 @@ class GitLabDriver extends VcsDriver
                     if (!$this->io->isInteractive() && $fetchingRepoData) {
                         $this->attemptCloneFallback();
 
-                        return new Response(array('url' => 'dummy'), 200, array(), 'null');
+                        return new Response(['url' => 'dummy'], 200, [], 'null');
                     }
 
                     throw $e;
@@ -568,7 +551,7 @@ class GitLabDriver extends VcsDriver
      *
      * @inheritDoc
      */
-    public static function supports(IOInterface $io, Config $config, $url, $deep = false)
+    public static function supports(IOInterface $io, Config $config, string $url, bool $deep = false): bool
     {
         if (!Preg::isMatch(self::URL_REGEX, $url, $match)) {
             return false;
@@ -578,7 +561,7 @@ class GitLabDriver extends VcsDriver
         $guessedDomain = !empty($match['domain']) ? $match['domain'] : $match['domain2'];
         $urlParts = explode('/', $match['parts']);
 
-        if (false === self::determineOrigin((array) $config->get('gitlab-domains'), $guessedDomain, $urlParts, $match['port'])) {
+        if (false === self::determineOrigin($config->get('gitlab-domains'), $guessedDomain, $urlParts, $match['port'])) {
             return false;
         }
 
@@ -591,10 +574,7 @@ class GitLabDriver extends VcsDriver
         return true;
     }
 
-    /**
-     * @return string|null
-     */
-    protected function getNextPage(Response $response)
+    protected function getNextPage(Response $response): ?string
     {
         $header = $response->getHeader('link');
 
@@ -610,32 +590,31 @@ class GitLabDriver extends VcsDriver
 
     /**
      * @param  array<string> $configuredDomains
-     * @param  string        $guessedDomain
      * @param  array<string> $urlParts
      * @param string         $portNumber
      *
      * @return string|false
      */
-    private static function determineOrigin(array $configuredDomains, $guessedDomain, array &$urlParts, $portNumber)
+    private static function determineOrigin(array $configuredDomains, string $guessedDomain, array &$urlParts, ?string $portNumber)
     {
         $guessedDomain = strtolower($guessedDomain);
 
-        if (in_array($guessedDomain, $configuredDomains) || ($portNumber && in_array($guessedDomain.':'.$portNumber, $configuredDomains))) {
-            if ($portNumber) {
+        if (in_array($guessedDomain, $configuredDomains) || (null !== $portNumber && in_array($guessedDomain.':'.$portNumber, $configuredDomains))) {
+            if (null !== $portNumber) {
                 return $guessedDomain.':'.$portNumber;
             }
 
             return $guessedDomain;
         }
 
-        if ($portNumber) {
+        if (null !== $portNumber) {
             $guessedDomain .= ':'.$portNumber;
         }
 
         while (null !== ($part = array_shift($urlParts))) {
             $guessedDomain .= '/' . $part;
 
-            if (in_array($guessedDomain, $configuredDomains) || ($portNumber && in_array(Preg::replace('{:\d+}', '', $guessedDomain), $configuredDomains))) {
+            if (in_array($guessedDomain, $configuredDomains) || (null !== $portNumber && in_array(Preg::replace('{:\d+}', '', $guessedDomain), $configuredDomains))) {
                 return $guessedDomain;
             }
         }
