@@ -21,16 +21,6 @@ use Composer\Pcre\Preg;
  */
 class ComposerMirror
 {
-    /**
-     * @param string      $mirrorUrl
-     * @param string      $packageName
-     * @param string      $version
-     * @param string|null $reference
-     * @param string|null $type
-     * @param string|null $prettyVersion
-     *
-     * @return string
-     */
     public static function processUrl(string $mirrorUrl, string $packageName, string $version, ?string $reference, ?string $type, ?string $prettyVersion = null): string
     {
         if ($reference) {
@@ -38,8 +28,8 @@ class ComposerMirror
         }
         $version = strpos($version, '/') === false ? $version : md5($version);
 
-        $from = array('%package%', '%version%', '%reference%', '%type%');
-        $to = array($packageName, $version, $reference, $type);
+        $from = ['%package%', '%version%', '%reference%', '%type%'];
+        $to = [$packageName, $version, $reference, $type];
         if (null !== $prettyVersion) {
             $from[] = '%prettyVersion%';
             $to[] = $prettyVersion;
@@ -48,14 +38,6 @@ class ComposerMirror
         return str_replace($from, $to, $mirrorUrl);
     }
 
-    /**
-     * @param string      $mirrorUrl
-     * @param string      $packageName
-     * @param string      $url
-     * @param string|null $type
-     *
-     * @return string
-     */
     public static function processGitUrl(string $mirrorUrl, string $packageName, string $url, ?string $type): string
     {
         if (Preg::isMatch('#^(?:(?:https?|git)://github\.com/|git@github\.com:)([^/]+)/(.+?)(?:\.git)?$#', $url, $match)) {
@@ -67,20 +49,12 @@ class ComposerMirror
         }
 
         return str_replace(
-            array('%package%', '%normalizedUrl%', '%type%'),
-            array($packageName, $url, $type),
+            ['%package%', '%normalizedUrl%', '%type%'],
+            [$packageName, $url, $type],
             $mirrorUrl
         );
     }
 
-    /**
-     * @param string $mirrorUrl
-     * @param string $packageName
-     * @param string $url
-     * @param string $type
-     *
-     * @return string
-     */
     public static function processHgUrl(string $mirrorUrl, string $packageName, string $url, string $type): string
     {
         return self::processGitUrl($mirrorUrl, $packageName, $url, $type);
