@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -42,14 +42,10 @@ class Git
     }
 
     /**
-     * @param callable    $commandCallable
-     * @param string      $url
-     * @param string|null $cwd
-     * @param bool        $initialClone
-     *
-     * @return void
+     * @param mixed       $commandOutput  the output will be written into this var if passed by ref
+     *                                    if a callable is passed it will be used as output handler
      */
-    public function runCommand($commandCallable, $url, $cwd, $initialClone = false)
+    public function runCommand(callable $commandCallable, string $url, ?string $cwd, bool $initialClone = false, &$commandOutput = null): void
     {
         // Ensure we are allowed to use this URL by config
         $this->config->prohibitUrlByConfig($url, $this->io);
@@ -72,12 +68,9 @@ class Git
         }
 
         $protocols = $this->config->get('github-protocols');
-        if (!is_array($protocols)) {
-            throw new \RuntimeException('Config value "github-protocols" must be an array, got ' . gettype($protocols));
-        }
         // public github, autoswitch protocols
         if (Preg::isMatch('{^(?:https?|git)://' . self::getGitHubDomainsRegex($this->config) . '/(.*)}', $url, $match)) {
-            $messages = array();
+            $messages = [];
             foreach ($protocols as $protocol) {
                 if ('ssh' === $protocol) {
                     $protoUrl = "git@" . $match[1] . ":" . $match[2];
@@ -85,7 +78,7 @@ class Git
                     $protoUrl = $protocol . "://" . $match[1] . "/" . $match[2];
                 }
 
-                if (0 === $this->process->execute(call_user_func($commandCallable, $protoUrl), $ignoredOutput, $cwd)) {
+                if (0 === $this->process->execute($commandCallable($protoUrl), $commandOutput, $cwd)) {
                     return;
                 }
                 $messages[] = '- ' . $protoUrl . "\n" . Preg::replace('#^#m', '  ', $this->process->getErrorOutput());
@@ -104,11 +97,11 @@ class Git
         // if we have a private github url and the ssh protocol is disabled then we skip it and directly fallback to https
         $bypassSshForGitHub = Preg::isMatch('{^git@' . self::getGitHubDomainsRegex($this->config) . ':(.+?)\.git$}i', $url) && !in_array('ssh', $protocols, true);
 
-        $command = call_user_func($commandCallable, $url);
+        $command = $commandCallable($url);
 
         $auth = null;
-        $credentials = array();
-        if ($bypassSshForGitHub || 0 !== $this->process->execute($command, $ignoredOutput, $cwd)) {
+        $credentials = [];
+        if ($bypassSshForGitHub || 0 !== $this->process->execute($command, $commandOutput, $cwd)) {
             $errorMsg = $this->process->getErrorOutput();
             // private github repository without ssh key access, try https with auth
             if (Preg::isMatch('{^git@' . self::getGitHubDomainsRegex($this->config) . ':(.+?)\.git$}i', $url, $match)
@@ -126,12 +119,12 @@ class Git
                 if ($this->io->hasAuthentication($match[1])) {
                     $auth = $this->io->getAuthentication($match[1]);
                     $authUrl = 'https://' . rawurlencode($auth['username']) . ':' . rawurlencode($auth['password']) . '@' . $match[1] . '/' . $match[2] . '.git';
-                    $command = call_user_func($commandCallable, $authUrl);
-                    if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
+                    $command = $commandCallable($authUrl);
+                    if (0 === $this->process->execute($command, $commandOutput, $cwd)) {
                         return;
                     }
 
-                    $credentials = array(rawurlencode($auth['username']), rawurlencode($auth['password']));
+                    $credentials = [rawurlencode($auth['username']), rawurlencode($auth['password'])];
                     $errorMsg = $this->process->getErrorOutput();
                 }
             } elseif (Preg::isMatch('{^https://(bitbucket\.org)/(.*?)(?:\.git)?$}i', $url, $match)) { //bitbucket oauth
@@ -161,18 +154,18 @@ class Git
                     $auth = $this->io->getAuthentication($match[1]);
                     $authUrl = 'https://' . rawurlencode($auth['username']) . ':' . rawurlencode($auth['password']) . '@' . $match[1] . '/' . $match[2] . '.git';
 
-                    $command = call_user_func($commandCallable, $authUrl);
-                    if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
+                    $command = $commandCallable($authUrl);
+                    if (0 === $this->process->execute($command, $commandOutput, $cwd)) {
                         return;
                     }
 
-                    $credentials = array(rawurlencode($auth['username']), rawurlencode($auth['password']));
+                    $credentials = [rawurlencode($auth['username']), rawurlencode($auth['password'])];
                     $errorMsg = $this->process->getErrorOutput();
                 } else { // Falling back to ssh
                     $sshUrl = 'git@bitbucket.org:' . $match[2] . '.git';
                     $this->io->writeError('    No bitbucket authentication configured. Falling back to ssh.');
-                    $command = call_user_func($commandCallable, $sshUrl);
-                    if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
+                    $command = $commandCallable($sshUrl);
+                    if (0 === $this->process->execute($command, $commandOutput, $cwd)) {
                         return;
                     }
 
@@ -203,17 +196,17 @@ class Git
                         $authUrl = $match[1] . '://' . rawurlencode($auth['username']) . ':' . rawurlencode($auth['password']) . '@' . $match[2] . '/' . $match[3];
                     }
 
-                    $command = call_user_func($commandCallable, $authUrl);
-                    if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
+                    $command = $commandCallable($authUrl);
+                    if (0 === $this->process->execute($command, $commandOutput, $cwd)) {
                         return;
                     }
 
-                    $credentials = array(rawurlencode($auth['username']), rawurlencode($auth['password']));
+                    $credentials = [rawurlencode($auth['username']), rawurlencode($auth['password'])];
                     $errorMsg = $this->process->getErrorOutput();
                 }
             } elseif ($this->isAuthenticationFailure($url, $match)) { // private non-github/gitlab/bitbucket repo that failed to authenticate
                 if (strpos($match[2], '@')) {
-                    list($authParts, $match[2]) = explode('@', $match[2], 2);
+                    [$authParts, $match[2]] = explode('@', $match[2], 2);
                 }
 
                 $storeAuth = false;
@@ -223,25 +216,25 @@ class Git
                     $defaultUsername = null;
                     if (isset($authParts) && $authParts) {
                         if (false !== strpos($authParts, ':')) {
-                            list($defaultUsername, ) = explode(':', $authParts, 2);
+                            [$defaultUsername, ] = explode(':', $authParts, 2);
                         } else {
                             $defaultUsername = $authParts;
                         }
                     }
 
                     $this->io->writeError('    Authentication required (<info>' . $match[2] . '</info>):');
-                    $auth = array(
+                    $auth = [
                         'username' => $this->io->ask('      Username: ', $defaultUsername),
                         'password' => $this->io->askAndHideAnswer('      Password: '),
-                    );
+                    ];
                     $storeAuth = $this->config->get('store-auths');
                 }
 
-                if ($auth) {
+                if (null !== $auth) {
                     $authUrl = $match[1] . rawurlencode($auth['username']) . ':' . rawurlencode($auth['password']) . '@' . $match[2] . $match[3];
 
-                    $command = call_user_func($commandCallable, $authUrl);
-                    if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
+                    $command = $commandCallable($authUrl);
+                    if (0 === $this->process->execute($command, $commandOutput, $cwd)) {
                         $this->io->setAuthentication($match[2], $auth['username'], $auth['password']);
                         $authHelper = new AuthHelper($this->io, $this->config);
                         $authHelper->storeAuth($match[2], $storeAuth);
@@ -249,7 +242,7 @@ class Git
                         return;
                     }
 
-                    $credentials = array(rawurlencode($auth['username']), rawurlencode($auth['password']));
+                    $credentials = [rawurlencode($auth['username']), rawurlencode($auth['password'])];
                     $errorMsg = $this->process->getErrorOutput();
                 }
             }
@@ -266,13 +259,7 @@ class Git
         }
     }
 
-    /**
-     * @param string $url
-     * @param string $dir
-     *
-     * @return bool
-     */
-    public function syncMirror($url, $dir)
+    public function syncMirror(string $url, string $dir): bool
     {
         if (Platform::getEnv('COMPOSER_DISABLE_NETWORK') && Platform::getEnv('COMPOSER_DISABLE_NETWORK') !== 'prime') {
             $this->io->writeError('<warning>Aborting git mirror sync of '.$url.' as network is disabled</warning>');
@@ -283,7 +270,7 @@ class Git
         // update the repo if it is a valid git repository
         if (is_dir($dir) && 0 === $this->process->execute('git rev-parse --git-dir', $output, $dir) && trim($output) === '.') {
             try {
-                $commandCallable = function ($url) {
+                $commandCallable = static function ($url): string {
                     $sanitizedUrl = Preg::replace('{://([^@]+?):(.+?)@}', '://', $url);
 
                     return sprintf('git remote set-url origin -- %s && git remote update --prune origin && git remote set-url origin -- %s && git gc --auto', ProcessExecutor::escape($url), ProcessExecutor::escape($sanitizedUrl));
@@ -301,7 +288,7 @@ class Git
         // clean up directory and do a fresh clone into it
         $this->filesystem->removeDirectory($dir);
 
-        $commandCallable = function ($url) use ($dir) {
+        $commandCallable = static function ($url) use ($dir): string {
             return sprintf('git clone --mirror -- %s %s', ProcessExecutor::escape($url), ProcessExecutor::escape($dir));
         };
 
@@ -310,16 +297,31 @@ class Git
         return true;
     }
 
-    /**
-     * @param string $url
-     * @param string $dir
-     * @param string $ref
-     *
-     * @return bool
-     */
-    public function fetchRefOrSyncMirror($url, $dir, $ref)
+    public function fetchRefOrSyncMirror(string $url, string $dir, string $ref, string $prettyVersion = null): bool
     {
         if ($this->checkRefIsInMirror($dir, $ref)) {
+            if (Preg::isMatch('{^[a-f0-9]{40}$}', $ref) && $prettyVersion !== null) {
+                $branch = Preg::replace('{(?:^dev-|(?:\.x)?-dev$)}i', '', $prettyVersion);
+                $branches = null;
+                $tags = null;
+                if (0 === $this->process->execute('git branch', $output, $dir)) {
+                    $branches = $output;
+                }
+                if (0 === $this->process->execute('git tag', $output, $dir)) {
+                    $tags = $output;
+                }
+
+                // if the pretty version cannot be found as a branch (nor branch with 'v' in front of the branch as it may have been stripped when generating pretty name),
+                // nor as a tag, then we sync the mirror as otherwise it will likely fail during install.
+                // this can occur if a git tag gets created *after* the reference is already put into the cache, as the ref check above will then not sync the new tags
+                // see https://github.com/composer/composer/discussions/11002
+                if (null !== $branches && !Preg::isMatch('{^[\s*]*v?'.preg_quote($branch).'$}m', $branches)
+                    && null !== $tags && !Preg::isMatch('{^[\s*]*'.preg_quote($branch).'$}m', $tags)
+                ) {
+                    $this->syncMirror($url, $dir);
+                }
+            }
+
             return true;
         }
 
@@ -330,10 +332,7 @@ class Git
         return false;
     }
 
-    /**
-     * @return string
-     */
-    public static function getNoShowSignatureFlag(ProcessExecutor $process)
+    public static function getNoShowSignatureFlag(ProcessExecutor $process): string
     {
         $gitVersion = self::getVersion($process);
         if ($gitVersion && version_compare($gitVersion, '2.10.0-rc0', '>=')) {
@@ -343,13 +342,7 @@ class Git
         return '';
     }
 
-    /**
-     * @param string $dir
-     * @param string $ref
-     *
-     * @return bool
-     */
-    private function checkRefIsInMirror($dir, $ref)
+    private function checkRefIsInMirror(string $dir, string $ref): bool
     {
         if (is_dir($dir) && 0 === $this->process->execute('git rev-parse --git-dir', $output, $dir) && trim($output) === '.') {
             $escapedRef = ProcessExecutor::escape($ref.'^{commit}');
@@ -363,24 +356,21 @@ class Git
     }
 
     /**
-     * @param string   $url
      * @param string[] $match
-     *
-     * @return bool
      */
-    private function isAuthenticationFailure($url, &$match)
+    private function isAuthenticationFailure(string $url, array &$match): bool
     {
         if (!Preg::isMatch('{^(https?://)([^/]+)(.*)$}i', $url, $match)) {
             return false;
         }
 
-        $authFailures = array(
+        $authFailures = [
             'fatal: Authentication failed',
             'remote error: Invalid username or password.',
             'error: 401 Unauthorized',
             'fatal: unable to access',
             'fatal: could not read Username',
-        );
+        ];
 
         $errorOutput = $this->process->getErrorOutput();
         foreach ($authFailures as $authFailure) {
@@ -392,15 +382,40 @@ class Git
         return false;
     }
 
-    /**
-     * @return void
-     */
-    public static function cleanEnv()
+    public function getMirrorDefaultBranch(string $url, string $dir, bool $isLocalPathRepository): ?string
     {
-        if (PHP_VERSION_ID < 50400 && ini_get('safe_mode') && false === strpos(ini_get('safe_mode_allowed_env_vars'), 'GIT_ASKPASS')) {
-            throw new \RuntimeException('safe_mode is enabled and safe_mode_allowed_env_vars does not contain GIT_ASKPASS, can not set env var. You can disable safe_mode with "-dsafe_mode=0" when running composer');
+        if ((bool) Platform::getEnv('COMPOSER_DISABLE_NETWORK')) {
+            return null;
         }
 
+        try {
+            if ($isLocalPathRepository) {
+                $this->process->execute('git remote show origin', $output, $dir);
+            } else {
+                $commandCallable = static function ($url): string {
+                    $sanitizedUrl = Preg::replace('{://([^@]+?):(.+?)@}', '://', $url);
+
+                    return sprintf('git remote set-url origin -- %s && git remote show origin && git remote set-url origin -- %s', ProcessExecutor::escape($url), ProcessExecutor::escape($sanitizedUrl));
+                };
+
+                $this->runCommand($commandCallable, $url, $dir, false, $output);
+            }
+
+            $lines = $this->process->splitLines($output);
+            foreach ($lines as $line) {
+                if (Preg::match('{^\s*HEAD branch:\s(.+)\s*$}m', $line, $matches) > 0) {
+                    return $matches[1];
+                }
+            }
+        } catch (\Exception $e) {
+            $this->io->writeError('<error>Failed to fetch root identifier from remote: ' . $e->getMessage() . '</error>', true, IOInterface::DEBUG);
+        }
+
+        return null;
+    }
+
+    public static function cleanEnv(): void
+    {
         // added in git 1.7.1, prevents prompting the user for username/password
         if (Platform::getEnv('GIT_ASKPASS') !== 'echo') {
             Platform::putEnv('GIT_ASKPASS', 'echo');
@@ -426,7 +441,7 @@ class Git
     /**
      * @return non-empty-string
      */
-    public static function getGitHubDomainsRegex(Config $config)
+    public static function getGitHubDomainsRegex(Config $config): string
     {
         return '(' . implode('|', array_map('preg_quote', $config->get('github-domains'))) . ')';
     }
@@ -434,18 +449,17 @@ class Git
     /**
      * @return non-empty-string
      */
-    public static function getGitLabDomainsRegex(Config $config)
+    public static function getGitLabDomainsRegex(Config $config): string
     {
         return '(' . implode('|', array_map('preg_quote', $config->get('gitlab-domains'))) . ')';
     }
 
     /**
      * @param non-empty-string $message
-     * @param string           $url
      *
      * @return never
      */
-    private function throwException($message, $url)
+    private function throwException($message, string $url): void
     {
         // git might delete a directory when it fails and php will not know
         clearstatcache();
@@ -462,7 +476,7 @@ class Git
      *
      * @return string|null The git version number, if present.
      */
-    public static function getVersion(ProcessExecutor $process)
+    public static function getVersion(ProcessExecutor $process): ?string
     {
         if (false === self::$version) {
             self::$version = null;
@@ -475,17 +489,14 @@ class Git
     }
 
     /**
-     * @param string   $error
      * @param string[] $credentials
-     *
-     * @return string
      */
-    private function maskCredentials($error, array $credentials)
+    private function maskCredentials(string $error, array $credentials): string
     {
-        $maskedCredentials = array();
+        $maskedCredentials = [];
 
         foreach ($credentials as $credential) {
-            if (in_array($credential, array('private-token', 'x-token-auth', 'oauth2', 'gitlab-ci-token', 'x-oauth-basic'))) {
+            if (in_array($credential, ['private-token', 'x-token-auth', 'oauth2', 'gitlab-ci-token', 'x-oauth-basic'])) {
                 $maskedCredentials[] = $credential;
             } elseif (strlen($credential) > 6) {
                 $maskedCredentials[] = substr($credential, 0, 3) . '...' . substr($credential, -3);
