@@ -40,7 +40,7 @@ class GitLab
      * @param ProcessExecutor $process        Process instance, injectable for mocking
      * @param HttpDownloader  $httpDownloader Remote Filesystem, injectable for mocking
      */
-    public function __construct(IOInterface $io, Config $config, ProcessExecutor $process = null, HttpDownloader $httpDownloader = null)
+    public function __construct(IOInterface $io, Config $config, ?ProcessExecutor $process = null, ?HttpDownloader $httpDownloader = null)
     {
         $this->io = $io;
         $this->config = $config;
@@ -95,7 +95,7 @@ class GitLab
 
             // Composer expects the GitLab token to be stored as username and 'private-token' or 'gitlab-ci-token' to be stored as password
             // Detect cases where this is reversed and resolve automatically resolve it
-            if (in_array($username, array('private-token', 'gitlab-ci-token',  'oauth2'), true)) {
+            if (in_array($username, ['private-token', 'gitlab-ci-token',  'oauth2'], true)) {
                 $this->io->setAuthentication($originUrl, $password, $username);
             } else {
                 $this->io->setAuthentication($originUrl, $username, $password);
@@ -119,14 +119,15 @@ class GitLab
      *
      * @return bool true on success
      */
-    public function authorizeOAuthInteractively(string $scheme, string $originUrl, string $message = null): bool
+    public function authorizeOAuthInteractively(string $scheme, string $originUrl, ?string $message = null): bool
     {
         if ($message) {
             $this->io->writeError($message);
         }
 
         $this->io->writeError(sprintf('A token will be created and stored in "%s", your password will never be stored', $this->config->getAuthConfigSource()->getName()));
-        $this->io->writeError('To revoke access to this token you can visit '.$scheme.'://'.$originUrl.'/-/profile/personal_access_tokens');
+        $this->io->writeError('To revoke access to this token you can visit '.$scheme.'://'.$originUrl.'/-/profile/applications');
+        $this->io->writeError('Alternatively you can setup an personal access token on  '.$scheme.'://'.$originUrl.'/-/profile/personal_access_token and store it under "gitlab-token" see https://getcomposer.org/doc/articles/authentication-for-private-packages.md#gitlab-token for more details.');
 
         $attemptCounter = 0;
 
@@ -136,7 +137,7 @@ class GitLab
             } catch (TransportException $e) {
                 // 401 is bad credentials,
                 // 403 is max login attempts exceeded
-                if (in_array($e->getCode(), array(403, 401))) {
+                if (in_array($e->getCode(), [403, 401])) {
                     if (401 === $e->getCode()) {
                         $response = json_decode($e->getResponse(), true);
                         if (isset($response['error']) && $response['error'] === 'invalid_grant') {
@@ -160,7 +161,18 @@ class GitLab
             $this->io->setAuthentication($originUrl, $response['access_token'], 'oauth2');
 
             // store value in user config in auth file
-            $this->config->getAuthConfigSource()->addConfigSetting('gitlab-oauth.'.$originUrl, $response['access_token']);
+            if (isset($response['expires_in'])) {
+                $this->config->getAuthConfigSource()->addConfigSetting(
+                    'gitlab-oauth.'.$originUrl,
+                    [
+                        'expires-at' => intval($response['created_at']) + intval($response['expires_in']),
+                        'refresh-token' => $response['refresh_token'],
+                        'token' => $response['access_token'],
+                    ]
+                );
+            } else {
+                $this->config->getAuthConfigSource()->addConfigSetting('gitlab-oauth.'.$originUrl, $response['access_token']);
+            }
 
             return true;
         }
@@ -169,10 +181,43 @@ class GitLab
     }
 
     /**
-     * @param string $scheme
-     * @param string $originUrl
+     * Authorizes a GitLab domain interactively via OAuth.
      *
-     * @return array{access_token: non-empty-string, token_type: non-empty-string, expires_in: positive-int}
+     * @param string $scheme    Scheme used in the origin URL
+     * @param string $originUrl The host this GitLab instance is located at
+     *
+     * @throws \RuntimeException
+     * @throws TransportException|\Exception
+     *
+     * @return bool true on success
+     */
+    public function authorizeOAuthRefresh(string $scheme, string $originUrl): bool
+    {
+        try {
+            $response = $this->refreshToken($scheme, $originUrl);
+        } catch (TransportException $e) {
+            $this->io->writeError("Couldn't refresh access token: ".$e->getMessage());
+
+            return false;
+        }
+
+        $this->io->setAuthentication($originUrl, $response['access_token'], 'oauth2');
+
+        // store value in user config in auth file
+        $this->config->getAuthConfigSource()->addConfigSetting(
+            'gitlab-oauth.'.$originUrl,
+            [
+                'expires-at' => intval($response['created_at']) + intval($response['expires_in']),
+                'refresh-token' => $response['refresh_token'],
+                'token' => $response['access_token'],
+            ]
+        );
+
+        return true;
+    }
+
+    /**
+     * @return array{access_token: non-empty-string, refresh_token: non-empty-string, token_type: non-empty-string, expires_in?: positive-int, created_at: positive-int}
      *
      * @see https://docs.gitlab.com/ee/api/oauth2.html#resource-owner-password-credentials-flow
      */
@@ -181,22 +226,22 @@ class GitLab
         $username = $this->io->ask('Username: ');
         $password = $this->io->askAndHideAnswer('Password: ');
 
-        $headers = array('Content-Type: application/x-www-form-urlencoded');
+        $headers = ['Content-Type: application/x-www-form-urlencoded'];
 
         $apiUrl = $originUrl;
-        $data = http_build_query(array(
+        $data = http_build_query([
             'username' => $username,
             'password' => $password,
             'grant_type' => 'password',
-        ), '', '&');
-        $options = array(
+        ], '', '&');
+        $options = [
             'retry-auth-failure' => false,
-            'http' => array(
+            'http' => [
                 'method' => 'POST',
                 'header' => $headers,
                 'content' => $data,
-            ),
-        );
+            ],
+        ];
 
         $token = $this->httpDownloader->get($scheme.'://'.$apiUrl.'/oauth/token', $options)->decodeJson();
 
@@ -204,4 +249,56 @@ class GitLab
 
         return $token;
     }
+
+    /**
+     * Is the OAuth access token expired?
+     *
+     * @return bool true on expired token, false if token is fresh or expiration date is not set
+     */
+    public function isOAuthExpired(string $originUrl): bool
+    {
+        $authTokens = $this->config->get('gitlab-oauth');
+        if (isset($authTokens[$originUrl]['expires-at'])) {
+            if ($authTokens[$originUrl]['expires-at'] < time()) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    /**
+     * @return array{access_token: non-empty-string, refresh_token: non-empty-string, token_type: non-empty-string, expires_in: positive-int, created_at: positive-int}
+     *
+     * @see https://docs.gitlab.com/ee/api/oauth2.html#resource-owner-password-credentials-flow
+     */
+    private function refreshToken(string $scheme, string $originUrl): array
+    {
+        $authTokens = $this->config->get('gitlab-oauth');
+        if (!isset($authTokens[$originUrl]['refresh-token'])) {
+            throw new \RuntimeException('No GitLab refresh token present for '.$originUrl.'.');
+        }
+
+        $refreshToken = $authTokens[$originUrl]['refresh-token'];
+        $headers = ['Content-Type: application/x-www-form-urlencoded'];
+
+        $data = http_build_query([
+            'refresh_token' => $refreshToken,
+            'grant_type' => 'refresh_token',
+        ], '', '&');
+        $options = [
+            'retry-auth-failure' => false,
+            'http' => [
+                'method' => 'POST',
+                'header' => $headers,
+                'content' => $data,
+            ],
+        ];
+
+        $token = $this->httpDownloader->get($scheme.'://'.$originUrl.'/oauth/token', $options)->decodeJson();
+        $this->io->writeError('GitLab token successfully refreshed', true, IOInterface::VERY_VERBOSE);
+        $this->io->writeError('To revoke access to this token you can visit '.$scheme.'://'.$originUrl.'/-/profile/applications', true, IOInterface::VERY_VERBOSE);
+
+        return $token;
+    }
 }
