@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -46,19 +46,12 @@ class Hg
         $this->process = $process;
     }
 
-    /**
-     * @param callable    $commandCallable
-     * @param string      $url
-     * @param string|null $cwd
-     *
-     * @return void
-     */
-    public function runCommand($commandCallable, $url, $cwd)
+    public function runCommand(callable $commandCallable, string $url, ?string $cwd): void
     {
         $this->config->prohibitUrlByConfig($url, $this->io);
 
         // Try as is
-        $command = call_user_func($commandCallable, $url);
+        $command = $commandCallable($url);
 
         if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
             return;
@@ -69,7 +62,7 @@ class Hg
             $auth = $this->io->getAuthentication($match[5]);
             $authenticatedUrl = $match[1] . '://' . rawurlencode($auth['username']) . ':' . rawurlencode($auth['password']) . '@' . $match[5] . (!empty($match[6]) ? $match[6] : null);
 
-            $command = call_user_func($commandCallable, $authenticatedUrl);
+            $command = $commandCallable($authenticatedUrl);
 
             if (0 === $this->process->execute($command, $ignoredOutput, $cwd)) {
                 return;
@@ -85,11 +78,10 @@ class Hg
 
     /**
      * @param non-empty-string $message
-     * @param string           $url
      *
      * @return never
      */
-    private function throwException($message, $url)
+    private function throwException($message, string $url): void
     {
         if (null === self::getVersion($this->process)) {
             throw new \RuntimeException(Url::sanitize('Failed to clone ' . $url . ', hg was not found, check that it is installed and in your PATH env.' . "\n\n" . $this->process->getErrorOutput()));
@@ -103,11 +95,11 @@ class Hg
      *
      * @return string|null The hg version number, if present.
      */
-    public static function getVersion(ProcessExecutor $process)
+    public static function getVersion(ProcessExecutor $process): ?string
     {
         if (false === self::$version) {
             self::$version = null;
-            if (0 === $process->execute('hg --version', $output) && Preg::isMatch('/^.+? (\d+(?:\.\d+)+)\)?\r?\n/', $output, $matches)) {
+            if (0 === $process->execute('hg --version', $output) && Preg::isMatch('/^.+? (\d+(?:\.\d+)+)(?:\+.*?)?\)?\r?\n/', $output, $matches)) {
                 self::$version = $matches[1];
             }
         }
