@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -25,18 +25,16 @@ class Response
     private $request;
     /** @var int */
     private $code;
-    /** @var string[] */
+    /** @var list<string> */
     private $headers;
     /** @var ?string */
     private $body;
 
     /**
-     * @param Request  $request
-     * @param int      $code
-     * @param string[] $headers
-     * @param ?string  $body
+     * @param Request      $request
+     * @param list<string> $headers
      */
-    public function __construct(array $request, $code, array $headers, $body)
+    public function __construct(array $request, ?int $code, array $headers, ?string $body)
     {
         if (!isset($request['url'])) { // @phpstan-ignore-line
             throw new \LogicException('url key missing from request array');
@@ -47,18 +45,12 @@ class Response
         $this->body = $body;
     }
 
-    /**
-     * @return int
-     */
-    public function getStatusCode()
+    public function getStatusCode(): int
     {
         return $this->code;
     }
 
-    /**
-     * @return string|null
-     */
-    public function getStatusMessage()
+    public function getStatusMessage(): ?string
     {
         $value = null;
         foreach ($this->headers as $header) {
@@ -75,16 +67,15 @@ class Response
     /**
      * @return string[]
      */
-    public function getHeaders()
+    public function getHeaders(): array
     {
         return $this->headers;
     }
 
     /**
-     * @param  string  $name
      * @return ?string
      */
-    public function getHeader($name)
+    public function getHeader(string $name): ?string
     {
         return self::findHeaderValue($this->headers, $name);
     }
@@ -92,7 +83,7 @@ class Response
     /**
      * @return ?string
      */
-    public function getBody()
+    public function getBody(): ?string
     {
         return $this->body;
     }
@@ -106,10 +97,9 @@ class Response
     }
 
     /**
-     * @return void
      * @phpstan-impure
      */
-    public function collect()
+    public function collect(): void
     {
         /** @phpstan-ignore-next-line */
         $this->request = $this->code = $this->headers = $this->body = null;
@@ -118,9 +108,8 @@ class Response
     /**
      * @param  string[]    $headers array of returned headers like from getLastHeaders()
      * @param  string      $name    header name (case insensitive)
-     * @return string|null
      */
-    public static function findHeaderValue(array $headers, $name)
+    public static function findHeaderValue(array $headers, string $name): ?string
     {
         $value = null;
         foreach ($headers as $header) {
