@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -32,20 +32,20 @@ use React\Promise\PromiseInterface;
  */
 class HttpDownloader
 {
-    const STATUS_QUEUED = 1;
-    const STATUS_STARTED = 2;
-    const STATUS_COMPLETED = 3;
-    const STATUS_FAILED = 4;
-    const STATUS_ABORTED = 5;
+    private const STATUS_QUEUED = 1;
+    private const STATUS_STARTED = 2;
+    private const STATUS_COMPLETED = 3;
+    private const STATUS_FAILED = 4;
+    private const STATUS_ABORTED = 5;
 
     /** @var IOInterface */
     private $io;
     /** @var Config */
     private $config;
     /** @var array<Job> */
-    private $jobs = array();
+    private $jobs = [];
     /** @var mixed[] */
-    private $options = array();
+    private $options = [];
     /** @var int */
     private $runningJobs = 0;
     /** @var int */
@@ -65,9 +65,8 @@ class HttpDownloader
      * @param IOInterface $io         The IO instance
      * @param Config      $config     The config
      * @param mixed[]     $options    The options
-     * @param bool        $disableTls
      */
-    public function __construct(IOInterface $io, Config $config, array $options = array(), $disableTls = false)
+    public function __construct(IOInterface $io, Config $config, array $options = [], bool $disableTls = false)
     {
         $this->io = $io;
 
@@ -103,31 +102,13 @@ class HttpDownloader
      * @throws TransportException
      * @return Response
      */
-    public function get($url, $options = array())
+    public function get(string $url, array $options = [])
     {
-        list($job) = $this->addJob(array('url' => $url, 'options' => $options, 'copyTo' => null), true);
+        [$job] = $this->addJob(['url' => $url, 'options' => $options, 'copyTo' => null], true);
         $this->wait($job['id']);
 
         $response = $this->getResponse($job['id']);
 
-        // check for failed curl response (empty body but successful looking response)
-        if (
-            $this->curl
-            && PHP_VERSION_ID < 70000
-            && $response->getBody() === null
-            && $response->getStatusCode() === 200
-            && $response->getHeader('content-length') !== '0'
-        ) {
-            $this->io->writeError('<warning>cURL downloader failed to return a response, disabling it and proceeding in slow mode.</warning>');
-
-            $this->curl = null;
-
-            list($job) = $this->addJob(array('url' => $url, 'options' => $options, 'copyTo' => null), true);
-            $this->wait($job['id']);
-
-            $response = $this->getResponse($job['id']);
-        }
-
         return $response;
     }
 
@@ -140,9 +121,9 @@ class HttpDownloader
      * @throws TransportException
      * @return PromiseInterface
      */
-    public function add($url, $options = array())
+    public function add(string $url, array $options = [])
     {
-        list(, $promise) = $this->addJob(array('url' => $url, 'options' => $options, 'copyTo' => null));
+        [, $promise] = $this->addJob(['url' => $url, 'options' => $options, 'copyTo' => null]);
 
         return $promise;
     }
@@ -157,9 +138,9 @@ class HttpDownloader
      * @throws TransportException
      * @return Response
      */
-    public function copy($url, $to, $options = array())
+    public function copy(string $url, string $to, array $options = [])
     {
-        list($job) = $this->addJob(array('url' => $url, 'options' => $options, 'copyTo' => $to), true);
+        [$job] = $this->addJob(['url' => $url, 'options' => $options, 'copyTo' => $to], true);
         $this->wait($job['id']);
 
         return $this->getResponse($job['id']);
@@ -175,9 +156,9 @@ class HttpDownloader
      * @throws TransportException
      * @return PromiseInterface
      */
-    public function addCopy($url, $to, $options = array())
+    public function addCopy(string $url, string $to, array $options = [])
     {
-        list(, $promise) = $this->addJob(array('url' => $url, 'options' => $options, 'copyTo' => $to));
+        [, $promise] = $this->addJob(['url' => $url, 'options' => $options, 'copyTo' => $to]);
 
         return $promise;
     }
@@ -204,23 +185,21 @@ class HttpDownloader
     }
 
     /**
-     * @param Request $request
-     * @param bool    $sync
-     *
+     * @phpstan-param Request $request
      * @return array{Job, PromiseInterface}
      */
-    private function addJob($request, $sync = false)
+    private function addJob(array $request, bool $sync = false): array
     {
         $request['options'] = array_replace_recursive($this->options, $request['options']);
 
         /** @var Job */
-        $job = array(
+        $job = [
             'id' => $this->idGen++,
             'status' => self::STATUS_QUEUED,
             'request' => $request,
             'sync' => $sync,
             'origin' => Url::getOrigin($this->config, $request['url']),
-        );
+        ];
 
         if (!$sync && !$this->allowAsync) {
             throw new \LogicException('You must use the HttpDownloader instance which is part of a Composer\Loop instance to be able to run async http requests');
@@ -234,13 +213,13 @@ class HttpDownloader
         $rfs = $this->rfs;
 
         if ($this->canUseCurl($job)) {
-            $resolver = function ($resolve, $reject) use (&$job) {
+            $resolver = static function ($resolve, $reject) use (&$job): void {
                 $job['status'] = HttpDownloader::STATUS_QUEUED;
                 $job['resolve'] = $resolve;
                 $job['reject'] = $reject;
             };
         } else {
-            $resolver = function ($resolve, $reject) use (&$job, $rfs) {
+            $resolver = static function ($resolve, $reject) use (&$job, $rfs): void {
                 // start job
                 $url = $job['request']['url'];
                 $options = $job['request']['options'];
@@ -264,10 +243,9 @@ class HttpDownloader
             };
         }
 
-        $downloader = $this;
         $curl = $this->curl;
 
-        $canceler = function () use (&$job, $curl) {
+        $canceler = static function () use (&$job, $curl): void {
             if ($job['status'] === HttpDownloader::STATUS_QUEUED) {
                 $job['status'] = HttpDownloader::STATUS_ABORTED;
             }
@@ -282,19 +260,18 @@ class HttpDownloader
         };
 
         $promise = new Promise($resolver, $canceler);
-        $promise = $promise->then(function ($response) use (&$job, $downloader) {
+        $promise = $promise->then(function ($response) use (&$job) {
             $job['status'] = HttpDownloader::STATUS_COMPLETED;
             $job['response'] = $response;
 
-            // TODO 3.0 this should be done directly on $this when PHP 5.3 is dropped
-            $downloader->markJobDone();
+            $this->markJobDone();
 
             return $response;
-        }, function ($e) use (&$job, $downloader) {
+        }, function ($e) use (&$job): void {
             $job['status'] = HttpDownloader::STATUS_FAILED;
             $job['exception'] = $e;
 
-            $downloader->markJobDone();
+            $this->markJobDone();
 
             throw $e;
         });
@@ -304,14 +281,10 @@ class HttpDownloader
             $this->startJob($job['id']);
         }
 
-        return array($job, $promise);
+        return [$job, $promise];
     }
 
-    /**
-     * @param  int  $id
-     * @return void
-     */
-    private function startJob($id)
+    private function startJob(int $id): void
     {
         $job = &$this->jobs[$id];
         if ($job['status'] !== self::STATUS_QUEUED) {
@@ -330,7 +303,7 @@ class HttpDownloader
 
         if ($this->disabled) {
             if (isset($job['request']['options']['http']['header']) && false !== stripos(implode('', $job['request']['options']['http']['header']), 'if-modified-since')) {
-                $resolve(new Response(array('url' => $url), 304, array(), ''));
+                $resolve(new Response(['url' => $url], 304, [], ''));
             } else {
                 $e = new TransportException('Network disabled, request canceled: '.Url::sanitize($url), 499);
                 $e->setStatusCode(499);
@@ -351,11 +324,7 @@ class HttpDownloader
         }
     }
 
-    /**
-     * @private
-     * @return void
-     */
-    public function markJobDone()
+    private function markJobDone(): void
     {
         $this->runningJobs--;
     }
@@ -367,7 +336,7 @@ class HttpDownloader
      *
      * @return void
      */
-    public function wait($index = null)
+    public function wait(?int $index = null)
     {
         do {
             $jobCount = $this->countActiveJobs($index);
@@ -376,10 +345,8 @@ class HttpDownloader
 
     /**
      * @internal
-     *
-     * @return void
      */
-    public function enableAsync()
+    public function enableAsync(): void
     {
         $this->allowAsync = true;
     }
@@ -390,7 +357,7 @@ class HttpDownloader
      * @param  int|null $index For internal use only, the job id
      * @return int      number of active (queued or started) jobs
      */
-    public function countActiveJobs($index = null)
+    public function countActiveJobs(?int $index = null): int
     {
         if ($this->runningJobs < $this->maxJobs) {
             foreach ($this->jobs as $job) {
@@ -422,9 +389,8 @@ class HttpDownloader
 
     /**
      * @param  int $index Job id
-     * @return Response
      */
-    private function getResponse($index)
+    private function getResponse(int $index): Response
     {
         if (!isset($this->jobs[$index])) {
             throw new \LogicException('Invalid request id');
@@ -448,14 +414,20 @@ class HttpDownloader
     /**
      * @internal
      *
-     * @param  string                                                                                    $url
      * @param  array{warning?: string, info?: string, warning-versions?: string, info-versions?: string, warnings?: array<array{versions: string, message: string}>, infos?: array<array{versions: string, message: string}>} $data
-     * @return void
      */
-    public static function outputWarnings(IOInterface $io, $url, $data)
+    public static function outputWarnings(IOInterface $io, string $url, $data): void
     {
+        $cleanMessage = static function ($msg) use ($io) {
+            if (!$io->isDecorated()) {
+                $msg = Preg::replace('{'.chr(27).'\\[[;\d]*m}u', '', $msg);
+            }
+
+            return $msg;
+        };
+
         // legacy warning/info keys
-        foreach (array('warning', 'info') as $type) {
+        foreach (['warning', 'info'] as $type) {
             if (empty($data[$type])) {
                 continue;
             }
@@ -469,11 +441,11 @@ class HttpDownloader
                 }
             }
 
-            $io->writeError('<'.$type.'>'.ucfirst($type).' from '.Url::sanitize($url).': '.$data[$type].'</'.$type.'>');
+            $io->writeError('<'.$type.'>'.ucfirst($type).' from '.Url::sanitize($url).': '.$cleanMessage($data[$type]).'</'.$type.'>');
         }
 
         // modern Composer 2.2+ format with support for multiple warning/info messages
-        foreach (array('warnings', 'infos') as $key) {
+        foreach (['warnings', 'infos'] as $key) {
             if (empty($data[$key])) {
                 continue;
             }
@@ -487,7 +459,7 @@ class HttpDownloader
                     continue;
                 }
 
-                $io->writeError('<'.$type.'>'.ucfirst($type).' from '.Url::sanitize($url).': '.$spec['message'].'</'.$type.'>');
+                $io->writeError('<'.$type.'>'.ucfirst($type).' from '.Url::sanitize($url).': '.$cleanMessage($spec['message']).'</'.$type.'>');
             }
         }
     }
@@ -497,7 +469,7 @@ class HttpDownloader
      *
      * @return ?string[]
      */
-    public static function getExceptionHints(\Exception $e)
+    public static function getExceptionHints(\Throwable $e): ?array
     {
         if (!$e instanceof TransportException) {
             return null;
@@ -508,20 +480,20 @@ class HttpDownloader
             || false !== strpos($e->getMessage(), 'Could not resolve host')
         ) {
             Silencer::suppress();
-            $testConnectivity = file_get_contents('https://8.8.8.8', false, stream_context_create(array(
-                'ssl' => array('verify_peer' => false),
-                'http' => array('follow_location' => false, 'ignore_errors' => true),
-            )));
+            $testConnectivity = file_get_contents('https://8.8.8.8', false, stream_context_create([
+                'ssl' => ['verify_peer' => false],
+                'http' => ['follow_location' => false, 'ignore_errors' => true],
+            ]));
             Silencer::restore();
             if (false !== $testConnectivity) {
-                return array(
+                return [
                     '<error>The following exception probably indicates you have misconfigured DNS resolver(s)</error>',
-                );
+                ];
             }
 
-            return array(
+            return [
                 '<error>The following exception probably indicates you are offline or have misconfigured DNS resolver(s)</error>',
-            );
+            ];
         }
 
         return null;
@@ -529,9 +501,8 @@ class HttpDownloader
 
     /**
      * @param  Job  $job
-     * @return bool
      */
-    private function canUseCurl(array $job)
+    private function canUseCurl(array $job): bool
     {
         if (!$this->curl) {
             return false;
@@ -550,9 +521,8 @@ class HttpDownloader
 
     /**
      * @internal
-     * @return bool
      */
-    public static function isCurlEnabled()
+    public static function isCurlEnabled(): bool
     {
         return \extension_loaded('curl') && \function_exists('curl_multi_exec') && \function_exists('curl_multi_init');
     }
