@@ -49,7 +49,7 @@ class RemoteFilesystem
     /** @var ?int */
     private $lastProgress;
     /** @var mixed[] */
-    private $options = array();
+    private $options = [];
     /** @var bool */
     private $disableTls = false;
     /** @var string[] */
@@ -73,10 +73,9 @@ class RemoteFilesystem
      * @param IOInterface $io         The IO instance
      * @param Config      $config     The config
      * @param mixed[]     $options    The options
-     * @param bool        $disableTls
      * @param AuthHelper  $authHelper
      */
-    public function __construct(IOInterface $io, Config $config, array $options = array(), bool $disableTls = false, AuthHelper $authHelper = null)
+    public function __construct(IOInterface $io, Config $config, array $options = [], bool $disableTls = false, ?AuthHelper $authHelper = null)
     {
         $this->io = $io;
 
@@ -106,7 +105,7 @@ class RemoteFilesystem
      *
      * @return bool true
      */
-    public function copy(string $originUrl, string $fileUrl, string $fileName, bool $progress = true, array $options = array())
+    public function copy(string $originUrl, string $fileUrl, string $fileName, bool $progress = true, array $options = [])
     {
         return $this->get($originUrl, $fileUrl, $options, $fileName, $progress);
     }
@@ -121,7 +120,7 @@ class RemoteFilesystem
      *
      * @return bool|string The content
      */
-    public function getContents(string $originUrl, string $fileUrl, bool $progress = true, array $options = array())
+    public function getContents(string $originUrl, string $fileUrl, bool $progress = true, array $options = [])
     {
         return $this->get($originUrl, $fileUrl, $options, null, $progress);
     }
@@ -217,7 +216,7 @@ class RemoteFilesystem
      *
      * @return bool|string
      */
-    protected function get(string $originUrl, string $fileUrl, array $additionalOptions = array(), string $fileName = null, bool $progress = true)
+    protected function get(string $originUrl, string $fileUrl, array $additionalOptions = [], ?string $fileName = null, bool $progress = true)
     {
         $this->scheme = parse_url(strtr($fileUrl, '\\', '/'), PHP_URL_SCHEME);
         $this->bytesMax = 0;
@@ -227,7 +226,7 @@ class RemoteFilesystem
         $this->progress = $progress;
         $this->lastProgress = null;
         $retryAuthFailure = true;
-        $this->lastHeaders = array();
+        $this->lastHeaders = [];
         $this->redirects = 1; // The first request counts.
 
         $tempAdditionalOptions = $additionalOptions;
@@ -271,7 +270,7 @@ class RemoteFilesystem
             unset($options['max_file_size']);
         }
 
-        $ctx = StreamContextFactory::getContext($fileUrl, $options, array('notification' => array($this, 'callbackGet')));
+        $ctx = StreamContextFactory::getContext($fileUrl, $options, ['notification' => [$this, 'callbackGet']]);
 
         $proxy = $this->proxyManager->getProxyForRequest($fileUrl);
         $usingProxy = $proxy->getFormattedUrl(' using proxy (%s)');
@@ -290,7 +289,7 @@ class RemoteFilesystem
         $errorMessage = '';
         $errorCode = 0;
         $result = false;
-        set_error_handler(function ($code, $msg) use (&$errorMessage): bool {
+        set_error_handler(static function ($code, $msg) use (&$errorMessage): bool {
             if ($errorMessage) {
                 $errorMessage .= "\n";
             }
@@ -298,7 +297,7 @@ class RemoteFilesystem
 
             return true;
         });
-        $http_response_header = array();
+        $http_response_header = [];
         try {
             $result = $this->getRemoteContents($originUrl, $fileUrl, $ctx, $http_response_header, $maxFileSize);
 
@@ -308,7 +307,7 @@ class RemoteFilesystem
                     HttpDownloader::outputWarnings($this->io, $originUrl, json_decode($result, true));
                 }
 
-                if (in_array($statusCode, array(401, 403)) && $retryAuthFailure) {
+                if (in_array($statusCode, [401, 403]) && $retryAuthFailure) {
                     $this->promptAuthAndRetry($statusCode, $this->findStatusMessage($http_response_header), $http_response_header);
                 }
             }
@@ -347,10 +346,10 @@ class RemoteFilesystem
             if (!$this->degradedMode && false !== strpos($e->getMessage(), 'Operation timed out')) {
                 $this->degradedMode = true;
                 $this->io->writeError('');
-                $this->io->writeError(array(
+                $this->io->writeError([
                     '<error>'.$e->getMessage().'</error>',
                     '<error>Retrying with degraded mode, check https://getcomposer.org/doc/articles/troubleshooting.md#degraded-mode for more info</error>',
-                ));
+                ]);
 
                 return $this->get($this->originUrl, $this->fileUrl, $additionalOptions, $this->fileName, $this->progress);
             }
@@ -428,11 +427,11 @@ class RemoteFilesystem
                 }
 
                 $this->degradedMode = true;
-                $this->io->writeError(array(
+                $this->io->writeError([
                     '',
                     '<error>Failed to decode response: '.$e->getMessage().'</error>',
                     '<error>Retrying with degraded mode, check https://getcomposer.org/doc/articles/troubleshooting.md#degraded-mode for more info</error>',
-                ));
+                ]);
 
                 return $this->get($this->originUrl, $this->fileUrl, $additionalOptions, $this->fileName, $this->progress);
             }
@@ -445,7 +444,7 @@ class RemoteFilesystem
             }
 
             $errorMessage = '';
-            set_error_handler(function ($code, $msg) use (&$errorMessage): bool {
+            set_error_handler(static function ($code, $msg) use (&$errorMessage): bool {
                 if ($errorMessage) {
                     $errorMessage .= "\n";
                 }
@@ -482,10 +481,10 @@ class RemoteFilesystem
             if (!$this->degradedMode && false !== strpos($e->getMessage(), 'Operation timed out')) {
                 $this->degradedMode = true;
                 $this->io->writeError('');
-                $this->io->writeError(array(
+                $this->io->writeError([
                     '<error>'.$e->getMessage().'</error>',
                     '<error>Retrying with degraded mode, check https://getcomposer.org/doc/articles/troubleshooting.md#degraded-mode for more info</error>',
-                ));
+                ]);
 
                 return $this->get($this->originUrl, $this->fileUrl, $additionalOptions, $this->fileName, $this->progress);
             }
@@ -511,7 +510,7 @@ class RemoteFilesystem
      *
      * @return string|false The response contents or false on failure
      */
-    protected function getRemoteContents(string $originUrl, string $fileUrl, $context, array &$responseHeaders = null, int $maxFileSize = null)
+    protected function getRemoteContents(string $originUrl, string $fileUrl, $context, ?array &$responseHeaders = null, ?int $maxFileSize = null)
     {
         $result = false;
 
@@ -531,7 +530,7 @@ class RemoteFilesystem
         }
 
         // https://www.php.net/manual/en/reserved.variables.httpresponseheader.php
-        $responseHeaders = $http_response_header ?? array();
+        $responseHeaders = $http_response_header ?? [];
 
         if (null !== $e) {
             throw $e;
@@ -587,12 +586,11 @@ class RemoteFilesystem
 
     /**
      * @param positive-int $httpStatus
-     * @param string|null  $reason
      * @param string[]     $headers
      *
      * @return void
      */
-    protected function promptAuthAndRetry($httpStatus, ?string $reason = null, array $headers = array())
+    protected function promptAuthAndRetry($httpStatus, ?string $reason = null, array $headers = [])
     {
         $result = $this->authHelper->promptAuthIfNeeded($this->fileUrl, $this->originUrl, $httpStatus, $reason, $headers, 1 /** always pass 1 as RemoteFilesystem is single threaded there is no race condition possible */);
 
@@ -605,15 +603,14 @@ class RemoteFilesystem
     }
 
     /**
-     * @param string  $originUrl
      * @param mixed[] $additionalOptions
      *
      * @return mixed[]
      */
     protected function getOptionsForUrl(string $originUrl, array $additionalOptions)
     {
-        $tlsOptions = array();
-        $headers = array();
+        $tlsOptions = [];
+        $headers = [];
 
         if (extension_loaded('zlib')) {
             $headers[] = 'Accept-Encoding: gzip';
@@ -695,8 +692,6 @@ class RemoteFilesystem
     /**
      * @param string|false $result
      * @param string[]     $http_response_header
-     *
-     * @return string|null
      */
     private function decodeResult($result, array $http_response_header): ?string
     {
@@ -719,8 +714,6 @@ class RemoteFilesystem
 
     /**
      * @param string|false $result
-     *
-     * @return string|null
      */
     private function normalizeResult($result): ?string
     {
