@@ -19,8 +19,6 @@ final class IgnoreNothingPlatformRequirementFilterTest extends TestCase
 {
     /**
      * @dataProvider dataIsIgnored
-     *
-     * @param string $req
      */
     public function testIsIgnored(string $req): void
     {
@@ -34,9 +32,9 @@ final class IgnoreNothingPlatformRequirementFilterTest extends TestCase
      */
     public function dataIsIgnored(): array
     {
-        return array(
-            'php is not ignored' => array('php'),
-            'monolog/monolog is not ignored' => array('monolog/monolog'),
-        );
+        return [
+            'php is not ignored' => ['php'],
+            'monolog/monolog is not ignored' => ['monolog/monolog'],
+        ];
     }
 }
