@@ -13,6 +13,7 @@
 namespace Composer\Test\Package\Version;
 
 use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterFactory;
+use Composer\IO\BufferIO;
 use Composer\Package\Version\VersionSelector;
 use Composer\Package\Package;
 use Composer\Package\Link;
@@ -20,6 +21,7 @@ use Composer\Package\AliasPackage;
 use Composer\Repository\PlatformRepository;
 use Composer\Package\Version\VersionParser;
 use Composer\Test\TestCase;
+use Symfony\Component\Console\Output\StreamOutput;
 
 class VersionSelectorTest extends TestCase
 {
@@ -29,12 +31,12 @@ class VersionSelectorTest extends TestCase
 
     public function testLatestVersionIsReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package1 = $this->createPackage('1.2.1');
-        $package2 = $this->createPackage('1.2.2');
-        $package3 = $this->createPackage('1.2.0');
-        $packages = array($package1, $package2, $package3);
+        $package1 = $this->getPackage('foo/bar', '1.2.1');
+        $package2 = $this->getPackage('foo/bar', '1.2.2');
+        $package3 = $this->getPackage('foo/bar', '1.2.0');
+        $packages = [$package1, $package2, $package3];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -51,44 +53,60 @@ class VersionSelectorTest extends TestCase
 
     public function testLatestVersionIsReturnedThatMatchesPhpRequirements(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $platform = new PlatformRepository(array(), array('php' => '5.5.0'));
+        $platform = new PlatformRepository([], ['php' => '5.5.0']);
         $repositorySet = $this->createMockRepositorySet();
         $versionSelector = new VersionSelector($repositorySet, $platform);
 
         $parser = new VersionParser;
-        $package1 = $this->createPackage('1.0.0');
-        $package1->setRequires(array('php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.4'), Link::TYPE_REQUIRE, '>=5.4')));
-        $package2 = $this->createPackage('2.0.0');
-        $package2->setRequires(array('php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.6'), Link::TYPE_REQUIRE, '>=5.6')));
-        $packages = array($package1, $package2);
+        $package0 = $this->getPackage('foo/bar', '0.9.0');
+        $package0->setRequires(['php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.6'), Link::TYPE_REQUIRE, '>=5.6')]);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package1->setRequires(['php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.4'), Link::TYPE_REQUIRE, '>=5.4')]);
+        $package2 = $this->getPackage('foo/bar', '2.0.0');
+        $package2->setRequires(['php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.6'), Link::TYPE_REQUIRE, '>=5.6')]);
+        $package3 = $this->getPackage('foo/bar', '2.1.0');
+        $package3->setRequires(['php' => new Link($packageName, 'php', $parser->parseConstraints('>=5.6'), Link::TYPE_REQUIRE, '>=5.6')]);
+        $packages = [$package0, $package1, $package2, $package3];
 
         $repositorySet->expects($this->any())
             ->method('findPackages')
             ->with($packageName, null)
             ->will($this->returnValue($packages));
 
-        $best = $versionSelector->findBestCandidate($packageName);
-        $this->assertSame($package1, $best, 'Latest version supporting php 5.5 should be returned (1.0.0)');
+        $io = new BufferIO();
+        $best = $versionSelector->findBestCandidate($packageName, null, 'stable', null, 0, $io);
+        $this->assertSame((string) $package1, (string) $best, 'Latest version supporting php 5.5 should be returned (1.0.0)');
+        self::assertSame("<warning>Cannot use foo/bar's latest version 2.1.0 as it requires php >=5.6 which is not satisfied by your platform.".PHP_EOL, $io->getOutput());
+
+        $io = new BufferIO('', StreamOutput::VERBOSITY_VERBOSE);
+        $best = $versionSelector->findBestCandidate($packageName, null, 'stable', null, 0, $io);
+        $this->assertSame((string) $package1, (string) $best, 'Latest version supporting php 5.5 should be returned (1.0.0)');
+        self::assertSame(
+            "<warning>Cannot use foo/bar's latest version 2.1.0 as it requires php >=5.6 which is not satisfied by your platform.".PHP_EOL
+            ."<warning>Cannot use foo/bar 2.0.0 as it requires php >=5.6 which is not satisfied by your platform.".PHP_EOL,
+            $io->getOutput()
+        );
+
         $best = $versionSelector->findBestCandidate($packageName, null, 'stable', PlatformRequirementFilterFactory::ignoreAll());
-        $this->assertSame($package2, $best, 'Latest version should be returned when ignoring platform reqs (2.0.0)');
+        $this->assertSame((string) $package3, (string) $best, 'Latest version should be returned when ignoring platform reqs (2.1.0)');
     }
 
     public function testLatestVersionIsReturnedThatMatchesExtRequirements(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $platform = new PlatformRepository(array(), array('ext-zip' => '5.3.0'));
+        $platform = new PlatformRepository([], ['ext-zip' => '5.3.0']);
         $repositorySet = $this->createMockRepositorySet();
         $versionSelector = new VersionSelector($repositorySet, $platform);
 
         $parser = new VersionParser;
-        $package1 = $this->createPackage('1.0.0');
-        $package1->setRequires(array('ext-zip' => new Link($packageName, 'ext-zip', $parser->parseConstraints('^5.2'), Link::TYPE_REQUIRE, '^5.2')));
-        $package2 = $this->createPackage('2.0.0');
-        $package2->setRequires(array('ext-zip' => new Link($packageName, 'ext-zip', $parser->parseConstraints('^5.4'), Link::TYPE_REQUIRE, '^5.4')));
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package1->setRequires(['ext-zip' => new Link($packageName, 'ext-zip', $parser->parseConstraints('^5.2'), Link::TYPE_REQUIRE, '^5.2')]);
+        $package2 = $this->getPackage('foo/bar', '2.0.0');
+        $package2->setRequires(['ext-zip' => new Link($packageName, 'ext-zip', $parser->parseConstraints('^5.4'), Link::TYPE_REQUIRE, '^5.4')]);
+        $packages = [$package1, $package2];
 
         $repositorySet->expects($this->any())
             ->method('findPackages')
@@ -103,17 +121,17 @@ class VersionSelectorTest extends TestCase
 
     public function testLatestVersionIsReturnedThatMatchesPlatformExt(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
         $platform = new PlatformRepository();
         $repositorySet = $this->createMockRepositorySet();
         $versionSelector = new VersionSelector($repositorySet, $platform);
 
         $parser = new VersionParser;
-        $package1 = $this->createPackage('1.0.0');
-        $package2 = $this->createPackage('2.0.0');
-        $package2->setRequires(array('ext-barfoo' => new Link($packageName, 'ext-barfoo', $parser->parseConstraints('*'), Link::TYPE_REQUIRE, '*')));
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package2 = $this->getPackage('foo/bar', '2.0.0');
+        $package2->setRequires(['ext-barfoo' => new Link($packageName, 'ext-barfoo', $parser->parseConstraints('*'), Link::TYPE_REQUIRE, '*')]);
+        $packages = [$package1, $package2];
 
         $repositorySet->expects($this->any())
             ->method('findPackages')
@@ -128,18 +146,18 @@ class VersionSelectorTest extends TestCase
 
     public function testLatestVersionIsReturnedThatMatchesComposerRequirements(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $platform = new PlatformRepository(array(), array('composer-runtime-api' => '1.0.0'));
+        $platform = new PlatformRepository([], ['composer-runtime-api' => '1.0.0']);
         $repositorySet = $this->createMockRepositorySet();
         $versionSelector = new VersionSelector($repositorySet, $platform);
 
         $parser = new VersionParser;
-        $package1 = $this->createPackage('1.0.0');
-        $package1->setRequires(array('composer-runtime-api' => new Link($packageName, 'composer-runtime-api', $parser->parseConstraints('^1.0'), Link::TYPE_REQUIRE, '^1.0')));
-        $package2 = $this->createPackage('1.1.0');
-        $package2->setRequires(array('composer-runtime-api' => new Link($packageName, 'composer-runtime-api', $parser->parseConstraints('^2.0'), Link::TYPE_REQUIRE, '^2.0')));
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package1->setRequires(['composer-runtime-api' => new Link($packageName, 'composer-runtime-api', $parser->parseConstraints('^1.0'), Link::TYPE_REQUIRE, '^1.0')]);
+        $package2 = $this->getPackage('foo/bar', '1.1.0');
+        $package2->setRequires(['composer-runtime-api' => new Link($packageName, 'composer-runtime-api', $parser->parseConstraints('^2.0'), Link::TYPE_REQUIRE, '^2.0')]);
+        $packages = [$package1, $package2];
 
         $repositorySet->expects($this->any())
             ->method('findPackages')
@@ -154,11 +172,11 @@ class VersionSelectorTest extends TestCase
 
     public function testMostStableVersionIsReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package1 = $this->createPackage('1.0.0');
-        $package2 = $this->createPackage('1.1.0-beta');
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package2 = $this->getPackage('foo/bar', '1.1.0-beta');
+        $packages = [$package1, $package2];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -174,11 +192,11 @@ class VersionSelectorTest extends TestCase
 
     public function testMostStableVersionIsReturnedRegardlessOfOrder(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package1 = $this->createPackage('2.x-dev');
-        $package2 = $this->createPackage('2.0.0-beta3');
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '2.x-dev');
+        $package2 = $this->getPackage('foo/bar', '2.0.0-beta3');
+        $packages = [$package1, $package2];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->exactly(2))
@@ -199,11 +217,11 @@ class VersionSelectorTest extends TestCase
 
     public function testHighestVersionIsReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package1 = $this->createPackage('1.0.0');
-        $package2 = $this->createPackage('1.1.0-beta');
-        $packages = array($package1, $package2);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package2 = $this->getPackage('foo/bar', '1.1.0-beta');
+        $packages = [$package1, $package2];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -219,12 +237,12 @@ class VersionSelectorTest extends TestCase
 
     public function testHighestVersionMatchingStabilityIsReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package1 = $this->createPackage('1.0.0');
-        $package2 = $this->createPackage('1.1.0-beta');
-        $package3 = $this->createPackage('1.2.0-alpha');
-        $packages = array($package1, $package2, $package3);
+        $package1 = $this->getPackage('foo/bar', '1.0.0');
+        $package2 = $this->getPackage('foo/bar', '1.1.0-beta');
+        $package3 = $this->getPackage('foo/bar', '1.2.0-alpha');
+        $packages = [$package1, $package2, $package3];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -240,11 +258,11 @@ class VersionSelectorTest extends TestCase
 
     public function testMostStableUnstableVersionIsReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package2 = $this->createPackage('1.1.0-beta');
-        $package3 = $this->createPackage('1.2.0-alpha');
-        $packages = array($package2, $package3);
+        $package2 = $this->getPackage('foo/bar', '1.1.0-beta');
+        $package3 = $this->getPackage('foo/bar', '1.2.0-alpha');
+        $packages = [$package2, $package3];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -260,12 +278,12 @@ class VersionSelectorTest extends TestCase
 
     public function testDefaultBranchAliasIsNeverReturned(): void
     {
-        $packageName = 'foobar';
+        $packageName = 'foo/bar';
 
-        $package = $this->createPackage('1.1.0-beta');
-        $package2 = $this->createPackage('dev-main');
+        $package = $this->getPackage('foo/bar', '1.1.0-beta');
+        $package2 = $this->getPackage('foo/bar', 'dev-main');
         $package2Alias = new AliasPackage($package2, VersionParser::DEFAULT_BRANCH_ALIAS, VersionParser::DEFAULT_BRANCH_ALIAS);
-        $packages = array($package, $package2Alias);
+        $packages = [$package, $package2Alias];
 
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
@@ -284,7 +302,7 @@ class VersionSelectorTest extends TestCase
         $repositorySet = $this->createMockRepositorySet();
         $repositorySet->expects($this->once())
             ->method('findPackages')
-            ->will($this->returnValue(array()));
+            ->will($this->returnValue([]));
 
         $versionSelector = new VersionSelector($repositorySet);
         $best = $versionSelector->findBestCandidate('foobaz');
@@ -293,11 +311,6 @@ class VersionSelectorTest extends TestCase
 
     /**
      * @dataProvider provideRecommendedRequireVersionPackages
-     *
-     * @param string      $prettyVersion
-     * @param string      $expectedVersion
-     * @param string|null $branchAlias
-     * @param string      $packageName
      */
     public function testFindRecommendedRequireVersion(string $prettyVersion, string $expectedVersion, ?string $branchAlias = null, string $packageName = 'foo/bar'): void
     {
@@ -308,7 +321,7 @@ class VersionSelectorTest extends TestCase
         $package = new Package($packageName, $versionParser->normalize($prettyVersion), $prettyVersion);
 
         if ($branchAlias) {
-            $package->setExtra(array('branch-alias' => array($prettyVersion => $branchAlias)));
+            $package->setExtra(['branch-alias' => [$prettyVersion => $branchAlias]]);
         }
 
         $recommended = $versionSelector->findRecommendedRequireVersion($package);
@@ -319,54 +332,42 @@ class VersionSelectorTest extends TestCase
 
     public function provideRecommendedRequireVersionPackages(): array
     {
-        return array(
+        return [
             // real version, expected recommendation, [branch-alias], [pkg name]
-            array('1.2.1', '^1.2'),
-            array('1.2', '^1.2'),
-            array('v1.2.1', '^1.2'),
-            array('3.1.2-pl2', '^3.1'),
-            array('3.1.2-patch', '^3.1'),
-            array('2.0-beta.1', '^2.0@beta'),
-            array('3.1.2-alpha5', '^3.1@alpha'),
-            array('3.0-RC2', '^3.0@RC'),
-            array('0.1.0', '^0.1.0'),
-            array('0.1.3', '^0.1.3'),
-            array('0.0.3', '^0.0.3'),
-            array('0.0.3-alpha', '^0.0.3@alpha'),
+            ['1.2.1', '^1.2'],
+            ['1.2', '^1.2'],
+            ['v1.2.1', '^1.2'],
+            ['3.1.2-pl2', '^3.1'],
+            ['3.1.2-patch', '^3.1'],
+            ['2.0-beta.1', '^2.0@beta'],
+            ['3.1.2-alpha5', '^3.1@alpha'],
+            ['3.0-RC2', '^3.0@RC'],
+            ['0.1.0', '^0.1.0'],
+            ['0.1.3', '^0.1.3'],
+            ['0.0.3', '^0.0.3'],
+            ['0.0.3-alpha', '^0.0.3@alpha'],
             // date-based versions are not touched at all
-            array('v20121020', 'v20121020'),
-            array('v20121020.2', 'v20121020.2'),
+            ['v20121020', 'v20121020'],
+            ['v20121020.2', 'v20121020.2'],
             // dev packages without alias are not touched at all
-            array('dev-master', 'dev-master'),
-            array('3.1.2-dev', '3.1.2-dev'),
+            ['dev-master', 'dev-master'],
+            ['3.1.2-dev', '3.1.2-dev'],
             // dev packages with alias inherit the alias
-            array('dev-master', '^2.1@dev', '2.1.x-dev'),
-            array('dev-master', '^2.1@dev', '2.1-dev'),
-            array('dev-master', '^2.1@dev', '2.1.3.x-dev'),
-            array('dev-master', '^2.0@dev', '2.x-dev'),
-            array('dev-master', '^0.3.0@dev', '0.3.x-dev'),
-            array('dev-master', '^0.0.3@dev', '0.0.3.x-dev'),
-            array('dev-master', 'dev-master', VersionParser::DEFAULT_BRANCH_ALIAS),
+            ['dev-master', '^2.1@dev', '2.1.x-dev'],
+            ['dev-master', '^2.1@dev', '2.1-dev'],
+            ['dev-master', '^2.1@dev', '2.1.3.x-dev'],
+            ['dev-master', '^2.0@dev', '2.x-dev'],
+            ['dev-master', '^0.3.0@dev', '0.3.x-dev'],
+            ['dev-master', '^0.0.3@dev', '0.0.3.x-dev'],
+            ['dev-master', 'dev-master', VersionParser::DEFAULT_BRANCH_ALIAS],
             // numeric alias
-            array('3.x-dev', '^3.0@dev', '3.0.x-dev'),
-            array('3.x-dev', '^3.0@dev', '3.0-dev'),
+            ['3.x-dev', '^3.0@dev', '3.0.x-dev'],
+            ['3.x-dev', '^3.0@dev', '3.0-dev'],
             // ext in sync with php
-            array(PHP_MAJOR_VERSION . '.' . PHP_MINOR_VERSION . '.' . PHP_RELEASE_VERSION,  '*', null, 'ext-filter'),
+            [PHP_MAJOR_VERSION . '.' . PHP_MINOR_VERSION . '.' . PHP_RELEASE_VERSION,  '*', null, 'ext-filter'],
             // ext versioned individually
-            array('3.0.5', '^3.0', null, 'ext-xdebug'),
-        );
-    }
-
-    /**
-     * @param string $version
-     *
-     * @return Package
-     */
-    private function createPackage(string $version): Package
-    {
-        $parser = new VersionParser();
-
-        return new Package('foo', $parser->normalize($version), $version);
+            ['3.0.5', '^3.0', null, 'ext-xdebug'],
+        ];
     }
 
     /**
