@@ -26,7 +26,7 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo = new ArrayRepository;
         $arrayRepoTwo->addPackage($this->getPackage('bar', '1'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne, $arrayRepoTwo));
+        $repo = new CompositeRepository([$arrayRepoOne, $arrayRepoTwo]);
 
         $this->assertTrue($repo->hasPackage($this->getPackage('foo', '1')), "Should have package 'foo/1'");
         $this->assertTrue($repo->hasPackage($this->getPackage('bar', '1')), "Should have package 'bar/1'");
@@ -43,7 +43,7 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo = new ArrayRepository;
         $arrayRepoTwo->addPackage($this->getPackage('bar', '1'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne, $arrayRepoTwo));
+        $repo = new CompositeRepository([$arrayRepoOne, $arrayRepoTwo]);
 
         $this->assertEquals('foo', $repo->findPackage('foo', '1')->getName(), "Should find package 'foo/1' and get name of 'foo'");
         $this->assertEquals('1', $repo->findPackage('foo', '1')->getPrettyVersion(), "Should find package 'foo/1' and get pretty version of '1'");
@@ -64,7 +64,7 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo->addPackage($this->getPackage('bar', '2'));
         $arrayRepoTwo->addPackage($this->getPackage('foo', '3'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne, $arrayRepoTwo));
+        $repo = new CompositeRepository([$arrayRepoOne, $arrayRepoTwo]);
 
         $bats = $repo->findPackages('bat');
         $this->assertCount(1, $bats, "Should find one instance of 'bats' (defined in just one repository)");
@@ -87,7 +87,7 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo = new ArrayRepository;
         $arrayRepoTwo->addPackage($this->getPackage('bar', '1'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne, $arrayRepoTwo));
+        $repo = new CompositeRepository([$arrayRepoOne, $arrayRepoTwo]);
 
         $packages = $repo->getPackages();
         $this->assertCount(2, $packages, "Should get two packages");
@@ -107,7 +107,7 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo->addPackage($this->getPackage('bar', '2'));
         $arrayRepoTwo->addPackage($this->getPackage('bar', '3'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne));
+        $repo = new CompositeRepository([$arrayRepoOne]);
         $this->assertCount(1, $repo, "Composite repository should have just one package before addRepository() is called");
         $repo->addRepository($arrayRepoTwo);
         $this->assertCount(4, $repo, "Composite repository should have four packages after addRepository() is called");
@@ -121,29 +121,28 @@ class CompositeRepositoryTest extends TestCase
         $arrayRepoTwo = new ArrayRepository;
         $arrayRepoTwo->addPackage($this->getPackage('bar', '1'));
 
-        $repo = new CompositeRepository(array($arrayRepoOne, $arrayRepoTwo));
+        $repo = new CompositeRepository([$arrayRepoOne, $arrayRepoTwo]);
 
-        $this->assertEquals(2, count($repo), "Should return '2' for count(\$repo)");
+        $this->assertCount(2, $repo, "Should return '2' for count(\$repo)");
     }
 
     /**
      * @dataProvider provideMethodCalls
      *
-     * @param string $method
      * @param mixed[] $args
      */
     public function testNoRepositories(string $method, array $args): void
     {
-        $repo = new CompositeRepository(array());
-        $this->assertEquals(array(), call_user_func_array(array($repo, $method), $args));
+        $repo = new CompositeRepository([]);
+        $this->assertEquals([], call_user_func_array([$repo, $method], $args));
     }
 
     public function provideMethodCalls(): array
     {
-        return array(
-            array('findPackages', array('foo')),
-            array('search', array('foo')),
-            array('getPackages', array()),
-        );
+        return [
+            ['findPackages', ['foo']],
+            ['search', ['foo']],
+            ['getPackages', []],
+        ];
     }
 }
