@@ -16,10 +16,13 @@ use Composer\Config;
 use Composer\Console\Application;
 use Composer\IO\IOInterface;
 use Composer\Json\JsonFile;
+use Composer\Package\Locker;
 use Composer\Pcre\Preg;
+use Composer\Repository\InstalledFilesystemRepository;
 use Composer\Semver\VersionParser;
 use Composer\Package\PackageInterface;
 use Composer\Semver\Constraint\Constraint;
+use Composer\Test\Mock\FactoryMock;
 use Composer\Test\Mock\HttpDownloaderMock;
 use Composer\Test\Mock\ProcessExecutorMock;
 use Composer\Util\Filesystem;
@@ -46,7 +49,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     /**
      * @var array<string, bool>
      */
-    private static $executableCache = array();
+    private static $executableCache = [];
 
     /**
      * @var list<HttpDownloaderMock>
@@ -85,9 +88,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         }
     }
 
-    /**
-     * @return string
-     */
     public static function getUniqueTmpDirectory(): string
     {
         $attempts = 5;
@@ -109,6 +109,9 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
      *
      * The directory will be cleaned up on tearDown automatically.
      *
+     * @see createInstalledJson
+     * @see createComposerLock
+     * @see getApplicationTester
      * @param mixed[] $composerJson
      * @param mixed[] $authJson
      * @return string the newly created temp dir
@@ -124,13 +127,64 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         Platform::putEnv('COMPOSER_HOME', $dir.'/composer-home');
         Platform::putEnv('COMPOSER_DISABLE_XDEBUG_WARN', '1');
 
+        if ($composerJson === []) {
+            $composerJson = new \stdClass;
+        }
+        if ($authJson === []) {
+            $authJson = new \stdClass;
+        }
+
+        if (is_array($composerJson) && isset($composerJson['repositories']) && !isset($composerJson['repositories']['packagist.org'])) {
+            $composerJson['repositories']['packagist.org'] = false;
+        }
+
         chdir($dir);
-        file_put_contents($dir.'/composer.json', JsonFile::encode($composerJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_FORCE_OBJECT));
-        file_put_contents($dir.'/auth.json', JsonFile::encode($authJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_FORCE_OBJECT));
+        file_put_contents($dir.'/composer.json', JsonFile::encode($composerJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
+        file_put_contents($dir.'/auth.json', JsonFile::encode($authJson, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
 
         return $dir;
     }
 
+    /**
+     * Creates a vendor/composer/installed.json in CWD with the given packages
+     *
+     * @param PackageInterface[] $packages
+     * @param PackageInterface[] $devPackages
+     */
+    protected function createInstalledJson(array $packages = [], array $devPackages = [], bool $devMode = true): void
+    {
+        mkdir('vendor/composer', 0777, true);
+        $repo = new InstalledFilesystemRepository(new JsonFile('vendor/composer/installed.json'));
+        $repo->setDevPackageNames(array_map(static function (PackageInterface $pkg) {
+            return $pkg->getPrettyName();
+        }, $devPackages));
+        foreach ($packages as $pkg) {
+            $repo->addPackage($pkg);
+            mkdir('vendor/'.$pkg->getName(), 0777, true);
+        }
+        foreach ($devPackages as $pkg) {
+            $repo->addPackage($pkg);
+            mkdir('vendor/'.$pkg->getName(), 0777, true);
+        }
+
+        $factory = new FactoryMock();
+        $repo->write($devMode, $factory->createInstallationManager());
+    }
+
+    /**
+     * Creates a composer.lock in CWD with the given packages
+     *
+     * @param PackageInterface[] $packages
+     * @param PackageInterface[] $devPackages
+     */
+    protected function createComposerLock(array $packages = [], array $devPackages = []): void
+    {
+        $factory = new FactoryMock();
+
+        $locker = new Locker($this->getMockBuilder(IOInterface::class)->getMock(), new JsonFile('./composer.lock'), $factory->createInstallationManager(), (string) file_get_contents('./composer.json'));
+        $locker->setLockData($packages, $devPackages, [], [], [], 'dev', [], false, false, []);
+    }
+
     public function getApplicationTester(): ApplicationTester
     {
         $application = new Application();
@@ -140,9 +194,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         return new ApplicationTester($application);
     }
 
-    /**
-     * @return VersionParser
-     */
     protected static function getVersionParser(): VersionParser
     {
         if (!self::$parser) {
@@ -154,8 +205,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
     /**
      * @param Constraint::STR_OP_* $operator
-     * @param string $version
-     * @return Constraint
      */
     protected function getVersionConstraint($operator, string $version): Constraint
     {
@@ -173,8 +222,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
      * @template PackageClass of CompletePackage|CompleteAliasPackage
      *
      * @param  string $class  FQCN to be instantiated
-     * @param  string $name
-     * @param  string $version
      *
      * @return CompletePackage|CompleteAliasPackage|RootPackage|RootAliasPackage
      *
@@ -196,7 +243,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     }
 
     /**
-     * @param string $version
      * @return ($package is RootPackage ? RootAliasPackage : ($package is CompletePackage ? CompleteAliasPackage : AliasPackage))
      */
     protected function getAliasPackage(Package $package, string $version): AliasPackage
@@ -215,7 +261,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
 
     /**
      * @param array<string, array<string, string>> $config
-     * @return void
      */
     protected function configureLinks(PackageInterface $package, array $config): void
     {
@@ -247,10 +292,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         return $config;
     }
 
-    /**
-     * @param  string $directory
-     * @return void
-     */
     protected static function ensureDirectoryExistsAndClear(string $directory): void
     {
         $fs = new Filesystem();
@@ -267,7 +308,6 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
      *
      * @param string $executableName The name of the binary to test.
      *
-     * @return void
      *
      * @throws \PHPUnit\Framework\SkippedTestError
      */
@@ -286,14 +326,13 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
     /**
      * Transforms an escaped non-Windows command to match Windows escaping.
      *
-     * @param string $cmd
      *
      * @return string The transformed command
      */
     protected function getCmd(string $cmd): string
     {
         if (Platform::isWindows()) {
-            $cmd = Preg::replaceCallback("/('[^']*')/", function ($m) {
+            $cmd = Preg::replaceCallback("/('[^']*')/", static function ($m) {
                 // Double-quotes are used only when needed
                 $char = (strpbrk($m[1], " \t^&|<>()") !== false || $m[1] === "''") ? '"' : '';
 
@@ -304,7 +343,7 @@ abstract class TestCase extends \PHPUnit\Framework\TestCase
         return $cmd;
     }
 
-    protected function getHttpDownloaderMock(IOInterface $io = null, Config $config = null): HttpDownloaderMock
+    protected function getHttpDownloaderMock(?IOInterface $io = null, ?Config $config = null): HttpDownloaderMock
     {
         $this->httpDownloaderMocks[] = $mock = new HttpDownloaderMock($io, $config);
 
